#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <cstdint>

using namespace std;
using ll = long long;

constexpr int maxn = 3e5 + 10;
int n, x0, d;
int targets[maxn];
int nearest_k[maxn];
ll near_k_power[maxn];
__int128 nkp_pf[maxn];
__int128 sq_pf[maxn];
ll pf[maxn];

int get_near_k(int x) {
    int v = (x - x0) / d, c = std::abs(x0 + v * d - x);
    if (std::abs(x0 + (v + 1) * d - x) < c) ++v;
    else if (std::abs(x0 + (v + 1) * d - x) == c) {
        if (std::abs(v + 1) < std::abs(v)) ++v;
    } else if (std::abs(x0 + (v - 1) * d - x) < c) --v;
    else if (std::abs(x0 + (v - 1) * d - x) == c) {
        if (std::abs(v - 1) < std::abs(v)) --v;
    }
    return v;
}

__int128 ans_for_pk(int p, int k) {
    int pos1 = lower_bound(nearest_k, nearest_k + n, k) - nearest_k;
    __int128 ans = nkp_pf[pos1];
    ans += __int128(n - pos1) * (x0 + k * d) * (x0 + k * d);
    ans += sq_pf[n] - sq_pf[pos1];
    ans -= __int128(2) * (x0 + k * d) * (pf[n] - pf[pos1]);
    return ans + __int128(k) * p;
}

int ans_for_p(int p) {
    int l = 0, r = nearest_k[n - 1] + 1;
    while (r - l >= 3) {
        int m1 = l + (r - l) / 3, m2 = r - (r - l) / 3;
        auto a1 = ans_for_pk(p, m1);
        auto a2 = ans_for_pk(p, m2);
        if (a1 > a2) l = m1;
        else r = m2;
    }
    __int128 ans = ans_for_pk(p, l);
    for (int i = l + 1; i <= r; ++i) ans = std::min(ans, ans_for_pk(p, i));
    return ans;
}

void solve() {
    cin >> n;
    for (int i = 0; i < n; ++i) cin >> targets[i];
    sort(targets, targets + n);
    sq_pf[0] = 0;
    for (int i = 0; i < n; ++i) sq_pf[i + 1] = sq_pf[i] + 1ll * targets[i] * targets[i];
    for (int i = 0; i < n; ++i) pf[i + 1] = pf[i] + targets[i];
    cin >> x0 >> d;
    for (int i = 0; i < n; ++i) nearest_k[i] = get_near_k(targets[i]);
    for (int i = 0; i < n; ++i)
        near_k_power[i] = 1ll * (targets[i] - (x0 + nearest_k[i] * d))
                          * (targets[i] - (x0 + nearest_k[i] * d));
    for (int i = 0; i < n; ++i) nkp_pf[i + 1] = nkp_pf[i] + near_k_power[i];
    int m;
    cin >> m;
    for (int _ = 0; _ < m; ++_) {
        int p;
        cin >> p;
        cout << static_cast<ll>(ans_for_p(p)) << "\n";
    }
}

int main() {
    ios::sync_with_stdio(false), cin.tie(nullptr);
    int t = 1;
#ifdef LOCAL
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
    cin >> t;
#endif
#ifdef TEST
    freopen("input.txt", "r",stdin);
#endif
    while (t--) solve();
    return 0;
}
