#include <iostream>
#include <vector>
#include <algorithm>
#include <cstdint>

using namespace std;
using ll = long long;

constexpr ll maxn = 3e5 + 10;
ll n, x0, d;
ll targets[maxn];
ll nearest_k[maxn];
ll near_k_power[maxn];
__int128 nkp_pf[maxn];
__int128 sq_pf[maxn];
ll pf[maxn];

ll get_near_k(ll x) {
    ll v = (x - x0) / d, c = std::abs(x0 + v * d - x);
    if (std::abs(x0 + (v + 1) * d - x) < c) ++v;
    else if (std::abs(x0 + (v + 1) * d - x) == c) {
        if (std::abs(v + 1) < std::abs(v)) ++v;
    } else if (std::abs(x0 + (v - 1) * d - x) < c) --v;
    else if (std::abs(x0 + (v - 1) * d - x) == c) {
        if (std::abs(v - 1) < std::abs(v)) --v;
    }
    return v;
}

__int128 ans_for_pk_right(ll pos0, ll p, ll k) {
    ll pos1 = lower_bound(nearest_k, nearest_k + n, k) - nearest_k;
    __int128 ans = nkp_pf[pos1] - nkp_pf[pos0];
    ans += __int128(n - pos1) * (x0 + k * d) * (x0 + k * d);
    ans += sq_pf[n] - sq_pf[pos1];
    ans -= __int128(2) * (x0 + k * d) * (pf[n] - pf[pos1]);
    return ans;
}

__int128 ans_for_pk_left(ll pos0, ll p, ll k) {
    ll pos1 = lower_bound(nearest_k, nearest_k + n, k) - nearest_k;
    __int128 ans = nkp_pf[pos0] - nkp_pf[pos1];
    ans += __int128(pos1) * (x0 + k * d) * (x0 + k * d);
    ans += sq_pf[pos1] - sq_pf[0];
    ans -= __int128(2) * (x0 + k * d) * (pf[pos1] - pf[0]);
    return ans;
}

__int128 res_lr(ll left_k, ll p, ll right_k) {
    __int128 ans = 0;
    if (!left_k) ans += p * right_k;
    else if (!right_k) ans += p * std::abs(left_k);
    else if (right_k < std::abs(left_k)) ans += p * (2 * right_k + std::abs(left_k));
    else ans += p * (2 * std::abs(left_k) + right_k);
    return ans;
}

__int128 best_left_res(ll pos0, ll p, ll right_k) {
    ll l = std::min<ll>(nearest_k[0], 0) - 1, r = 0;
    while (r - l != 1) {
        ll m = (l + r) / 2;
        auto d = (ans_for_pk_left(pos0, p, m + 1) + res_lr(m + 1, p, right_k)) -
                 (ans_for_pk_left(pos0, p, m) + res_lr(m, p, right_k));
        if (d < 0) l = m;
        else r = m;
    }
    return ans_for_pk_left(pos0, p, r) + res_lr(r, p, right_k);
}

__int128 ans_for_p(ll p) {
    int pos0 = lower_bound(nearest_k, nearest_k + n, 0) - nearest_k;
    ll l = -1, r = std::max<ll>(0, nearest_k[n - 1]);
    while (r - l != 1) {
        ll m = (l + r) / 2;
        auto d = (ans_for_pk_right(pos0, p, m+1) + best_left_res(pos0, p, m+1)) -
                 (ans_for_pk_right(pos0, p, m) + best_left_res(pos0, p, m));
        if (d < 0) l = m;
        else r = m;
    }
    return ans_for_pk_right(pos0, p, r) + best_left_res(pos0, p, r);
    // ll l = 0, r = std::max<ll>(0, nearest_k[n - 1]);
    // while (r - l >= 3) {
    //     ll m1 = l + (r - l) / 3, m2 = r - (r - l) / 3;
    //     auto a1 = ans_for_pk_right(pos0, p, m1) + best_left_res(pos0, p, m1);
    //     auto a2 = ans_for_pk_right(pos0, p, m2) + best_left_res(pos0, p, m2);
    //     if (a1 > a2) l = m1;
    //     else r = m2;
    // }
    // auto ans = ans_for_pk_right(pos0, p, l) + best_left_res(pos0, p, l);
    // for (ll i = l + 1; i <= r; ++i) ans = std::min(ans, ans_for_pk_right(pos0, p, i) + best_left_res(pos0, p, i));
    // return ans;
}

void solve() {
    cin >> n;
    for (ll i = 0; i < n; ++i) cin >> targets[i];
    sort(targets, targets + n);
    sq_pf[0] = 0;
    for (ll i = 0; i < n; ++i) sq_pf[i + 1] = sq_pf[i] + 1ll * targets[i] * targets[i];
    for (ll i = 0; i < n; ++i) pf[i + 1] = pf[i] + targets[i];
    cin >> x0 >> d;
    for (ll i = 0; i < n; ++i) nearest_k[i] = get_near_k(targets[i]);
    for (ll i = 0; i < n; ++i)
        near_k_power[i] = 1ll * (targets[i] - (x0 + nearest_k[i] * d))
                          * (targets[i] - (x0 + nearest_k[i] * d));
    for (ll i = 0; i < n; ++i) nkp_pf[i + 1] = nkp_pf[i] + near_k_power[i];
    ll m;
    cin >> m;
    for (ll _ = 0; _ < m; ++_) {
        ll p;
        cin >> p;
        cout << static_cast<ll>(ans_for_p(p)) << "\n";
    }
}

int main() {
    ios::sync_with_stdio(false), cin.tie(nullptr);
    ll t = 1;
#ifdef LOCAL
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
    cin >> t;
#endif
#ifdef TEST
    freopen("input.txt", "r",stdin);
#endif
    while (t--) solve();
    return 0;
}
