#ifdef LOCAL
using int128 = long long;
#define I128MAX LLONG_MAX
#else
using int128 = __int128;
#define I128MAX LLONG_MAX;
#endif

#include <iostream>
#include <vector>
#include <utility>
#include <algorithm>
#include <numeric>
#include <set>
#include <map>
#include <array>
#include <limits.h>

using namespace std;
using ll = int128;
using printable = long long;
#define all(a) (a).begin(), (a).end()

ll cost(ll x, ll y) {
	return (x - y) * (x - y);
}

ll g(ll start, ll step_size, ll steps, ll step_cost, ll sum, ll cnt) {
	ll x = start + step_size * steps;
	return cnt * x * x - 2 * sum * x + steps * step_cost;
}

ll mincost(ll start, ll step_size, ll step_cost, ll sum, ll cnt) {
	ll l = 0, r = int(1e9) / step_size + 1;
	while (l < r) {
		ll steps = (l + r) / 2;
		if (g(start, step_size, steps, step_cost, sum, cnt) > g(start, step_size, steps + 1, step_cost, sum, cnt)) {
			l = steps + 1;
		}
		else {
			r = steps;
		}
	}
	return g(start, step_size, l, step_cost, sum, cnt);
}

vector<ll> solve(vector<ll> a, vector<ll> b, vector<ll> t, ll d) {
	int n = a.size(), m = b.size(), q = t.size();
	vector<ll> opt1(a.size()), opt2(b.size());
	for (int i = 0; i < a.size(); i++) {
		ll x = a[i];
		opt1[i] = (x + d / 2) / d;
	}
	for (int i = 0; i < b.size(); i++) {
		ll x = b[i];
		opt2[i] = (x + d / 2) / d;
	}
	vector<int> p(q); iota(all(p), 0);
	sort(all(p), [&](int l, int r) {return t[l] > t[r]; });
	ll sum = accumulate(all(b), 0), sumsq = 0;
	for (int j = 0; j < m; j++) {
		sumsq += b[j] * b[j];
	}
	vector<ll> res(q, LLONG_MAX);

	int prevj = 0;
	ll prev_ans = 0;
	ll prev_pos = 0;
	ll prev_sum = sum;
	ll prev_sumsq = sumsq;

	for (int i : p) {
		ll ans = prev_ans;
		ll pos = prev_pos;
		sum = prev_sum;
		sumsq = prev_sumsq;
		int j = prevj;
		for (; j <= m; j++) {
			ll x = ans + sumsq + mincost(pos * d, d, t[i], sum, m - j) + pos * t[i];
			if (res[i] >= x) {
				res[i] = min(res[i], x);
				prev_ans = ans;
				prev_pos = pos;
				prev_sum = sum;
				prev_sumsq = sumsq;
				prevj = j;
			}
			else {
				break;
			}
			if (j != b.size()) {
				ans += cost(opt2[j] * d, b[j]);
				sum -= b[j];
				sumsq -= b[j] * b[j];
				pos = opt2[j];
			}
		}
	}
	return res;
}

int main() {
	ios::sync_with_stdio(false);
	cin.tie(nullptr);

	int n; cin >> n;
	vector<long long> a(n);
	for (int i = 0; i < n; i++) cin >> a[i];
	long long x0, d; cin >> x0 >> d;
	vector<ll> bef, after;
	for (long long x : a) {
		(x < x0 ? bef : after).push_back(abs(x - x0));
	}
	int m; cin >> m;
	vector<ll> t(m);
	for (int i = 0; i < m; i++) {
		long long x; cin >> x;
		t[i] = x;
	}

	sort(all(bef));
	sort(all(after));
	vector<ll> ans = solve(bef, after, t, d);
	for (ll x : ans) {
		cout << printable(x) << '\n';
	}

	return 0;
}