#include <vector>
#include <iostream>
#include <algorithm>

using namespace std;


struct Tnode {
	int l, r, s;

	Tnode(int l, int r, int s) : l{ l }, r{ r }, s{ s }{}
};


struct tree {
	int n;
	vector <Tnode> T;

	void build(int l, int r, int v) {
		if (r - l == 1) {
			return;
		}

		int m = (l + r) / 2;

		T[v].l = T.size();
		T.emplace_back(-1, -1, 0);
		T[v].r = T.size();
		T.emplace_back(-1, -1, 0);
		build(l, m, T[v].l);
		build(m, r, T[v].r);
	}
	
	tree(int n_) {
		n = n_;
		T.emplace_back(0, -1, -1);
		build(0, n, 0);
	}



	int get(int l, int r, int v, int lv, int rv) {
		if (l >= rv || r <= lv) {
			return 0;
		}
		if (l >= lv && r <= rv) {
			return T[v].s;
		}

		int m = (l + r) / 2;

		return get(l, m, T[v].l, lv, rv) + get(m, r, T[v].r, lv, rv);
	}

	bool get(int l, int r, int vers) {
		return get(0, n, vers, l, r) > 0;
	}

	void change(int l, int r, int v, int pos, int val) {
		if (l > pos || r <= pos) {
			return;
		}
		if (r - l == 1) {
			T[v].s = val;
			return;
		}

		int m = (l + r) / 2;

		T.emplace_back(T[T[v].l]);
		T[v].l = T.size() - 1;
		change(l, m, T[v].l, pos, val);

		T.emplace_back(T[T[v].r]);
		T[v].r = T.size() - 1;
		change(m, r, T[v].r, pos, val);

		T[v].s = T[T[v].l].s + T[T[v].r].s;
	}

	void change(int pos, int val, int vers) {
		change(0, n, vers, pos, val);
	}
};


struct Node {
	int l, r, m;

	//Node(int l, int r, int m) : l{ l }, r{ r }, m{ m }{}

	bool operator < (const Node& other) const {
		return m < other.m;
	}
};

void solve() {
	int n, k;
	cin >> n >> k;

	vector <Node> inp(k);
	for (int i = 0; i < k; i++) {
		cin >> inp[i].l >> inp[i].m >> inp[i].r;
	}

	sort(inp.begin(), inp.end());

	tree T(n + 1);
	vector <int> Vers(k + 1);
	Vers[0] = T.T.size();
	T.T.emplace_back(T.T[0]);
	T.change(0, 1, Vers[0]);
	

	for (int i = 0; i < k; i++) {
		Vers[i + 1] = Vers[i];
		if (T.get(inp[i].l - 1, inp[i].m, Vers[i])) {
			Vers[i + 1] = T.T.size();
			T.T.emplace_back(T.T[Vers[i]]);
			T.change(inp[i].r, 1, Vers[i + 1]);
			continue;
		}

		int l = -2, r = i - 1;
		while (r - l > 1) {
			int m = (l + r) / 2;

			if (inp[m + 1].m >= inp[i].l) {
				r = m;
			}
			else {
				l = m;
			}
		}

		if (T.get(inp[i].l - 1, inp[i].r, Vers[r + 1])) {
			Vers[i + 1] = T.T.size();
			T.T.emplace_back(T.T[Vers[i]]);
			T.change(inp[i].r, 1, Vers[i + 1]);
		}
	}

	cout << (T.get(n, n + 1, Vers[k]) ? "YES" : "NO") << "\n";
}


int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);

	int t;
	cin >> t;
	while (t--) {
		solve();
	}
}
