#ifdef _DEBUG
#define _CRT_SECURE_NO_WARNINGS
#endif
#include <iostream>
#include <fstream>
#include <iomanip>
#include <string>
#include <cmath>
#include <stack>
#include <queue>
#include <deque>
#include <vector>
#include <algorithm>
#include <numeric>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <chrono>
#include <random>
#include <assert.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pil = pair<int, long long>;
using pli = pair<long long, int>;
using pll = pair<long long, long long>;
template <typename T>
using uset = unordered_set<T>;
template <typename T1, typename T2>
using umap = unordered_map<T1, T2>;

#ifdef _DEBUG
using i128 = long long;
#else
using i128 = __int128;
#endif

#define all(x) x.begin(), x.end()

const int N = 30000;
vector<int> t[N];
int dep[N];
int par[N];
int original[N];

void norm(int v, int pr = -1) {
	if (pr > -1)
		t[v].erase(find(all(t[v]), pr));
	for (int u : t[v])
		norm(u, v);
}

void renumerate(int n) {
	queue<int> q;
	int timer = 0;
	q.push(0);
	vector<int> id(n);
	while (!q.empty()) {
		int v = q.front();
		q.pop();
		original[timer] = v;
		id[v] = timer++;
		for (int u : t[v])
			q.push(u);
	}
	vector<pii> edges;
	for (int v = 0; v < n; v++)
		for (int u : t[v])
			edges.push_back({ v, u });
	for (int v = 0; v < n; v++)
		t[v].clear();
	for (pii e : edges)
		t[id[e.first]].push_back(id[e.second]);
}

void dfs1(int v) {
	for (int u : t[v]) {
		par[u] = v;
		dep[u] = dep[v] + 1;
		dfs1(u);
	}
}

/*int LCA(int v, int u) {
	if (dep[v] < dep[u])
		swap(v, u);
	for (int i = lg - 1; i > -1; i--)
		if (dep[up[i][v]] >= dep[u])
			v = up[i][v];
	if (v == u)
		return v;
	for (int i = lg - 1; i > -1; i--)
		if (up[i][v] != up[i][u])
			v = up[i][v], u = up[i][u];
	return par[v];
}

int dist(int v, int u) {
	return dep[v] + dep[u] - 2 * dep[LCA(v, u)];
}*/

struct edge {
	int u, c, f;
};

const int NODES = 1e6;
vector<int> g[NODES];
vector<edge> edges;

void add(int v, int u, int c) {
	g[v].push_back(edges.size());
	edges.push_back({ u, c, 0 });
	g[u].push_back(edges.size());
	edges.push_back({ v, 0, 0 });
}

const int inf = 1e9;
int bfsDep[N], ptr[N];
int S, T, V;

bool bfs() {
	for (int i = 0; i < V; i++)
		bfsDep[i] = inf;
	queue<int> q;
	bfsDep[S] = 0;
	q.push(S);
	while (!q.empty()) {
		int v = q.front();
		q.pop();
		for (int ei : g[v]) {
			int u = edges[ei].u;
			int cap = edges[ei].c - edges[ei].f;
			if (cap && bfsDep[u] > bfsDep[v] + 1) {
				bfsDep[u] = bfsDep[v] + 1;
				q.push(u);
			}
		}
	}
	return bfsDep[T] < inf;
}

int dfs(int v, int w = inf) {
	if (v == T)
		return w;
	for (; ptr[v] < (int)g[v].size(); ptr[v]++) {
		int ei = g[v][ptr[v]];
		int u = edges[ei].u;
		int cap = edges[ei].c - edges[ei].f;
		if (bfsDep[u] == bfsDep[v] + 1 && cap > 0) {
			int delta = dfs(u, min(w, cap));
			if (delta) {
				edges[ei].f += delta;
				edges[ei ^ 1].f -= delta;
				return delta;
			}
		}
	}
	return 0;
}

int ls[2 * N], rs[2 * N];
int leaf_id[N];
int nv = 1;

void build(int v, int tl, int tr) {
	if (tr - tl == 1) {
		leaf_id[tl] = v;
		return;
	}
	ls[v] = nv++;
	rs[v] = nv++;
	add(v, ls[v], inf);
	add(v, rs[v], inf);
	int m = (tl + tr) / 2;
	build(ls[v], tl, m);
	build(rs[v], m, tr);
}

void add_seg(int l, int r, int from, int v, int tl, int tr) {
	if (l <= tl && tr <= r) {
		add(from, v, 1);
		return;
	}
	if (l >= tr || r <= tl)
		return;
	int m = (tl + tr) / 2;
	add_seg(l, r, from, ls[v], tl, m);
	add_seg(l, r, from, rs[v], m, tr);
}

inline void solve() {
	int n;
	cin >> n;
	int d;
	cin >> d;
	for (int i = 0; i < n - 1; i++) {
		int v, u;
		cin >> v >> u;
		v--;
		u--;
		t[v].push_back(u);
		t[u].push_back(v);
	}
	norm(0);
	renumerate(n);
	dfs1(0);
	auto get_seg = [&](int v, int di) -> pii {
		int L = v;
		int R = v;
		for (int _ = 0; _ < di && !g[L].empty(); _++)
			L = g[L][0];
		for (int _ = 0; _ < di && !g[R].empty(); _++)
			R = g[R].back();
		return { L, R };
	};
	nv = n + 1;
	build(n, 0, n);
	for (int v = 0; v < n; v++)
		if (dep[v] & 1) {
			vector<pii> segs;
			int u = v;
			for (int _ = 0; _ < d; _++) {
				segs.push_back(get_seg(u, d - _));
				if (!u)
					break;
				u = par[u];
			}
			segs.push_back({ u, u });
			vector<pii> evt;
			for (auto& p : segs) {
				evt.push_back({ p.first, 0 });
				evt.push_back({ p.second + 1, 1 });
			}
			sort(all(evt));
			int ops = 0;
			int last = -1;
			for (auto e : evt) {
				if (!e.second) {
					ops++;
					if (!ops)
						last = e.first;
				} else {
					ops--;
					if (ops == 0)
						add_seg(last, e.first, v, n, 0, n);
				}
			}
		}
	for (int v = 0; v < n; v++)
		if (!(dep[v] & 1))
			add(leaf_id[v], v, 1);
	S = nv;
	T = nv + 1;
	V = nv + 2;
	for (int v = 0; v < n; v++) {
		if (dep[v] & 1)
			add(S, v, 1);
		else
			add(v, T, 1);
	}
	int flow = 0;
	while (bfs()) {
		fill(ptr, ptr + V, 0);
		while (int f = dfs(S))
			flow += f;
	}
	cout << flow << '\n';
	//cout << -1 << '\n';
}

signed main() {
#ifdef _DEBUG
	freopen("01.dat", "r", stdin);
#endif
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	int tt = 1;
#ifdef _DEBUG
	cin >> tt;
#endif
	for (int test_id = 1; test_id <= tt; test_id++) {
#ifdef _DEBUG
		cout << "TESTCASE# " << test_id << ":" << endl;
#endif
		solve();
	}
	return 0;
}