#pragma GCC optimize("O3, Ofast, unroll-loops, inline, no-stack-protector")
#include <bits/stdc++.h>
#pragma GCC target("avx2")

using namespace std;


using ll = long long;
using pii = pair<int, int>;

struct SegmentTree {
    struct Node {
        int x = 0, push = 0;

        Node operator+(const Node &other) const {
            return {x + other.x, 0};
        }
    };
    vector<Node> tree;
    int n;

    SegmentTree(int sz) {
        n = sz;
        tree.resize(4 * n);
    }

    void apply(int v) {
        tree[v].x = 1;
        tree[v].push = 1;
    }

    void push(int v) {
        if (tree[v].push) {
            apply(2 * v + 1);
            apply(2 * v + 2);
            tree[v].push = 0;
        }
    }

    void upd(int v, int cl, int cr, int l, int r) {
        if (cl >= r || cr <= l) return;
        if (cl >= l && cr <= r) {
            apply(v);
            return;
        }
        push(v);
        int m = (cl + cr) / 2;
        upd(2 * v + 1, cl, m, l, r);
        upd(2 * v + 2, m, cr, l, r);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }

    void upd(int l, int r) {
        upd(0, 0, n, l, r);
    }

    Node get(int v, int cl, int cr, int l, int r) {
        if (cl >= r || cr <= l) return {0, 0};
        if (cl >= l && cr <= r) return tree[v];
        int m = (cl + cr) / 2;
        push(v);
        return get(2 * v + 1, cl, m, l, r) + get(2 * v + 2, m, cr, l, r);
    }

    int get(int l, int r) {
        return get(0, 0, n, l, r).x;
    }
};


random_device rd;
mt19937 rng(rd());

struct Solution {
    int n, k;
    vector<vector<int>> g, gr;
    vector<int> used, ts;

    struct Segment {
        int l, m, r;
    };

    void dfs(int v) {
        used[v] = 1;
        for (auto u : g[v]) {
            if (!used[u]) dfs(u);
        }
        ts.push_back(v);
    }

    void dfs2(int v, vector<int> &comp) {
        used[v] = 1;
        comp.push_back(v);
        for (auto u : gr[v]) {
            if (used[u]) continue;
            dfs2(u, comp);
        }
    }

    Solution() {
        cin >> n >> k;
        vector<Segment> a(k);
        for (int i = 0; i < k; ++i) {
            cin >> a[i].l >> a[i].m >> a[i].r;
            --a[i].l; --a[i].r; --a[i].m;
        }
        g.resize(k);
        gr.resize(k);
        for (int i = 0; i < k; ++i) {
            for (int j = 0; j < k; ++j) {
                if (a[i].m >= a[j].l && a[i].m <= a[j].r) {
                    g[i].push_back(j);
                    gr[j].push_back(i);
                }
            }
        }
        used.resize(n);
        for (int i = 0; i < k; ++i) {
            if (!used[i]) {
                dfs(i);
            }
        }
        used.assign(n, 0);
        reverse(ts.begin(), ts.end());
        int cnt = 0;
        vector<vector<int>> comps;
        for (int i = 0; i < k; ++i) {
            if (!used[ts[i]]) {
                ++cnt;
                comps.emplace_back();
                dfs2(ts[i], comps.back());
            }
        }
        for (int _ = 0; _ < 1000; ++_) {
            SegmentTree tree(n);
            for (auto& comp : comps) {
                auto [l, m, r] = a[comp[rng() % int(comp.size())]];
                if (tree.get(m, m + 1)) continue;
                tree.upd(l, r + 1);
            }
            int cnt = 0;
            for (int i = 0; i < n; ++i) {
                if (!tree.get(i, i + 1)) {
                    ++cnt;
                }
            }
            if (cnt == 0) {
                cout << "YES\n";
                return;
            }
        }
        cout << "NO\n";
    }
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int t;
    cin >> t;
    while (t --> 0) {
        Solution sol{};
    }
}