#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>
#include <string>
#include <numeric>
#include <unordered_map>
#include <set>

using namespace std;

using ll = long long;

struct segmentTree {
	vector<ll> tree;
	vector<ll> vec;

	void build(ll i, ll l, ll r) {
		tree[i] = l;
		if (r - l > 1) {
			ll m = (l + r) / 2;
			build(i * 2 + 1, l, m);
			build(i * 2 + 2, m, r);
		}
	}

	segmentTree(ll n, ll x) {
		tree.resize(4 * n, 0);
		vec.resize(n, x);
		build(0, 0, n);
	}

	ll get(ll i, ll l, ll r, ll ql, ll qr) {
		if (l >= ql && r <= qr) return tree[i];
		if (l >= qr || r <= ql) return -1;
		ll m = (l + r) / 2;
		ll i1 = get(i * 2 + 1, l, m, ql, qr);
		ll i2 = get(i * 2 + 2, m, r, ql, qr);
		if (i1 == -1) return i2;
		if (i2 == -1) return i1;
		if (vec[i1] <= vec[i2]) return i1;
		return i2;
	}

	void set(ll i, ll l, ll r, ll id, ll x) {
		if (r - l == 1) {
			vec[l] = min(vec[l], x);
			return;
		}
		ll m = (l + r) / 2;
		if (id < m) set(i * 2 + 1, l, m, id, x);
		else set(i * 2 + 2, m, r, id, x);
		tree[i] = tree[i * 2 + 1];
		if (vec[tree[i]] > vec[tree[i * 2 + 2]]) tree[i] = tree[i * 2 + 2];
	}
};

struct staff {
	ll l, r, m;

	staff(bool b) {
		cin >> l >> m >> r;
		l--;
		m--;
	}
};

bool cmp(staff a, staff b) {
	return a.r < b.r;
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	ll t; cin >> t;
	while (t--) {
		ll n, k; cin >> n >> k;
		vector<staff> vec;
		for (int i = 0; i < k; i++) vec.push_back(true);
		sort(vec.begin(), vec.end(), cmp);
		vector<ll> dp(k, 1e18);
		bool ans = false; 
		segmentTree st1(n + 1, 1e18);
		segmentTree st2(n + 1, 1e18);
		for (int i = 0; i < k; i++) {
			if (vec[i].l == 0) dp[i] = 0;
			else {
				ll i1 = st1.get(0, 0, n + 1, vec[i].l + 1, vec[i].m + 1);
				ll i2 = st2.get(0, 0, n + 1, vec[i].l + 1, vec[i].r + 1);
				if (i1 != -1 && st1.vec[i1] < vec[i].l) {
					dp[i] = min(dp[i], i1);
				}
				else if (st2.vec[i2] < vec[i].l){
					dp[i] = min(dp[i], i2);
				}
			}
			if (vec[i].r == n && dp[i] != 1e18) ans = true;
			if (dp[i] != 1e18) {
				st1.set(0, 0, n + 1, vec[i].r, dp[i]);
				st2.set(0, 0, n + 1, vec[i].r, max(dp[i], vec[i].m));
			}
		}
		if (ans) cout << "YES" << endl;
		else cout << "NO" << endl;
	}
}
