#include <iostream>
#include <vector>
#include <iostream>
#include <algorithm>

using namespace std;

const int INF = 2e9;

struct Node {
    int mn, upd;

    Node(int mn = INF, int upd = INF) : mn(mn), upd(upd) {}

    Node operator+(const Node &node) const {
        return {min(mn, node.mn)};
    }

    void recalc(int x) {
        upd = min(upd, x);
        mn = min(upd, mn);
    }
};

struct SegmentTree {
    vector<Node> data;

    SegmentTree(int n) : data(4 * n) {}

    void push(int v) {
        data[2 * v + 1].recalc(data[v].upd);
        data[2 * v + 1].recalc(data[v].upd);
        data[v].upd = INF;
    }

    void update(int v, int l, int r, int lq, int rq, int x) {
        if (rq <= l || r <= lq) {
            return;
        }
        if (lq <= l & r <= rq) {
            data[v].recalc(x);
            return;
        }
        push(v);
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, lq, rq, x);
        update(2 * v + 2, m, r, lq, rq, x);
        data[v] = data[2 * v + 1] + data[2 * v + 2];
    }

    Node get(int v, int l, int r, int lq, int rq) {
        if (rq <= l || r <= lq || lq == rq) {
            return {};
        }
        if (lq <= l && r <= rq) {
            return data[v];
        }
        push(v);
        int m = (l + r) / 2;
        auto p1 = get(2 * v + 1, l, m, lq, rq);
        auto p2 = get(2 * v + 2, m, r, lq, rq);
        return p1 + p2;
    }
};

struct Event {
    int p, type, id;

    Event(int p, int type, int id) : p(p), type(type), id(id) {}

    bool operator<(const Event &ev) const {
        return p < ev.p || (p == ev.p && type < ev.type) || (p == ev.p && type == ev.type && id < ev.id);
    }
};

int solve() {
    int n, k;
    cin >> n >> k;
    vector<tuple<int, int, int>> a(k);
    vector<Event> evs;
    for (auto &[l, m, r] : a) {
        cin >> l >> m >> r;
        int id = (int) evs.size() / 2;
        evs.emplace_back(l, 0, id);
        evs.emplace_back(r, 1, id);
    }
    sort(evs.begin(), evs.end());
    SegmentTree tree_m2(n + 1), tree_m1(n + 1);
    vector<int> dp(k, INF), mn_l(n + 1, INF);
    bool ans = false;
    for (auto [p, type, id] : evs) {
        if (type) {
            auto [l, m, r] = a[id];
            int x = min({l, mn_l[l - 1],
                tree_m2.get(0, 0, n + 1, l, l + 1).mn,
                tree_m1.get(0, 0, n + 1, l, m).mn});
            dp[id] = x;
            mn_l[r] = min(mn_l[r], x);
            tree_m2.update(0, 0, n + 1, l, m, x);
            tree_m1.update(0, 0, n + 1, r, r + 1, x);
            ans |= (dp[id] == 1 && r == n);
            //cout << dp[id] << ' ' << id << '\n';
        }
    }
    if (ans) {
        cout << "YES\n";
    } else {
        cout << "NO\n";
    }
    return 0;
}

int main() {
    ios_base::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
    return 0;
}
