#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <cmath>
#include <map>
#include <set>
#include <algorithm>
#define all(v) v.begin(), v.end()
#define fi first
#define se second

using namespace std;
typedef int ll;
typedef long double ld;
typedef pair<int, int> pii;

const ll MAXN = (1 << 22);

struct SegTree {
	vector<ll> t, ot;
	vector<bool> ot2;
	SegTree() {
		t.resize(2 * MAXN, 0);
		ot.resize(2 * MAXN, 0);
		ot2.resize(2 * MAXN, 0);
	}
	void update(ll v) {
		t[v] = t[2 * v] + t[2 * v + 1];
	}
	void push(ll v, ll l, ll r) {
		if (ot2[v]) {
			t[v] = 0;
			if (r - l > 1) {
				ot[2 * v] = 0;
				ot[2 * v + 1] = 0;
				ot2[2 * v] = 1;
				ot2[2 * v + 1] = 1;
			}
			ot2[v] = 0;
		}
		if (ot[v]) {
			t[v] += (r - l) * ot[v];
			if (r - l > 1) {
				ot[2 * v] += ot[v];
				ot[2 * v + 1] += ot[v];
			}
			ot[v] = 0;
		}
	}
	ll get(ll v, ll l, ll r, ll al, ll ar) {
		push(v, l, r);
		if (l >= ar || r <= al) return 0;
		if (l >= al && r <= ar) return t[v];
		ll m = (l + r) / 2, vl = 2 * v, vr = vl + 1;
		return get(vl, l, m, al, ar) + get(vr, m, r, al, ar);
	}
	void add(ll v, ll l, ll r, ll al, ll ar, ll x) {
		push(v, l, r);
		if (l >= ar || r <= al) return;
		if (l >= al && r <= ar) {
			ot[v] += x;
			push(v, l, r);
			return;
		}
		ll m = (l + r) / 2, vl = 2 * v, vr = vl + 1;
		add(vl, l, m, al, ar, x);
		add(vr, m, r, al, ar, x);
		update(v);
	}
	void nu(ll v, ll l, ll r, ll al, ll ar) {
		push(v, l, r);
		if (l >= ar || r <= al) return;
		if (l >= al && r <= ar) {
			ot2[v] = 1;
			push(v, l, r);
			return;
		}
		ll m = (l + r) / 2, vl = 2 * v, vr = vl + 1;
		nu(vl, l, m, al, ar);
		nu(vr, m, r, al, ar);
		update(v);
	}
};

void solve() {
	ll n, m;
	cin >> n >> m;
	vector<vector<char>> a(n, vector<char>(m));
	for (ll i = 0; i < n; i++) {
		for (ll j = 0; j < m; j++) cin >> a[i][j];
	}
	ll ans = 0;
	ll last;
	ll cur = 0;
	SegTree t;
	vector<vector<ll>> cnt(n, vector<ll>(m, 0));
	for (ll i = 0; i < n; i++) {
		for (ll j = 0; j < m; j++) {
			if (a[i][j] == '0') continue;
			cnt[i][j] = 1;
			if (i) cnt[i][j] += cnt[i - 1][j];
		}
	}
	for (ll i = 0; i < n; i++) {
		last = 0;
		cur = 0;
		for (ll j = m - 1; j >= 0; j--) {
			ll r = i + 1 - cnt[i][j];
			if (last > i + 1 - r) {
				ll temp = t.get(1, 0, MAXN, 0, r);
				cur -= temp;
				t.nu(1, 0, MAXN, 0, r);
			}
			t.add(1, 0, MAXN, r, i + 1, 1);
			last = i + 1 - r;
			cur += last;
			ans = max(ans, cur);
		}
		t.nu(1, 0, MAXN, 0, n);
	}
	cout << ans << '\n';
}

int main() {
	ll t = 1;
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	cin >> t;
#else
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
#endif
	while (t--) solve();
}