#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <cmath>
#include <map>
#include <set>
#include <algorithm>
#define all(v) v.begin(), v.end()
#define fi first
#define se second

using namespace std;
typedef long long ll;
typedef long double ld;
typedef pair<long long, long long> pii;

struct SegTree {
	ll n;
	vector<ll> a, t, ot;
	SegTree(ll _n) {
		n = _n;
		t.resize(4 * n);
		ot.resize(4 * n);
	}
	void update(ll v) {
		t[v] = t[2 * v] + t[2 * v + 1];
	}
	void push(ll v, ll l, ll r) {
		if (ot[v]) {
			t[v] += (r - l) * ot[v];
			if (r - l > 1) {
				ot[2 * v] += ot[v];
				ot[2 * v + 1] += ot[v];
			}
			ot[v] = 0;
		}
	}
	ll get(ll v, ll l, ll r, ll al, ll ar) {
		push(v, l, r);
		if (l >= ar || r <= al) return 0;
		if (l >= al && r <= ar) return t[v];
		ll m = (l + r) / 2, vl = 2 * v, vr = vl + 1;
		return get(vl, l, m, al, ar) + get(vr, m, r, al, ar);
	}
	void add(ll v, ll l, ll r, ll al, ll ar, ll x) {
		push(v, l, r);
		if (l >= ar || r <= al) return;
		if (l >= al && r <= ar) {
			ot[v] += x;
			push(v, l, r);
			return;
		}
		ll m = (l + r) / 2, vl = 2 * v, vr = vl + 1;
		add(vl, l, m, al, ar, x);
		add(vr, m, r, al, ar, x);
		update(v);
	}
	void change(ll v, ll l, ll r, ll i, ll x) {
		push(v, l, r);
		if (r - l == 1) {
			t[v] = x;
			return;
		}
		ll m = (l + r) / 2, vl = 2 * v, vr = vl + 1;
		if (i < m) change(vl, l, m, i, x);
		else change(vr, m, r, i, x);
		update(v);
	}
};

ll get(ll x1, ll y1, ll x2, ll y2, vector<vector<ll>>& pref) {
	if (!x1 && !y1) return pref[x2][y2];
	if (!x1) return pref[x2][y2] - pref[x2][y1 - 1];
	if (!y1) return pref[x2][y2] - pref[x1 - 1][y2];
	return pref[x2][y2] - pref[x1 - 1][y2] - pref[x2][y1 - 1] + pref[x1 - 1][y1 - 1];
}

void solve() {
	ll n, m;
	cin >> n >> m;
	vector<vector<char>> a(n, vector<char>(m));
	vector<vector<ll>> pref(n, vector<ll>(m));
	for (ll i = 0; i < n; i++) {
		for (ll j = 0; j < m; j++) cin >> a[i][j];
	}
	pref[0][0] = (a[0][0] - '0');
	for (ll i = 1; i < n; i++) {
		pref[i][0] = pref[i - 1][0] + (a[i][0] - '0');
	}
	for (ll i = 1; i < m; i++) {
		pref[0][i] = pref[0][i - 1] + (a[0][i] - '0');
	}
	for (ll i = 1; i < n; i++) {
		for (ll j = 1; j < m; j++) {
			pref[i][j] = pref[i - 1][j] + pref[i][j - 1] - pref[i - 1][j - 1] + (a[i][j] - '0');
		}
	}
	ll ans = 0;
	ll last;
	ll cur = 0;
	for (ll i = 0; i < n; i++) {
		last = 0;
		cur = 0;
		SegTree t(n);
		for (ll j = m - 1; j >= 0; j--) {
			ll mid, l = -1, r = i + 1;
			while (r - l > 1) {
				mid = (l + r) / 2;
				if (get(mid, j, i, j, pref) != (i - mid + 1)) l = mid;
				else r = mid;
			}
			if (last > i + 1 - r) {
				ll temp = t.get(1, 0, n, 0, r);
				cur -= temp;
				for (ll k = 0; k < r; k++) {
					t.change(1, 0, n, k, 0);
				}
			}
			t.add(1, 0, n, r, i + 1, 1);
			last = i + 1 - r;
			cur += last;
			ans = max(ans, cur);
		}
	}
	cout << ans << '\n';
}

int main() {
	ll t = 1;
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	cin >> t;
#else
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
#endif
	while (t--) solve();
}