#include <bits/stdc++.h>
using namespace std;
using ll = long long;
using ld = long double;

vector<vector<int>> g;
vector<int> used;

struct SegmentTree {
    vector<int> tree, push;
    int sz;

    SegmentTree(int _sz) {
        sz = _sz;
        tree.resize(4 * sz);
        push.resize(4 * sz);
    }

    void make_push(int v, int tl, int tr) {
        int tm = (tl + tr) / 2;
        tree[v * 2 + 1] += push[v] * (tm - tl);
        tree[v * 2 + 2] += push[v] * (tr - tm);
        push[v * 2 + 1] += push[v];
        push[v * 2 + 2] += push[v];
        push[v] = 0;
    }

    void update(int v, int tl, int tr, int l, int r, int val) {
        if (tl >= r || tr <= l) {
            return;
        }
        if (tl >= l && tr <= r) {
            tree[v] += val * (tr - tl);
            push[v] += val;
            return;
        }
        make_push(v, tl, tr);
        int tm = (tl + tr) / 2;
        update(v * 2 + 1, tl, tm, l, r, val);
        update(v * 2 + 2, tm, tr, l, r, val);
        tree[v] = tree[v * 2 + 1] + tree[v * 2 + 2];
    }

    int get(int v, int tl, int tr, int l, int r) {
        if (tl >= r || tr <= l) {
            return 0;
        }
        if (tl >= l && tr <= r) {
            return tree[v];
        }
        make_push(v, tl, tr);
        int tm = (tl + tr) / 2;
        return get(v * 2 + 1, tl, tm, l, r) + get(v * 2 + 2, tm, tr, l, r);
    }

    void update(int l, int r, int val) {
        update(0, 0, sz, l, r, val);
    }

    void add(int pos) {
        update(0, 0, sz, pos, pos + 1, 1);
    }

    void del(int pos) {
        int val = get(0, 0, sz, pos, pos + 1);
        update(0, 0, sz, pos, pos + 1, -val);
    }

    int get(int l, int r) {
        return get(0, 0, sz, l, r);
    }

    int get(int pos) {
        return get(0, 0, sz, pos, pos + 1);
    }
};

struct segment {
    int l, r;
    segment(int _l, int _r) : l(_l), r(_r) {}

    bool operator<(const segment& s) const {
        return l < s.l;
    }
};

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);

    int h, w;
    cin >> h >> w;
    vector<vector<int>> arr(h, vector<int>(w));
    for (int i = 0; i < h; ++i) {
        string s;
        cin >> s;
        for (int j = 0; j < w; ++j) {
            arr[i][j] = (s[j] == '1');
        }
    }

    SegmentTree tree(w);
    int best = 0;
    for (int i = 0; i < h; ++i) {
        int last = -1, l = -1;
        for (int j = 0; j < w; ++j) {
            if (arr[i][j] == 1) {
                tree.add(j);
                int cur = tree.get(j);
                if (cur > last) {
                    l = j;
                }
                last = cur;
            } else {
                tree.del(j);
                l = j;
                last = 0;
            }
            best = max(best, tree.get(l, j + 1));
        }
    }

    cout << best;

    return 0;
}