#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

#define int long long

struct DSU {
	vector <int> p, sz;
	vector <int> mn, mx;

	DSU(int n) {
		p.resize(n);
		mx.resize(n);
		mn.resize(n);
		for (int i = 0; i < n; i++) {
			p[i] = mn[i] = mx[i] = i;
		}
		sz.resize(n, 1);
	}

	int get(int x) {
		if (p[x] == x) return x;
		return p[x] = get(p[x]);
	}

	void merge(int x, int y) {
		x = get(x);
		y = get(y);
		if (x == y) return;
		if (sz[x] > sz[y]) {
			swap(x, y);
		}
		sz[y] += sz[x];
		p[x] = y;
		mn[y] = min(mn[y], mn[x]);
		mx[y] = max(mx[y], mx[x]);
	}

	int lft(int x) {
		return mn[get(x)];
	}

	int rgh(int x) {
		return mx[get(x)];
	}
};

signed main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);



	int n, m;
	cin >> n >> m;
	bool swapped = 0;
	if (m > n) {
		swapped = 1;
		swap(n, m);
	}
	
	vector <vector <bool>> a(n, vector <bool>(m));
	if (swapped) {
		for (int i = 0; i < m; i++) {
			for (int j = 0; j < n; j++) {
				char x;
				cin >> x;
				a[n - 1 - j][m - 1 - i] = x == '1';
			}
		}
	}
	else {
		for (int i = 0; i < n; i++) {
			for (int j = 0; j < m; j++) {
				char x;
				cin >> x;
				a[i][j] = x == '1';
			}
		}
	}

	

	int answer = 0;
	vector <int> streak(n);
	vector <int> inds(n);
	for (int i = 0; i < n; i++) {
		inds[i] = i;
	}
	for (int l = m - 1; l >= 0; l--) {
		for (int i = 0; i < n; i++) {
			if (a[i][l] == 0) {
				streak[i] = 0;
			}
			else {
				streak[i]++;
			}
		}
		sort(inds.begin(), inds.end(), [&](int i, int j) {
			return make_pair(-streak[i], -i) < make_pair(-streak[j], -j);
			});

		vector <int> val(n);
		DSU dsu(n);

		for (auto i : inds) {
			int k = streak[i];
			if (k == 0) break;

			val[i] = k;
			if (i < n - 1 && val[i + 1]) {
				val[i] = val[i + 1] + k;

				dsu.merge(i, i + 1);
			}
			if (0 < i && val[i - 1]) {
				val[dsu.lft(i - 1)] = max(val[dsu.lft(i - 1)], val[i] + (i - dsu.lft(i - 1)) * k);

				dsu.merge(i - 1, i);
			}
			answer = max(answer, val[dsu.lft(i)]);
		}
	}

	cout << answer;
}