#include <iostream>
#include <ios>
#include <algorithm>
#include <vector>
#include <deque>

using namespace std;

#define int long long

const int UNDO = 1e9;
const int HEIGHT = 2e5 + 2;

struct segtree {
    vector<int> t, lp, la;
    
    segtree(int n) {
        t.assign(n * 4, 0);
        lp.assign(n * 4, 0);
        la.assign(n * 4, 0);
    }

    void push(int v, int l, int r) {
        if (la[v] != UNDO) {
            t[v] = (r - l) * la[v];
            lp[v * 2 + 2] = lp[v * 2 + 2] = 0;
            la[v * 2 + 1] = la[v * 2 + 2] = la[v];
            la[v] = UNDO;
        }
        t[v] += (r - l) * lp[v];
        lp[v * 2 + 1] += lp[v];
        lp[v * 2 + 2] += lp[v];
        lp[v] = 0;
    }

    int plus(int v, int l, int r, int ql, int qr, int x) {
        push(v, l, r);
        if (r <= ql || qr <= l)
            return t[v];
        if (ql <= l && r <= qr) {
            lp[v] = x;
            return t[v] + (r - l) * x;
        }
        int m = (l + r) / 2;
        return t[v] = plus(v * 2 + 1, l, m, ql, qr, x) + plus(v * 2 + 2, m, r, ql, qr, x);
    }

    int asign(int v, int l, int r, int ql, int qr, int x) {
        push(v, l, r);
        if (r <= ql || qr <= l)
            return t[v];
        if (ql <= l && r <= qr) {
            lp[v] = 0;
            la[v] = x;
            return (r - l) * x;
        }
        int m = (l + r) / 2;
        return t[v] = asign(v * 2 + 1, l, m, ql, qr, x) + asign(v * 2 + 2, m, r, ql, qr, x);
    }

    int get(int v, int l, int r, int ql, int qr) {
        push(v, l, r);
        if (r <= ql || qr <= l)
            return 0;
        if (ql <= l && r <= qr)
            return t[v];
        int m = (l + r) / 2;
        return get(v * 2 + 1, l, m, ql, qr) + get(v * 2 + 2, m, r, ql, qr);
    }
};

signed main() {
    int n, m; cin >> n >> m;
    vector<string> ladder(n);
    for (auto &x: ladder) {
        cin >> x;
        x += '0';
    }
    vector<vector<int>> h(n, vector<int> (m));
    for (int i = 0; i < m; i++) 
        h[0][i] = ladder[0][i] == '1';
    for (int i = 1; i < n; i++) {
        for (int j = 0; j < m; j++) {
            h[i][j] = (h[i - 1][j] + 1) * (ladder[i][j] == '1');
        }
    }
    int ans = 0;
    for (int i = 0; i < n; i++) {
        segtree st(HEIGHT);
        for (int j = m - 1; j >= 0; j--) {
            st.asign(0, 0, HEIGHT, h[i][j] + 1, HEIGHT, 0);
            st.plus(0, 0, HEIGHT, 1, h[i][j] + 1, 1);
            ans = max(ans, st.get(0, 0, HEIGHT, 0, HEIGHT));
        }
    }
    cout << ans << '\n';
    // int n; cin >> n;
    // segtree st(n);
    // while (true) {
    //     char t; cin >> t;
    //     if (t == 'p') {
    //         int ql, qr, x; cin >> ql >> qr >> x;
    //         st.plus(0, 0, n, ql, ++qr, x);
    //     } if (t == 'a') {
    //         int ql, qr, x; cin >> ql >> qr >> x;
    //         st.asign(0, 0, n, ql, ++qr, x);
    //     } if (t == 'g') {
    //         int ql, qr; cin >> ql >> qr;
    //         cout << st.get(0, 0, n, ql, ++qr) << '\n';
    //     }
    // }
}