#pragma GCC optimize("O3")
#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<lng>(x.size())

using lng = long long;

struct SegTree {
	vector<int> left, right, max_elem, sum, setted;
	SegTree(int n) : left(4 * n), right(4 * n), max_elem(4 * n, 0), sum(4 * n, 0), setted(4 * n, -1) {
		build(0, 0, n);
	}
	void build(int v, int l, int r) {
		left[v] = l, right[v] = r;
		if (l + 1 != r) {
			int m = (l + r) / 2;
			build(2 * v + 1, l, m);
			build(2 * v + 2, m, r);
		}
	}
	void set_seg(int qleft, int qright, int val, int v = 0) {
		if (qleft <= left[v] && right[v] <= qright) {
			sum[v] = (right[v] - left[v]) * val;
			max_elem[v] = val;
			setted[v] = val;
			return;
		}
		if (qright <= left[v] || right[v] <= qleft) {
			return;
		}
		if (setted[v] != -1) {
			push(v);
		}
		set_seg(qleft, qright, val, 2 * v + 1);
		set_seg(qleft, qright, val, 2 * v + 2);
		max_elem[v] = max(max_elem[2 * v + 1], max_elem[2 * v + 2]);
		sum[v] = sum[2 * v + 1] + sum[2 * v + 2];
	}
	void push(int v) {
		if (setted[v] == -1) {
			return;
		}
		setted[2 * v + 1] = max_elem[2 * v + 1] = setted[v];
		setted[2 * v + 2] = max_elem[2 * v + 2] = setted[v];
		sum[2 * v + 1] = (right[2 * v + 1] - left[2 * v + 1]) * setted[v];
		sum[2 * v + 2] = (right[2 * v + 2] - left[2 * v + 2]) * setted[v];
		setted[v] = -1;
	}
	int rightmost_geq(int x, int v = 0) {
		if (max_elem[v] < x) {
			return -1;
		}
		if (left[v] + 1 == right[v]) {
			return left[v];
		}
		if (setted[v] != 0) {
			push(v);
		}
		if (max_elem[2 * v + 2] >= x) {
			return rightmost_geq(x, 2 * v + 2);
		}
		return rightmost_geq(x, 2 * v + 1);
	}
	int get_sum(int qleft, int qright, int v = 0) {
		if (qleft <= left[v] && right[v] <= qright) {
			return sum[v];
		}
		if (qright <= left[v] || right[v] <= qleft) {
			return 0;
		}
		if (setted[v] != -1) {
			push(v);
		}
		return get_sum(qleft, qright, 2 * v + 1) + get_sum(qleft, qright, 2 * v + 2);
	}
};

void solve() {
	int h, w; cin >> h >> w;
	vector<string> T(h);
	for (int i = 0; i < h; i++) {
		cin >> T[i];
	}
	vector<int> max_height(w, 0);
	for (int j = 0; j < w; j++) {
		while (max_height[j] < h && T[h - 1 - max_height[j]][j] == '1') {
			max_height[j]++;
		}
	}
	int ans = 0;
	SegTree tree(w);
	for (int l = w - 1; l >= 0; l--) {
		int pos = tree.rightmost_geq(max_height[l]);
		tree.set_seg(l, max(l, pos) + 1, max_height[l]);
		ans = max(ans, tree.get_sum(l, w));
	}
	for (int bottom = h - 2; bottom >= 0; bottom--) {
		for (int j = 0; j < w; j++) {
			if (max_height[j] > 0) {
				max_height[j]--;
			}
			else {
				while (max_height[j] < bottom + 1 && T[bottom - max_height[j]][j] == '1') {
					max_height[j]++;
				}
			}
		}
		tree.set_seg(0, w, 0);
		for (int l = w - 1; l >= 0; l--) {
			int pos = tree.rightmost_geq(max_height[l]);
			tree.set_seg(l, max(l, pos) + 1, max_height[l]);
			ans = max(ans, tree.get_sum(l, w));
		}
	}
	cout << ans;
}


int main() {
	cin.tie(nullptr)->sync_with_stdio(false);
	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
	}
	return 0;
}

/*
6 4
0011
1101
0111
1110
0111
0100
*/
/*
5 5
00100
01110
01110
01000
00000
*/