#pragma GCC optimize("O3")
#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <array>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<lng>(x.size())

using lng = long long;

struct Segment {
	int l, m, r, id;
	Segment(int a = 0, int b = 0, int c = 0, int i = 0) : l(a), m(b), r(c), id(i) {}
	bool operator< (Segment other) {
		if (r != other.r) {
			return (r < other.r);
		}
		if (m != other.m) {
			return (m < other.m);
		}
		if (l != other.l) {
			return (l < other.l);
		}
		return (id < other.id);
	}
};

static const int INF = 1e9;

struct SegTree {
	int left, right, min_elem;
	SegTree* lv, * rv;
	SegTree(int l = 0, int r = 1) : left(l), right(r), min_elem(INF), lv(nullptr), rv(nullptr) {
		if (l + 1 != r) {
			int m = (l + r) / 2;
			lv = new SegTree(l, m);
			rv = new SegTree(m, r);
		}
	}
	void update(int pos, int val) {
		if (left + 1 == right) {
			min_elem = min(min_elem, val);
			return;
		}
		if (pos < lv->right) {
			lv->update(pos, val);
		}
		else {
			rv->update(pos, val);
		}
		min_elem = min(lv->min_elem, rv->min_elem);
	}
	int get_min(int qleft, int qright) {
		if (qleft <= left && right <= qright) {
			return min_elem;
		}
		if (qright <= left || right <= qleft) {
			return INF;
		}
		return min(lv->get_min(qleft, qright), rv->get_min(qleft, qright));
	}
};

void solve() {
	int n, k; cin >> n >> k;
	vector<Segment> segs(k);
	for (auto& p : segs) {
		cin >> p.l >> p.m >> p.r;
	}
	sort(all(segs));
	SegTree dp(0, n + 1);
	dp.update(0, 0);
	for (auto& s : segs) {
		if (dp.get_min(s.l - 1, s.m) < INF) {
			dp.update(s.r, s.m);
		}
		else if (dp.get_min(s.m, s.r + 1) < s.l) {
			dp.update(s.r, s.m);
		}
	}
	if (dp.get_min(n, n + 1) < INF) {
		cout << "YES\n";
	}
	else {
		cout << "NO\n";
	}
}


int main() {
	cin.tie(nullptr)->sync_with_stdio(false);
	int t = 1;
	cin >> t;
	while (t--) {
		solve();
	}
	return 0;
}

/*
2
5 2
3 4 5
1 3 3
5 3
1 2 4
2 4 5
3 3 3
*/