#pragma GCC optimize("O3")
#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <array>
#include <stdint-gcc.h>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<lng>(x.size())

using lng = __int128_t;
static const lng INF = 1e18 + 1e6;
using ld = long double;

istream& operator>> (istream& in, __int128_t& X) {
	long long x; cin >> x;
	X = x;
	return in;
}

ostream& operator<< (ostream& out, __int128_t X) {
	vector<char> st;
	__int128_t ZERO = 0, TEN = 10;
	while (X > ZERO) {
		st.push_back('0' + X % TEN);
		X /= TEN;
	}
	reverse(all(st));
	for (auto elem : st) {
		cout << elem;
	}
	return out;
}

struct Query {
	lng energy_cost, left_ans, right_ans;
	int id, type;
	Query(lng t = 0, int i = 0) : energy_cost(t), left_ans(-1), right_ans(-1), id(i) {}
	bool operator< (Query other) {
		if (energy_cost != other.energy_cost) {
			return (energy_cost < other.energy_cost);
		}
		return (id < other.id);
	}
};

vector<__int128_t> suf_K, suf_B, pref_min;

__int128_t get_cost(__int128_t T, __int128_t k, vector<__int128_t>& coords, __int128_t d) {
	__int128_t X = k * d;
	int suf_pos = coords.end() - upper_bound(all(coords), X);
	int pref_pos = upper_bound(all(coords), X) - coords.begin();
	lng suf_ans = X * X * static_cast<lng>(suf_pos) + suf_B[suf_pos] - 2ll * X * suf_K[suf_pos];
	suf_ans += pref_min[pref_pos];
	suf_ans += T * k;
	return suf_ans;
}

void divide_and_conquer(lng min_d, lng max_d, int min_q, int max_q, vector<Query>& queries, vector<__int128_t>& coords, lng D) {
	if (min_q >= max_q) {
		return;
	}
	int q = (min_q + max_q) / 2;
	lng L = min_d - 1, R = max_d;
	while (R - L > 1ll) {
		lng M = (L + R) / 2ll;
		__int128_t p1 = get_cost(queries[q].energy_cost, M, coords, D);
		if (p1 >= get_cost(queries[q].energy_cost, M + 1, coords, D)) {
			L = M;
		}
		else {
			R = M;
		}
	}
	queries[q].right_ans = get_cost(queries[q].energy_cost, R, coords, D);
	divide_and_conquer(min_d, R, q + 1, max_q, queries, coords, D);
	divide_and_conquer(R, max_d, min_q, q, queries, coords, D);
}

//coords are sorted, queries are sorted
void solve_x0(lng n, vector<__int128_t> coords, lng d, vector<Query>& queries) {
	if (n == 0) {
		for (Query& q : queries) {
			q.right_ans = 0;
		}
		return;
	}
	suf_K.assign(n + 1, 0);
	suf_B.assign(n + 1, 0);
	pref_min.assign(n + 1, 0);
	for (int i = 1; i <= n; i++) {
		lng coord_r = coords[i - 1] + (d - coords[i - 1] % d);
		lng coord_l = coord_r - d;
		pref_min[i] = pref_min[i - 1] + min((coords[i - 1] - coord_r) * (coords[i - 1] - coord_r), (coords[i - 1] - coord_l) * (coords[i - 1] - coord_l));
	}
	for (int i = 1; i <= n; i++) {
		suf_K[i] = suf_K[i - 1] + coords[n - i];
		suf_B[i] = suf_B[i - 1] + coords[n - i] * coords[n - i];
	}
	divide_and_conquer(0, (coords[n - 1] + (d - coords[n - 1] % d)) / d, 0, sz(queries), queries, coords, d);
}

void solve() {
	lng n; cin >> n;
	vector<lng> x(n);
	for (lng& i : x) {
		cin >> i;
	}
	sort(all(x));
	lng x0, d, m; cin >> x0 >> d >> m;
	vector<Query> queries;
	for (int i = 0; i < m; i++) {
		lng t; cin >> t;
		queries.emplace_back(t, 2 * i);
		queries.emplace_back(2 * t, 2 * i + 1);
	}
	sort(all(queries));
	vector<__int128_t> coords;
	for (int i = 0; i < n && x[i] < x0; i++) {
		coords.push_back(x0 - x[i]);
	}
	reverse(all(coords));
	solve_x0(sz(coords), coords, d, queries);
	for (Query& que : queries) {
		swap(que.left_ans, que.right_ans);
	}
	coords.clear();
	for (int i = 0; i < n; i++) {
		if (x[i] < x0) {
			continue;
		}
		coords.push_back(x[i] - x0);
	}
	solve_x0(sz(coords), coords, d, queries);
	sort(all(queries), [&](Query a, Query b) {
		return (a.id < b.id);
		});
	for (int i = 0; i < m; i++) {
		cout << min(queries[2 * i].left_ans + queries[2 * i + 1].right_ans, queries[2 * i + 1].left_ans + queries[2 * i].right_ans) << '\n';
	}
}


int main() {
	cin.tie(nullptr)->sync_with_stdio(false);
	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
	}
	return 0;
}

/*
3
4 0 7
2 3
7
0
1
2
3
4
23
25
*/