#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using vll = vector<ll>;

#define all(x) x.begin(), x.end()

const ll INF = (ll) 1e18;

struct Node {
    ll sum;
    ll push;
    ll min;

    Node() {
        sum = 0;
        push = -1;
        min = INF;
    }
};

struct SegmentTree {
    vector<Node> t;
    int n;
    vector<tuple<ll, ll, ll>> partitions;

    void makePush(int v, int l, int r) {
        int m = (l + r) / 2;
        if (t[v].push == -1) {
            return;
        }
        t[2 * v + 1].sum = (m - l) * t[v].push;
        t[2 * v + 2].sum = (r - m) * t[v].push;
        t[2 * v + 1].push = t[v].push;
        t[2 * v + 2].push = t[v].push;
        t[2 * v + 1].min = t[v].push;
        t[2 * v + 2].min = t[v].push;
        t[v].push = -1;
    }

    void set(int v, int l, int r, int ql, int qr, ll val) {
        if (r <= ql || l >= qr) {
            return;
        }
        if (ql <= l && r <= qr) {
            t[v].sum = (r - l) * val;
            t[v].push = val;
            t[v].min = val;
            return;
        }
        int m = (l + r) / 2;
        makePush(v, l, r);
        set(2 * v + 1, l, m, ql, qr, val);
        set(2 * v + 2, m, r, ql, qr, val);
        t[v].sum = t[2 * v + 1].sum + t[2 * v + 2].sum;
        t[v].min = min(t[2 * v + 1].min, t[2 * v + 2].min);
    }

    void set(int l, int r, ll val) {
        set(0, 0, n, l, r, val);
    }

    ll get(int v, int l, int r, int ql, int qr) {
        if (r <= ql || l >= qr) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return t[v].sum;
        }
        int m = (l + r) / 2;
        makePush(v, l, r);
        return get(2 * v + 1, l, m, ql, qr) + get(2 * v + 2, m, r, ql, qr);
    }

    ll get(int l, int r) {
        return get(0, 0, n, l, r);
    }

    ll get_min(int v, int l, int r, int ql, int qr) {
        if (r <= ql || l >= qr) {
            return INF;
        }
        if (ql <= l && r <= qr) {
            return t[v].min;
        }
        int m = (l + r) / 2;
        makePush(v, l, r);
        return min(get_min(2 * v + 1, l, m, ql, qr), get_min(2 * v + 2, m, r, ql, qr));
    }

    ll get_min(int l, int r) {
        return get_min(0, 0, n, l, r);
    }

    void get_partitions(int v, int l, int r, int ql, int qr) {
        if (r <= ql || l >= qr) {
            return;
        }
        if (ql <= l && r <= qr) {
            partitions.push_back({l, r, v});
            return;
        }
        int m = (l + r) / 2;
        makePush(v, l, r);
        get_partitions(2 * v + 1, l, m, ql, qr);
        get_partitions(2 * v + 2, m, r, ql, qr);
    }

    ll find_less(int l, int r, int x) {
        partitions.clear();
        get_partitions(0, 0, n, l, r);
        sort(all(partitions));
        for (auto [l, r, v] : partitions) {
            makePush(v, l, r);
            if (t[v].min < x) {
                int left = l;
                int right = r;
                int nowV = v;
                while (left + 1 != right) {
                    makePush(nowV, left, right);
                    int mid = (left + right) / 2;
                    if (t[2 * nowV + 1].min < x) {
                        nowV = 2 * nowV + 1;
                        right = mid;
                    } else {
                        nowV = 2 * nowV + 2;
                        left = mid;
                    }
                }
                return left - 1;
            }
        }
        return r - 1;
    }
    
    SegmentTree(int n_) {
        n = n_;
        t.resize(4 * n);
    }
};

void solve() {
    int n, k;
    cin >> n >> k;
    vector<tuple<ll, ll, ll>> arr(k);
    for (int i = 0; i < k; ++i) {
        int l, m, r;
        cin >> l >> m >> r;
        arr[i] = {l, m, r};
    }
    vector<vll> dp(n + 1, vll(n + 1, 0));
    for (int len = 1; len <= n; ++len) {
        for (int l = 1; l <= n - len + 1; ++l) {
            int r = l + len - 1;
            for (auto [l2, m, r2] : arr) {
                if (!(l <= l2 && r2 <= r)) {
                    continue;
                }
                bool pref = (l == l2);
                bool suff = (r == r2);
                for (int j = l2; j < m; ++j) {
                    pref |= dp[l][j];
                }
                for (int j = m + 1; j <= r2; ++j) {
                    suff |= dp[j][r];
                }
                // if (pref && suff) {
                //     cout << l << " " << r << endl;
                // }
                dp[l][r] |= (pref && suff);
            }
        }
    }
    if (dp[1][n]) {
        cout << "YES\n";
    } else {
        cout << "NO\n";
    }
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(NULL);
    cout.tie(NULL);
    int t = 1;
    cin >> t;
    while (t--) {
        solve();
    }
    return 0;
}