#pragma GCC optimize("O3,unroll-loops")
#include <iostream>
#include <vector>
#include <cstddef>
#include <cstdint>
#include <algorithm>
#include <map>
#include <set>
#pragma GCC target("avx2")

using namespace std;

// #define int int64_t


#define vl (v * 2 + 1)
#define vr (v * 2 + 2)
#define tm ((tl + tr) / 2)

struct SegTree {
    struct Node {
        int sum = 0;
        int to_push = -1;
    };
public:
    SegTree(int sz) : da(sz * 4, Node{}) {
    }

    static Node Merge(Node a, Node b) {
        return {
            a.sum + b.sum,
            -1
        };
    }

    void Set(int ql, int qr, int val) {
        Set(ql, qr, val, 0, 0, da.size() / 4);
    }

    int Get(int ql, int qr) {
        return Get(ql, qr, 0, 0, da.size() / 4);
    }

private:

    Node Set(int ql, int qr, int val, int v, int tl, int tr) {
        if (qr <= tl || tr <= ql) {
            return da[v];
        } else if (ql <= tl && tr <= qr) {
            return da[v] = {
                val * (tr - tl),
                val
            };
        } else {
            Push(v, tl, tr);
            return da[v] = Merge(Set(ql, qr, val, vl, tl, tm), Set(ql, qr, val, vr, tm, tr));
        }
    }

    int Get(int ql, int qr, int v, int tl, int tr) {
        if (qr <= tl || tr <= ql) {
            return 0;
        } else if (ql <= tl && tr <= qr) {
            return da[v].sum;
        } else {
            Push(v, tl, tr);
            return Get(ql, qr, vl, tl, tm) + Get(ql, qr, vr, tm, tr);
        }
    }

    void Push(int v, int tl, int tr) {
        if (da[v].to_push == -1) return;
        da[vl] = {
            da[v].to_push * (tm - tl),
            da[v].to_push
        };
        da[vr] = {
            da[v].to_push * (tr - tm),
            da[v].to_push
        };
        da[v].to_push = -1;
    }

    vector<Node> da;
};

template<typename T>
int BinSearch(T &&f) {
    int l = 0, r = 1;
    while (f(r)) {
        l = r;
        r *= 2;
    }
    while (l + 1 < r) {
        int m = (l + r) / 2;
        if (f(m)) {
            l = m;
        } else {
            r = m;
        }
    }
    return l;
}


signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int h, w;
    cin >> h >> w;
    vector<vector<bool>> table(h, vector<bool>(w));
    string s;
    for (auto &i : table) {
        cin >> s;
        for (int j = 0; j < w; ++j) {
            i[j] = (s[j] == '1');
        }
    }
    vector<vector<int>> up_for(h, vector<int>(w));
    for (int c = 0; c < w; ++c) {
        up_for[0][c] = table[0][c];
    }
    for (int l = 1; l < h; ++l) {
        for (int c = 0; c < w; ++c) {
            up_for[l][c] = table[l][c] ? up_for[l - 1][c] + 1 : 0;
        }
    }
    int ans = 0;
    for (int line = 0; line < h; ++line) {
        vector<pair<int, int>> segs;
        bool active = false;
        for (int c = 0; c < w; ++c) {
            if (table[line][c] && active) {
                ++segs.back().second;
            } else if (table[line][c] && !active) {
                segs.emplace_back(c, c);
            }
            active = table[line][c];
        }
        for (auto z : segs) {
            auto l = z.first;
            auto r = z.second;
            const int len = r - l + 1;
            // first ind
            map<int, pair<int, int>, std::greater<>> vindlen;
            int curans = 0;
            for (int i = len - 1; i >= 0; --i) {
                auto it = vindlen.upper_bound(up_for[line][l + i]);
                int first_l;
                if (it == vindlen.end()) {
                    first_l = len;
                } else {
                    first_l = it->second.first;
                }
                for (auto jt = vindlen.begin(); jt != it; ++jt) {
                    curans += up_for[line][l + i] - jt->first * jt->second.second;
                }
                vindlen.erase(vindlen.begin(), it);
                curans += up_for[line][i + l];
                vindlen[up_for[line][l + i]] = { i, first_l - i };
                ans = max(ans, curans);
            }
        }
    }
    cout << ans << endl;


    return 0;
}