#pragma GCC optimize("Ofast")
#include<bits/stdc++.h>
#pragma GCC target("avx2")
 
using namespace std;
 
typedef int ll;
 
const ll INF = 1'000'000'000;
 
template<typename T>
bool assign_min(T& a, T b) {
    if (a > b) {
        a = b;
        return true;
    }
    return false;
}
 
template<typename T>
bool assign_max(T& a, T b) {
    if (a < b) {
        a = b;
        return true;
    }
    return false;
}
 
struct edge {
    ll mf, b;
    edge *inv;
    edge(ll mf, ll b): mf(mf), b(b) {}
    void add(ll x) {
        mf -= x;
        inv->mf += x;
    }
};
 
pair<edge*, edge*> make_edge(ll a, ll b, ll c) {
    edge *eto = new edge(c, b);
    edge *efrom = new edge(0, a);
    eto->inv = efrom;
    efrom->inv = eto;
    return make_pair(eto, efrom);
}
 
bool find_flow(ll v, ll fin, ll nt, vector<ll>& used, vector<vector<edge*>>& to) {
    if (v == fin) {
        return true;
    }
    used[v] = nt;
    for (auto i : to[v]) {
        if (used[i->b] != nt && i->mf > 0) {
            if (find_flow(i->b, fin, nt, used, to)) {
                i->add(1);
                return true;
            }
        }
    }
    return false;
}
 
bool find_block(ll v, ll fin, vector<vector<edge*>>& to) {
    if (v == fin) {
        return true;
    }
    while (!to[v].empty()) {
        auto it = to[v].back();
        bool now = find_block(it->b, fin, to);
        to[v].pop_back();
        if (now) {
            it->add(1);
            return true;
        }
    }
    return false;
}
 
ll find_flow(ll st, ll fin, vector<vector<edge*>>& to) {
    ll n = to.size();
    queue<ll> q;
    vector<ll> dist(n, INF);
    dist[st] = 0;
    q.push(st);
    while (!q.empty()) {
        ll x = q.front();
        q.pop();
        for (auto i : to[x]) {
            if (i->mf != 0) {
                if (assign_min(dist[i->b], dist[x] + 1)) {
                    q.push(i->b);
                }
            }
        }
    }
    vector<vector<edge*>> ost(n);
    for (ll i = 0; i < n; i++) {
        for (auto j : to[i]) {
            if (j->mf != 0 && dist[j->b] == dist[i] + 1) {
                ost[i].push_back(j);
            }
        }
    }
    ll ans = 0;
    while (find_block(st, fin, ost)) {
        ans++;
    }
    return ans;
}
 
void dfs(ll v, ll p, vector<vector<ll>>& to, vector<ll>& h, vector<ll>& ps, vector<ll>& ts) {
    ts.push_back(v);
    ps[v] = p;
    h[v] = h[p] + 1;
    for (auto i : to[v]) {
        if (i != p) {
            dfs(i, v, to, h, ps, ts);
        }
    }
}
 
void solve() {
    ll n;
    cin >> n;
    ll d;
    cin >> d;
    vector<vector<ll>> to(n);
    for (ll i = 1; i < n; i++) {
        ll a, b;
        cin >> a >> b;
        a--;
        b--;
        to[a].push_back(b);
        to[b].push_back(a);
    }
    if (d == n - 1) {
        vector<ll> h(n, 0);
        vector<ll> p(n, 0);
        vector<ll> ts;
        dfs(0, 0, to, h, p, ts);
        vector<ll> fir, sec;
        for (ll i = 0; i < n; i++) {
            if (h[i] % 2) {
                fir.push_back(i);
            } else {
                sec.push_back(i);
            }
        }
        cout << min(fir.size(), sec.size()) << '\n';
        for (ll i = 0; i < fir.size() && i < sec.size(); i++) {
            cout << fir[i] + 1 << ' ' << sec[i] + 1 << '\n';
        }
        return;
    }
    if (d % 2 == 0) {
        d--;
    }
    ll lst = 0;
    ll ph = n;
    n = to.size();
    ll bans = 0;
    random_device rd;
    mt19937 rnd(rd());
    vector<ll> p(n, 0);
    vector<ll> ts;
    vector<ll> h(n, -1);
    dfs(lst, lst, to, h, p, ts);
    vector<vector<edge*>> all(n + 2 + n * (d + 1));
    for (ll i = 0; i < ph; i++) {
        if (h[i] % 2 == 0) {
            auto[a, b] = make_edge(n, i, 1);
            all[n].push_back(a);
            all[i].push_back(b);
        } else {
            auto[a, b] = make_edge(i, n + 1, 1);
            all[i].push_back(a);
            all[n + 1].push_back(b);
        }
    }
    for (ll i = 0; i < ph; i++) {
	ll now = i;
    	for (ll up = 0; up <= d; up++) {
            if (h[i] % 2 == 0) {
                auto[a, b] = make_edge(i, n + 2 + n * up + now, 1);
                all[i].push_back(a);
                all[n + 2 + n * up + now].push_back(b);
            } else {
                auto[a, b] = make_edge(n + 2 + n * (d - up) + now, i, 1);
                all[i].push_back(b);
                all[n + 2 + n * (d - up) + now].push_back(a);
            }
	    now = p[now];
        }
    }
    ll ans = 0;
    ll x = 0;
    while (x = find_flow(n, n + 1, all)) {
        ans += x;
    }
    cout << ans << '\n' << -1 << '\n';
}
 
int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    solve();
}
