#include <bits/stdc++.h>

using namespace std;

#ifndef LOCAL
#pragma GCC optimize("Ofast,no-stack-protector,unroll-loops")
#pragma GCC target("avx2,bmi,bmi2,popcnt,lzcnt,tune=native")
#endif

const int MAX_N = 2e5 + 4;
using ll = long long;

struct Node {
    ll x = 0, to_push = 0;
    bool should_zero = false;

    void push(ll y, bool zero, int l, int r) {
        if (zero) {
            x = 0;
            to_push = 0;
            should_zero = true;
        }
        x += y * (r - l + 1);
        to_push += y;
    }
};

Node unite(Node a, Node b) {
    return {a.x + b.x, 0};
}

struct SegTree {
    int len;
    Node tree[1 << 19];

    void init(int n) {
        len = __bit_ceil(n);
    }

    void push(int v, int l, int r) {
        if (l == r) return;
        int mid = (l + r) / 2;
        tree[v * 2].push(tree[v].to_push, tree[v].should_zero, l, mid);
        tree[v * 2 + 1].push(tree[v].to_push, tree[v].should_zero, mid + 1, r);
        tree[v].to_push = 0;
        tree[v].should_zero = false;
    }

    Node get(int l, int r, int v, int q_l, int q_r) {
        if (l > q_r || r < q_l || q_l > q_r) return {};
        if (q_l <= l && r <= q_r) return tree[v];
        push(v, l, r);
        int mid = (l + r) / 2;
        Node res1 = get(l, mid, v * 2, q_l, q_r);
        Node res2 = get(mid + 1, r, v * 2 + 1, q_l, q_r);
        return unite(res1, res2);
    }

    void add(int l, int r, int v, ll x, int q_l, int q_r) {
        if (l > q_r || r < q_l || q_l > q_r) return;
        if (q_l <= l && r <= q_r) {
            tree[v].push(x, false, l, r);
            return;
        }
        push(v, l, r);
        int mid = (l + r) / 2;
        add(l, mid, v * 2, x, q_l, q_r);
        add(mid + 1, r, v * 2 + 1, x, q_l, q_r);
        tree[v] = unite(tree[v * 2], tree[v * 2 + 1]);
    }

    void zero(int l, int r, int v, int q_l, int q_r) {
        if (l > q_r || r < q_l || q_l > q_r) return;
        if (q_l <= l && r <= q_r) {
            tree[v].push(0, true, l, r);
            return;
        }
        push(v, l, r);
        int mid = (l + r) / 2;
        zero(l, mid, v * 2, q_l, q_r);
        zero(mid + 1, r, v * 2 + 1, q_l, q_r);
        tree[v] = unite(tree[v * 2], tree[v * 2 + 1]);
    }
};

// struct SegTree {
//     int len;
//     vector<int> arr;
//
//     void init(int n) {
//         len = n;
//         arr.resize(len);
//     }
//
//     Node get(int l, int r, int v, int q_l, int q_r) {
//         int res = 0;
//         for (int i = q_l; i <= q_r; ++i) {
//             res += arr[i];
//         }
//         return {res};
//     }
//
//     void add(int l, int r, int v, ll x, int q_l, int q_r) {
//         for (int i = q_l; i <= q_r; ++i) {
//             arr[i] += x;
//         }
//     }
//
//     void zero(int l, int r, int v, int q_l, int q_r) {
//         for (int i = q_l; i <= q_r; ++i) {
//             arr[i] = 0;
//         }
//     }
// };

string arr[MAX_N];
int len[MAX_N];

SegTree tree;

void solve() {
    int n, m;
    cin >> n >> m;
    if (n <= m) {
        for (int i = 0; i < n; ++i) {
            getchar();
            arr[i].resize(m, '0');
            for (int j = 0; j < m; ++j) {
                arr[i][j] = getchar();
            }
        }
    } else {
        for (int i = 0; i < m; ++i) {
            arr[i].resize(n, '0');
        }
        for (int i = 0; i < n; ++i) {
            getchar();
            for (int j = 0; j < m; ++j) {
                arr[m - 1 - j][n - 1 - i] = getchar();
            }
        }
        swap(n, m);
    }
    tree.init(m + 1);
    ll ans = 0;
    for (int j1 = m - 1; j1 >= 0; --j1) {
        tree.zero(0, tree.len - 1, 1, 0, m);
        for (int i = 0; i < n; ++i) {
            if (arr[i][j1] == '1') {
                len[i]++;
            } else {
                len[i] = 0;
            }
            tree.add(0, tree.len - 1, 1, 1, 1, len[i]);
            tree.zero(0, tree.len - 1, 1, len[i] + 1, m);
            ll val = tree.get(0, tree.len - 1, 1, 0, m).x;
            ans = max(ans, val);
        }
    }
    cout << ans << "\n";
}

signed main() {
    // ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
#ifdef LOCAL
    freopen("../input.txt", "r", stdin);
#endif
    int tt = 1;
    // cin >> tt;
    while (tt--) {
        solve();
    }
}
