#include <bits/stdc++.h>

using namespace std;

typedef long long ll;

struct Segment {
    ll l, r, m;
};

bool cmp(const Segment &a, const Segment &b) {
    if (a.r == b.r) {
        return a.l > b.l;
    }
    return a.r < b.r;
}

bool pid(const Segment &a, const Segment &b) {
    return b.l <= a.m && a.m <= b.r && a.l <= b.m && b.m <= a.r;
}

constexpr ll inf = 1e15;

struct SegmentTree {
    vector<ll> tree;
    ll n;

    explicit SegmentTree(const ll n): n(n) {
        tree.assign(4 * n, inf);
    }

    void update(ll v, ll l, ll r, ll ind, ll val) {
        if (ind < l || r <= ind) {
            return;
        }
        if (l == r - 1) {
            tree[v] = val;
            return;
        }
        ll m = (l + r) / 2;
        update(2 * v + 1, l, m, ind, val);
        update(2 * v + 2, m, r, ind, val);
        tree[v] = min(tree[2 * v + 1], tree[2 * v + 2]);
    }

    void update(ll ind, ll val) {
        update(0, 0, n, ind, val);
    }

    ll get(ll v, ll l, ll r, ll ql, ll qr) {
        if (qr <= l || r <= ql) {
            return inf;
        }
        if (ql <= l && r <= qr) {
            return tree[v];
        }
        ll m = (l + r) / 2;
        ll x = get(2 * v + 1, l, m, ql, qr);
        ll y = get(2 * v + 2, m, r, ql, qr);
        return min(x, y);
    }

    ll get(ll ql, ll qr) {
        return get(0, 0, n, ql, qr);
    }
};

void solve() {
    ll n, k;
    cin >> n >> k;
    vector<Segment> a(k);
    for (ll i = 0; i < k; i++) {
        cin >> a[i].l >> a[i].m >> a[i].r;
    }
    sort(a.begin(), a.end(), cmp);
    vector<bool> dp(k);
    SegmentTree tree_r(k), tree_m(k);
    vector<ll> r(k);
    for (ll i = 0; i < k; i++) {
        r[i] = a[i].r;
    }
    for (ll i = 0; i < k; i++) {
        if (a[i].l == 1) {
            dp[i] = true;
            tree_r.update(i, a[i].r);
            tree_m.update(i, a[i].m);
            continue;
        }
        ll ind = lower_bound(r.begin(), r.end(), a[i].l - 1) - r.begin();
        if (ind == i) {
            continue;
        }
        if (tree_r.get(ind, i) < a[i].m) {
            dp[i] = true;
        }
        if (tree_m.get(ind, i) < a[i].l) {
            dp[i] = true;
        }
        if (dp[i]) {
            tree_r.update(i, a[i].r);
            tree_m.update(i, a[i].m);
        }
    }
    bool ans = false;
    for (ll i = 0; i < k; i++) {
        if (a[i].r == n) {
            ans = ans || dp[i];
        }
    }
    if (ans) {
        cout << "YES\n";
    } else {
        cout << "NO\n";
    }
}

int main() {
#ifdef DEBUG_Q
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
#endif
    ll t;
    cin >> t;
    while (t--) {
        solve();
    }
}
