#include <algorithm>
#include <array>
#include <cassert>
#include <iostream>
#include <vector>

using namespace std;


struct SegTree {
    vector<int> T;
    vector <int> pushed;
    SegTree(const size_t n) {
      T.resize(4 * n, 0);
      pushed.resize(4 * n, 0);
    }
    // ~SegTree() {
    //     T.clear();
    //     pushed.clear();
    //     cout << "DESTROYED" << endl;
    // }
    void push(int v, int L, int R) {
        if (R - L == 1) {
            T[v] = 1;
            pushed[v] = 0;
            return;
        }
      T[v] = (R - L);
      pushed[2 * v + 1] = 1;
      pushed[2 * v + 2] = 1;
      pushed[v] = 0;
    }

    void upd(int v, int L, int R, int pos, int val) {
        if (R - L == 1) {
            T[v] = val;
            return;
        }
        if (pushed[v]) push(v, L, R);
        int m = (L + R) / 2;
        if (m > pos) upd(2 * v + 1, L, m, pos, val);
        else upd(2 * v + 2, m, R, pos, val);
        T[v] = T[2 * v + 1] + T[2 * v + 2];
    }

    int get(int v, int L, int R, int l, int r) {
        if (pushed[v]) push(v, L, R);
        if (R <= l || r <= L) return 0;
        if (L >= l && R <= r) return T[v];
        int m = (L + R) / 2;
        return get(2 * v + 1, L, m, l, r) + get(2 * v + 2, m, R, l, r);
    }

    void set(int v, int L, int R, int l, int r) {
        if (pushed[v]) push(v, L, R);
        if (R <= l || r <= L) return;
        if (L >= l && R <= r) {
          pushed[v] = 1;
          return;
        }
        int m = (L + R) / 2;
        set(2 * v + 1, L, m, l, r);
        set(2 * v + 2, m, R, l, r);
        if (pushed[2 * v + 1]) push(2 * v + 1, L, m);
        if (pushed[2 * v + 2]) push(2 * v + 2, m, R);
        T[v] = T[2 * v + 1] + T[2 * v + 2];
    }
};

void solve() {
    int n, k; cin >> n >> k;
    vector <pair<int, int>> lr(k);
    vector <int> m(k);
    for (int i = 0; i < k; ++i) {
        cin >> lr[i].first >> m[i] >> lr[i].second;
        --m[i];
        --lr[i].first;
    }
    // vector <bool> a(n, false);
    SegTree a(n);
    bool res = true;
    for (int i = 0; i < k && res; ++i) {
        if (a.get(0, 0, n, m[i], m[i] + 1)) res = false;
        else {
            a.set(0, 0, n, lr[i].first, lr[i].second);
        }
    }
    int u = 0;
    for (int i = 0; i < k; ++i) u += a.get(0, 0, n, i, i + 1);
    assert(u == a.get(0, 0, n, 0, n));
    res = res && (a.get(0, 0, n, 0, n) == n);
    cout << (res ? "YES" : "NO") << "\n";
}

int main() {
    int Times;
    for (cin >> Times; Times--; solve()) {}
    return 0;
}