#include <algorithm>
#include <array>
#include <cassert>
#include <iostream>
#include <vector>

using namespace std;


struct SegTree {
    vector<int> T;
    vector <int> pushed;
    SegTree(const size_t n) {
      T.resize(4 * n, 0);
      pushed.resize(4 * n, 0);
    }
    // ~SegTree() {
    //     T.clear();
    //     pushed.clear();
    //     cout << "DESTROYED" << endl;
    // }
    void push(int v, int L, int R) {
        if (R - L == 1) {
            T[v] = 1;
            pushed[v] = 0;
            return;
        }
      T[v] = (R - L);
      pushed[2 * v + 1] = 1;
      pushed[2 * v + 2] = 1;
      pushed[v] = 0;
    }

    void upd(int v, int L, int R, int pos, int val) {
        if (R - L == 1) {
            T[v] = val;
            return;
        }
        if (pushed[v]) push(v, L, R);
        int m = (L + R) / 2;
        if (m > pos) upd(2 * v + 1, L, m, pos, val);
        else upd(2 * v + 2, m, R, pos, val);
        T[v] = T[2 * v + 1] + T[2 * v + 2];
    }

    int get(int v, int L, int R, int l, int r) {
        if (pushed[v]) push(v, L, R);
        if (R <= l || r <= L) return 0;
        if (L >= l && R <= r) return T[v];
        int m = (L + R) / 2;
        return get(2 * v + 1, L, m, l, r) + get(2 * v + 2, m, R, l, r);
    }

    void set(int v, int L, int R, int l, int r) {
        if (pushed[v]) push(v, L, R);
        if (R <= l || r <= L) return;
        if (L >= l && R <= r) {
          pushed[v] = 1;
          return;
        }
        int m = (L + R) / 2;
        set(2 * v + 1, L, m, l, r);
        set(2 * v + 2, m, R, l, r);
        if (pushed[v]) push(v, L, R);
        if (pushed[2 * v + 1]) push(2 * v + 1, L, m);
        if (pushed[2 * v + 2]) push(2 * v + 2, m, R);
        T[v] = T[2 * v + 1] + T[2 * v + 2];
    }
};

void solve() {
    int n, k; cin >> n >> k;
    vector <array<int, 3>> lr(k);
    for (int i = 0; i < k; ++i) {
        cin >> lr[i][0] >> lr[i][1] >> lr[i][2];
        --lr[i][1];
        --lr[i][0];
    }
    // vector <bool> a(n, false);
    sort(lr.begin(), lr.end(), [](array<int, 3> x, array<int, 3> y) {
      return x[1] >= y[0] && x[1] < y[2];
    });
    SegTree a(n);
    bool res = true;
    for (auto [l, m, r]: lr) {
        if (!res) break;
        if (a.get(0, 0, n, m, m + 1)) res = false;
        else {
            a.set(0, 0, n, l, r);
        }
    }
    res = res && (a.get(0, 0, n, 0, n) == n);

    cout << (res ? "YES" : "NO") << "\n";
}

int main() {
    int Times;
    for (cin >> Times; Times--; solve()) {}
    return 0;
}