#include <algorithm>
#include <array>
#include <cassert>
#include <iostream>
#include <vector>

using namespace std;


struct SegTree {
    vector<int> T;
    vector<int> pushed;

    SegTree(const size_t n) {
        T.resize(4 * n, 0);
        pushed.resize(4 * n, 0);
    }

    // ~SegTree() {
    //     T.clear();
    //     pushed.clear();
    //     cout << "DESTROYED" << endl;
    // }
    void push(int v, int L, int R) {
        if (R - L == 1) {
            T[v] = 1;
            pushed[v] = 0;
            return;
        }
        T[v] = (R - L);
        pushed[2 * v + 1] = 1;
        pushed[2 * v + 2] = 1;
        pushed[v] = 0;
    }

    void upd(int v, int L, int R, int pos, int val) {
        if (R - L == 1) {
            T[v] = val;
            return;
        }
        if (pushed[v]) push(v, L, R);
        int m = (L + R) / 2;
        if (m > pos) upd(2 * v + 1, L, m, pos, val);
        else upd(2 * v + 2, m, R, pos, val);
        T[v] = T[2 * v + 1] + T[2 * v + 2];
    }

    int get(int v, int L, int R, int l, int r) {
        if (pushed[v]) push(v, L, R);
        if (R <= l || r <= L) return 0;
        if (L >= l && R <= r) return T[v];
        int m = (L + R) / 2;
        return get(2 * v + 1, L, m, l, r) + get(2 * v + 2, m, R, l, r);
    }

    void set(int v, int L, int R, int l, int r) {
        if (pushed[v]) push(v, L, R);
        if (R <= l || r <= L) return;
        if (L >= l && R <= r) {
            pushed[v] = 1;
            return;
        }
        int m = (L + R) / 2;
        set(2 * v + 1, L, m, l, r);
        set(2 * v + 2, m, R, l, r);
        if (pushed[v]) push(v, L, R);
        if (pushed[2 * v + 1]) push(2 * v + 1, L, m);
        if (pushed[2 * v + 2]) push(2 * v + 2, m, R);
        T[v] = T[2 * v + 1] + T[2 * v + 2];
    }
};

void dfs(int v, vector<vector<int> > &gr, vector<int> &ts, vector<int> &used, int &err) {
    used[v] = 1;
    for (auto u: gr[v]) {
        if (used[u] == 1) {
            err = true;
            return;
        }
        if (!used[u]) dfs(u, gr, ts, used, err);
    }
    used[v] = 2;
    ts.push_back(v);
}

void solve() {
    int n, k;
    cin >> n >> k;
    vector<array<int, 3> > lr(k);
    for (int i = 0; i < k; ++i) {
        cin >> lr[i][0] >> lr[i][1] >> lr[i][2];
        --lr[i][1];
        --lr[i][0];
    }
    SegTree a(n);
    bool res = true;
    // vector <bool> a(n, false);
    vector<vector<int> > gr(k);
    vector<int> used(k, 0);
    vector<int> ts;
    int err = 0;
    {
        vector <array<int, 4>> slr(k);
        for (int i = 0; i < k; ++i) slr[i] = {lr[i][0], lr[i][1], lr[i][2], i};
        sort(slr.begin(), slr.end());
        for (int x = 0; x < k - 1; ++x) {
            int i = slr[x][3];
            int j = slr[x + 1][3];
            bool c1 = lr[i][1] >= lr[j][0] && lr[i][1] < lr[j][2];
            bool c2 = lr[j][1] >= lr[i][0] && lr[j][1] < lr[i][2];
            if (c1) gr[i].push_back(j);
            if (c2) gr[j].push_back(i);
            if (c1 && c2) {
                cout << "NO\n";
                return;
            }
        }
    }
    // for (int i = 0; i < k; ++i) {
    //     cout << i << '\t';
    //     for (auto u: gr[i]) cout << u << " ";
    //     cout << endl;
    // }
    for (int i = 0; i < k; ++i)
        if (!used[i])
            dfs(i, gr, ts, used, err);
    if (err) {
        cout << "NO\n";
        return;
    }
    reverse(ts.begin(), ts.end());
    // for (auto el: ts) cout << el << " ";
    // cout << endl;
    for (auto i: ts) {
        auto [l, m, r] = lr[i];
        if (!res) break;
        if (a.get(0, 0, n, m, m + 1)) res = false;
        else {
            a.set(0, 0, n, l, r);
        }
    }
    res = res && (a.get(0, 0, n, 0, n) == n);

    cout << (res ? "YES" : "NO") << "\n";
}

int main() {
    int Times;
    for (cin >> Times; Times--; solve()) {
    }
    return 0;
}
