#include "bits/extc++.h"

using namespace std;
using namespace __gnu_pbds;

template<class T>
using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;

template<class T>
istream &operator>>(istream &is, vector<T> &a) {
      for (T &elem: a) is >> elem;
      return is;
}

template<class T>
ostream &operator<<(ostream &os, vector<T> &a) {
      for (T &elem: a) os << elem << ' ';
      return (os << '\n');
}

#define int long long

struct seg {
      int l, m, r;
};

struct Node1 {
      int val;
      Node1(int val = 0) : val(val) {}
      friend Node1 operator+(Node1 &x, Node1 &y) {
            return {x.val + y.val};
      }
      void apply(int v) {
            val = max(val, v);
      }
};

struct Node2 {
      int val;
      Node2(int val = 0) : val(val) {}
      friend Node2 operator+(Node2 &x, Node2 &y) {
            return {max(x.val, y.val)};
      }
      void apply(int v) {
            val = v;
      }
};

template<typename Node>
struct Segtree {
      int size;
      vector<Node> tree;

      Segtree(int n) {
            size = 1;
            while (size < n) size <<= 1;
            tree.resize(size << 1);
      }

      Segtree(vector<int> &a) : Segtree(a.size()) {
            for (int i = 0; i < a.size(); ++i) tree[i] = a[i];
            for (int i = size - 1; i > 0; --i) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }

      Node get(int l, int r) {
            l += size, r += size - 1;
            Node lres, rres;
            while (l <= r) {
                  if (l & 1) lres = lres + tree[l++];
                  if (r & 1 ^ 1) rres = tree[r--] + rres;
                  l >>= 1, r >>= 1;
            }
            return lres + rres;
      }

      void set(int i, int v) {
            tree[i += size].apply(v);
            for (i >>= 1; i > 0; i >>= 1) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }
};

void solve() {
      int n, k;
      cin >> n >> k;
      vector<seg> a(k);
      for (auto &[l, m, r]: a) cin >> l >> m >> r;

      Segtree<Node1> st(n + 1);
      st.set(0, 1);

      Segtree<Node2> st2(n + 1);

      sort(a.begin(), a.end(), [&](auto x, auto y) {
            return x.r < y.r;
      });

      for (auto [l, m, r]: a) {
//            cout << l << ' ' << m << " " << r << endl;
            int val = min(1ll, st.get(l - 1, m).val);

            if (st2.get(0, l).val >= l - 1) {
                  val = 1;
            }

            st.set(r, val);
            if (val) {
                  st2.set(m, r);
            }
      }
//      for (int i = 0; i < n; ++i) {
//            cout << st.get(i + 1, i + 2) << ' ';
//      }
//      cout << endl;
//      for (int i = 0; i < n; ++i) {
//            cout << i + 1 << ' ';
//      }
      if (st.get(n, n + 1).val) {
            cout << "YES\n";
      } else {
            cout << "NO\n";
      }
}

signed main() {
#ifdef LOCAL
      freopen("input.txt", "r", stdin);
      freopen("output.txt", "w", stdout);
#else
      ios_base::sync_with_stdio(false);
      cin.tie(nullptr);
#endif
      int t;
      cin >> t;
      while (t--) solve();
}

