#include "bits/extc++.h"

using namespace std;
using namespace __gnu_pbds;

template<class T>
using ordered_set = tree<T, null_type, less < T>, rb_tree_tag, tree_order_statistics_node_update>;

template<class T>
istream &operator>>(istream &is, vector <T> &a) {
      for (T &elem: a) is >> elem;
      return is;
}

template<class T>
ostream &operator<<(ostream &os, vector <T> &a) {
      for (T &elem: a) os << elem << ' ';
      return (os << '\n');
}

#define int long long

struct seg {
      int l, m, r;
};

struct Node1 {
      int val;

      Node1(int val = 0) : val(val) {}

      friend Node1 operator+(Node1 &x, Node1 &y) {
            return {x.val + y.val};
      }

      void apply(int v) {
            val = max(val, v);
      }
};

struct Node2 {
      int val;

      Node2(int val = 0) : val(val) {}

      friend Node2 operator+(Node2 &x, Node2 &y) {
            return {max(x.val, y.val)};
      }

      void apply(int v) {
            val = v;
      }
};

template<typename Node>
struct Segtree {
      int size;
      vector <Node> tree;

      Segtree(int n) {
            size = 1;
            while (size < n) size <<= 1;
            tree.resize(size << 1);
      }

      Segtree(vector<int> &a) : Segtree(a.size()) {
            for (int i = 0; i < a.size(); ++i) tree[i] = a[i];
            for (int i = size - 1; i > 0; --i) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }

      Node get(int l, int r) {
            l += size, r += size - 1;
            Node lres, rres;
            while (l <= r) {
                  if (l & 1) lres = lres + tree[l++];
                  if (r & 1 ^ 1) rres = tree[r--] + rres;
                  l >>= 1, r >>= 1;
            }
            return lres + rres;
      }

      void set(int i, int v) {
            tree[i += size].apply(v);
            for (i >>= 1; i > 0; i >>= 1) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }
};

using i128 = __int128;

signed main() {
#ifdef LOCAL
      freopen("input.txt", "r", stdin);
      freopen("output.txt", "w", stdout);
#else
      ios_base::sync_with_stdio(false);
      cin.tie(nullptr);
#endif
      int n;
      cin >> n;
      vector<int> x(n);
      cin >> x;

//      cout << x;
      int x0, d;
      cin >> x0 >> d;
      x.push_back(x0);
      std::sort(x.begin(), x.end());
      n++;
      vector<int> ks(n);
      for (int i = 0; i < n; ++i) {
            int k1 = (x[i] - x0) / d;
            int dist = abs((x0 + k1 * d) - x[i]);
            ks[i] = k1;
            k1++;
            if (abs((x0 + k1 * d) - x[i]) < dist) ks[i] = k1, dist = abs((x0 + k1 * d) - x[i]);
            k1--, k1--;
            if (abs((x0 + k1 * d) - x[i]) < dist) ks[i] = k1, dist = abs((x0 + k1 * d) - x[i]);
      }

      auto get = [&](int lk, int rk, int t) {
            int res = (min(-lk, rk) - lk + rk) * t;
            for (int i =0 ; i < n; ++i) {
                  int pr = ks[i];
                  pr = max(pr, lk);
                  pr = min(pr, rk);
                  res += ((x0 + pr * d) - x[i]) * ((x0 + pr * d) - x[i]);
            }
            return res;
      };

      int q;
      cin >> q;
      vector <pair<int, int>> qs(q);
      for (int i = 0; i < q; ++i) {
            int t;
            cin >> t;

            int l = -1e9, r = 1e9;
            while (r - l > 5) {
                  int mid = (l + l + r) >> 1;
                  int mid2 = (l + r + r) >> 1;

                  if (get(mid, mid, t) < get(mid2, mid2, t)) r = mid2;
                  else l = mid;
            }

            int res = 1e18;
            for (int j = l; j <= r; ++j) {
                  res = max(res, get(j, j, t));
            }
            cout << res << endl;
      }

//      sort(qs.begin(), qs.end(), [&](auto a, auto b) {
//            return a.first > b.first;
//      });
//
//      vector<i128> s_sq(n), p_sq(n), s(n), p(n);
//      for (int i = 0; i < n; ++i) {
//            if (i) p_sq[i] += p_sq[i - 1], p[i] += p[i - 1];
//            p_sq[i] += x[i] * x[i], p[i] += x[i];
//      }
//
//      for (int i = n - 1; i >= 0; --i) {
//            if (i + 1 < n) s_sq[i] += s_sq[i + 1], s[i] += s[i + 1];
//            s_sq[i] += x[i] * x[i], s[i] += x[i];
//      }
//
//      vector<int> cost(n);
//      for (int i = 0; i < n; ++i) {
//            cost[i] = ((x0 + ks[i] * d) - x[i]) * ((x0 + ks[i] * d) - x[i]);
//      }
//
//      vector<int> pc(n);
//      for (int i = 0; i < n; ++i) {
//            if (i) pc[i] += pc[i - 1];
//            pc[i] += cost[i];
//      }
////      cout << pc.back();
//      auto get = [&](int lk, int rk, int t) {
//            i128 res = (min(-lk, rk) - lk + rk) * t;
//            for (int i =0 ; i < n; ++i) {
//                  int pr = ks[i];
//                  pr = max(pr, lk);
//                  pr = min(pr, rk);
//                  res += ((x0 + pr * d) - x[i]) * ((x0 + pr * d) - x[i]);
//            }
//            return res;
//      };
//
//
////      cout << ks;
//      vector<int> ans(q);
////      int C = lower_bound(ks.begin(), ks.end(), 0ll) - ks.begin();
////      for (auto [t, id]: qs) {
////
////            i128 now = 1e18;
////            for (int lk = ks[0]; lk <= 0; ++lk) {
////                  for (int rk = 0; rk <= ks.back(); ++rk) {
////                        now = min(now, get(lk, rk, t));
////                  }
////            }
////
////            ans[id] = now;
////      }
//
////      cout << ans;
}

