#include "bits/extc++.h"

using namespace std;
using namespace __gnu_pbds;

template<class T>
using ordered_set = tree<T, null_type, less < T>, rb_tree_tag, tree_order_statistics_node_update>;

template<class T>
istream &operator>>(istream &is, vector <T> &a) {
      for (T &elem: a) is >> elem;
      return is;
}

template<class T>
ostream &operator<<(ostream &os, vector <T> &a) {
      for (T &elem: a) os << elem << ' ';
      return (os << '\n');
}

#define int long long

struct seg {
      int l, m, r;
};

struct Node1 {
      int val;

      Node1(int val = 0) : val(val) {}

      friend Node1 operator+(Node1 &x, Node1 &y) {
            return {x.val + y.val};
      }

      void apply(int v) {
            val = max(val, v);
      }
};

struct Node2 {
      int val;

      Node2(int val = 0) : val(val) {}

      friend Node2 operator+(Node2 &x, Node2 &y) {
            return {max(x.val, y.val)};
      }

      void apply(int v) {
            val = v;
      }
};

template<typename Node>
struct Segtree {
      int size;
      vector <Node> tree;

      Segtree(int n) {
            size = 1;
            while (size < n) size <<= 1;
            tree.resize(size << 1);
      }

      Segtree(vector<int> &a) : Segtree(a.size()) {
            for (int i = 0; i < a.size(); ++i) tree[i] = a[i];
            for (int i = size - 1; i > 0; --i) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }

      Node get(int l, int r) {
            l += size, r += size - 1;
            Node lres, rres;
            while (l <= r) {
                  if (l & 1) lres = lres + tree[l++];
                  if (r & 1 ^ 1) rres = tree[r--] + rres;
                  l >>= 1, r >>= 1;
            }
            return lres + rres;
      }

      void set(int i, int v) {
            tree[i += size].apply(v);
            for (i >>= 1; i > 0; i >>= 1) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }
};

using i128 = __int128;

signed main() {
#ifdef LOCAL
      freopen("input.txt", "r", stdin);
      freopen("output.txt", "w", stdout);
#else
      ios_base::sync_with_stdio(false);
      cin.tie(nullptr);
#endif
      int n, d;
      cin >> n >> d;
      vector<int> g[n];
      for (int i = 1; i < n; ++i) {
            int u, v;
            cin >> u >> v;
            u--, v--;
            g[u].push_back(v), g[v].push_back(u);
      }

      vector<int> dist(n);
      function<void(int, int)> dfs1 = [&](int u, int p) {
            for (int v: g[u]) {
                  if (v == p) continue;
                  dist[v] = dist[u] + 1;
                  dfs1(v, u);
            }
      };

      vector<int> g1[n];
      for (int i = 0; i < n; ++i) {
            vector<int> d2(n, 1e9);
            d2[i] = 0;
            queue<int> q;
            q.push(i);
            while (!q.empty()) {
                  int u = q.front();
                  q.pop();

                  if (d2[u] + 1 <= d) {
                        for (int v: g[u]) {
                              if (d2[v] > d2[u] + 1) {
                                    d2[v] = d2[u] + 1;
                                    q.push(v);
                              }
                        }
                  }
            }

            for (int j = 0; j < n; ++j) {
                  if (d2[j] % 2 == 1) {
                        g1[i].push_back(j);
                  }
            }
      }

      vector<int> used(n, -1);
      vector<int> match(n, -1);
      int tm = 0;
      function<bool(int)> dfs = [&](int u) {
            used[u] = tm;
            for (int v: g1[u]) {
                  if (match[v] == -1) {
                        match[v] = u;
                        return true;
                  }
            }
            for (int v: g1[u]) {
                  if (used[match[v]] != tm and dfs(match[v])) {
                        match[v] = u;
                        return true;
                  }
            }
            return false;
      };
      dfs1(0, -1);
      int res =0 ;
      for (int i = 0; i < n; ++i) {
            if (dist[i] % 2) {
                  res += dfs(i);
                  tm++;
            }
      }
      cout << res << endl;
      for (int i = 0; i < n; ++i) {
            if (match[i] != -1) cout << i + 1 << ' ' << match[i] + 1 << endl;
      }
}

