#include <iostream>
#include <string>
#include <vector>
#include <cmath>
#include <set>
#include <map>
#include <algorithm>
#include <random>
#include <array>
#include <iomanip>
#include <queue>
using namespace std;
typedef long long ll;
typedef long double ld;
#define all(a) a.begin(), a.end()
#ifdef _DEBUG
#define int128 ll
#else
#define int128 __int128
#endif
const ll INF = 1e18, MOD = 1e9 + 7, N = 3e5 + 20;
const ld EPS = 1e-9;
ll n, d, c[N];
vector<ll> g[N];
void coloring(ll v, ll p) {
	for (ll u : g[v]) {
		if (u != p) {
			c[u] = 1 - c[v];
			coloring(u, v);
		}
	}
}
struct Flow {
	ll n, s, t;
	vector<ll> f, c;
	vector<ll> us; ll usnow;
	vector<vector<array<ll, 2>>> g;
	void addedge(ll u, ll v, ll cap) {
		ll i = f.size();
		g[u].push_back({ v, i });
		f.push_back(0);
		c.push_back(cap);
		i = f.size();
		g[v].push_back({ u, i });
		f.push_back(0);
		c.push_back(0);
	}
	Flow(vector<vector<pair<ll, ll>>>& g_, ll s_, ll t_) {
		n = g_.size();
		us.resize(n, 0);
		g.resize(n);
		usnow = 0;
		s = s_, t = t_;
		for (ll v = 0; v < n; v++) {
			for (auto u : g_[v]) {
				addedge(v, u.first, u.second);
			}
		}
	}
	vector<ll> d;
	bool bfs() {
		d.assign(n, n + 10);
		queue<ll> que;
		que.push(s);
		d[s] = 0;
		while (que.size() > 0) {
			ll v = que.front();
			que.pop();
			for (auto p : g[v]) {
				ll u = p[0], i = p[1];
				if (f[i] < c[i]) {
					if (d[u] > d[v] + 1) {
						d[u] = d[v] + 1;
						que.push(u);
					}
				}
			}
		}
		return (d[t] <= n);
	}
	bool dfs(ll v) {
		us[v] = usnow;
		if (v == t) return 1;
		for (auto p : g[v]) {
			ll u = p[0], i = p[1];
			if (d[u] == d[v] + 1 && f[i] < c[i] && us[u] < usnow) {
				if (dfs(u)) {
					f[i]++;
					f[i ^ 1]--;
					return 1;
				}
			}
		}
		return 0;
	}
	ll make() {
		ll ans = 0;
		usnow = 1;
		while (bfs()) {
			while (dfs(s)) {
				ans++;
				usnow++;
			}
			usnow++;
		}
		return ans;
	}
	ll find(ll v) {
		us[v] = usnow;
		for (auto p : g[v]) {
			ll u = p[0], i = p[1];
			if (f[i] >= 1) {
				f[i]--;
				if (u == t) return v;
				return find(u);
			}
		}
	}
	vector<pair<ll, ll>> vost() {
		vector<pair<ll, ll>> ans;
		usnow++;
		for (auto p : g[s]) {
			ll u = p[0], i = p[1];
			if (f[i] == 1) {
				ans.push_back({ u, find(u) });
			}
		}
		return ans;
	}
};
ll dp[N][2]{};
void calc(ll v, ll p) {
	dp[v][0] = 0, dp[v][1] = 0;
	ll mnd = n;
	for (ll u : g[v]) {
		if (u == p) continue;
		calc(u, v);
		dp[v][0] += dp[u][1];
		mnd = min(mnd, dp[u][1] - dp[u][0]);
	}
	dp[v][1] = max(dp[v][0], dp[v][0] - mnd + 1);
}
void vost(ll v, ll p, ll c) {
	if (dp[v][c] == dp[v][0]) {
		for (ll u : g[v]) {
			if (u != p) {
				vost(u, v, 1);
			}
		}
	}
	else {
		ll w = -1, mnd = n;
		for (ll u : g[v]) {
			if (u != p) {
				if (dp[u][1] - dp[u][0] < mnd) {
					w = u;
					mnd = dp[u][1] - dp[u][0];
				}
			}
		}
		cout << v + 1 << " " << w + 1 << "\n";
		for (ll u : g[v]) {
			if (u != p) {
				if (u == w) vost(u, v, 0);
				else vost(u, v, 1);
			}
		}
	}
}
int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cin >> n >> d;
	for (ll i = 0; i < n - 1; i++) {
		ll u, v;
		cin >> u >> v;
		u--; v--;
		g[u].push_back(v);
		g[v].push_back(u);
	}
	c[0] = 0;
	coloring(0, 0);
	ll m = (d + 1) / 2; // [0, m)
	vector<vector<pair<ll, ll>>> gf(n * m + 2);
	ll s = gf.size() - 2, t = gf.size() - 1;
	for (ll v = 0; v < n; v++) {
		if (c[v] == 0) {
			gf[s].push_back({ v * m + m - 1, 1 });
			for (ll x = 0; x < m; x++) {
				for (ll u : g[v]) {
					gf[v * m + x].push_back({ u * m + x, n });
				}
			}
		}
		else {
			gf[v * m].push_back({ t, 1 });
			for (ll x = 1; x < m; x++) {
				for (ll u : g[v]) {
					gf[v * m + x].push_back({ u * m + x - 1, n });
				}
			}
		}
	}
	Flow f = Flow(gf, s, t);
	cout << f.make() << "\n";
	vector<pair<ll, ll>> vost = f.vost();
	for (ll i = 0; i < vost.size(); i++) {
		cout << vost[i].first / m + 1 << " " << vost[i].second / m + 1 << "\n";
	}
	return 0;
}