// #pragma GCC optimize("O3")

#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <random>
#include <cmath>

#define all(a) a.begin(), a.end()

using namespace std;
using ll = long long;
using ull = unsigned long long;
using pii = pair<int, int>;
using pll = pair<ll, ll>;

int n, d, lg, timer = 0;
vector<vector<int>> tree, g;
vector<int> z, v, p;
vector<vector<int>> binup;
vector<int> h, used;

void dfs(int id, int pr, bool f) {
    if (f) z.push_back(id);
    else v.push_back(id);
    for (int const &e : tree[id]) {
        if (e != pr) {
            h[e] = h[id] + 1;
            binup[0][e] = id;
            dfs(e, id, not f);
        }
    }
}

int get_dist(int a, int b) {
    if (h[a] > h[b]) swap(a, b);
    int d = h[a] + h[b];
    for (int i = lg - 1; i >= 0; --i) {
        if (h[b] - (1 << i) >= h[a]) {
            b = binup[i][b];
        }
    }

    if (a == b) return d - h[a] - h[a];

    for (int i = lg - 1; i >= 0; --i) {
        if (binup[i][a] != binup[i][b]) {
            a = binup[i][a];
            b = binup[i][b];
        }
    }

    return d - h[binup[0][a]] * 2;
}

bool kuhn(int id) {
    if (used[id] == timer) return false;
    used[id] = timer;
    for (int const &e : g[id]) {
        if (p[e] == -1) {
            p[e] = id;
            return true;
        }
    }
    for (int const &e : g[id]) {
        if (kuhn(p[e])) {
            p[e] = id;
            return true;
        }
    }

    return false;
}

void solve() {
    cin >> n >> d;
    tree.resize(n);
    h.resize(n);
    lg = __lg(n) + 1;
    binup.resize(lg, vector<int>(n));
    int a, b;
    for (int i = 1; i < n; ++i) {
        cin >> a >> b;
        tree[a - 1].push_back(b - 1);
        tree[b - 1].push_back(a - 1);
    }

    dfs(0, -1, true);

    for (int i = 1; i < lg; ++i) {
        for (int j = 0; j < n; ++j) {
            binup[i][j] = binup[i - 1][binup[i - 1][j]];
        }
    }

    sort(all(z));
    sort(all(v));
    g.resize(z.size());
    p.resize(v.size(), -1);

    for (int i = 0; i < z.size(); ++i) {
        for (int j = 0; j < v.size(); ++j) {
            if (get_dist(z[i], v[j]) <= d) {
                g[i].push_back(j);
            }
        }
    }

    used.resize(z.size(), -1);
    for (int i = 0; i < z.size(); ++i) {
        timer++;
        kuhn(i);
    }

    vector<pii> ans;
    for (int i = 0; i < v.size(); ++i) {
        if (p[i] != -1) {
            ans.emplace_back(z[p[i]], v[i]);
        }
    }

    cout << ans.size() << '\n';
    for (auto const &p : ans) cout << p.first + 1 << ' ' << p.second + 1 << '\n';
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    solve();
}