// Created by rost on 27.03.25.

#pragma GCC optimize("Ofast")
#pragma GCC target("avx2")
#pragma GCC optimize("unroll-loops")

#include <bits/stdc++.h>

using ll = long long;
using ld = long double;
using namespace std;

const int INF = 1e9 + 7;

struct Worker {
    int m;
    int l, r;
};

const int MAX_N = 5e5;

class SegmentTree {
private:
    struct Vertex {
        pair<int, int> val;
        pair<int, int> push;
        bool forcePush = false;

        Vertex() : val({INF, INF}), push({INF, INF}) {
        }
    };

    Vertex merge(const Vertex &a, const Vertex &b) {
        Vertex res;
        if (a.val < b.val)
            res.val = a.val;
        else
            res.val = b.val;
        return res;
    }

    const int N;
    vector<Vertex> tree;

    inline void push(int v) {
        if (tree[v].forcePush) {
            tree[2 * v + 1].val = {INF, INF};
            tree[2 * v + 1].push = {INF, INF};
            tree[2 * v + 1].forcePush = true;
            tree[2 * v + 2].val = {INF, INF};
            tree[2 * v + 2].push = {INF, INF};
            tree[2 * v + 2].forcePush = true;
            tree[v].forcePush = false;
            return;
        }

        if (tree[v].push == make_pair(INF, INF))
            return;

        tree[2 * v + 1].val = min(tree[2 * v + 1].val, tree[v].push);
        tree[2 * v + 1].push = min(tree[2 * v + 1].push, tree[v].push);
        tree[2 * v + 2].val = min(tree[2 * v + 2].val, tree[v].push);
        tree[2 * v + 2].push = min(tree[2 * v + 2].push, tree[v].push);
        tree[v].push = {INF, INF};
    }

    Vertex tree_get(int v, int tl, int tr, int ql, int qr) {
        if (qr <= tl || tr <= ql) return {};
        if (ql <= tl && tr <= qr) return tree[v];

        push(v);

        int tm = (tl + tr) / 2;
        return merge(tree_get(2 * v + 1, tl, tm, ql, qr),
                     tree_get(2 * v + 2, tm, tr, ql, qr));
    }

    void tree_upd(int v, int tl, int tr, int qp, pair<int, int> qx) {
        if (tl + 1 == tr) {
            tree[v].val = min(tree[v].val, qx);
            return;
        }

        push(v);

        int tm = (tl + tr) / 2;
        if (qp < tm) {
            tree_upd(2 * v + 1, tl, tm, qp, qx);
        } else {
            tree_upd(2 * v + 2, tm, tr, qp, qx);
        }
        tree[v] = merge(tree[2 * v + 1], tree[2 * v + 2]);
    }

    void tree_upd(int v, int tl, int tr, int ql, int qr, pair<int, int> qx) {
        if (qr <= tl || tr <= ql) return;
        if (ql <= tl && tr <= qr) {
            tree[v].val = min(tree[v].val, qx);
            tree[v].push = min(tree[v].push, qx);
            return;
        }

        push(v);

        int tm = (tl + tr) / 2;
        tree_upd(2 * v + 1, tl, tm, ql, qr, qx);
        tree_upd(2 * v + 2, tm, tr, ql, qr, qx);
        tree[v] = merge(tree[2 * v + 1], tree[2 * v + 2]);
    }

public:
    SegmentTree(int n) : N(n), tree(4 * N) {
    }

    pair<int, int> get(int l, int r) {
        return tree_get(0, 0, N, l, r).val;
    }

    void upd(int pos, pair<int, int> val) {
        tree_upd(0, 0, N, pos, val);
    }

    void upd(int l, int r, pair<int, int> val) {
        tree_upd(0, 0, N, l, r, val);
    }

    void clear() {
        tree[0].val = {INF, INF};
        tree[0].push = {INF, INF};
        tree[0].forcePush = true;
    }
};

const int MAX_K = 5e5;

Worker workers[MAX_K];
// SegmentTree minR(MAX_N + 1), minM(MAX_N + 1);

void solve() {
    int n, k;
    cin >> n >> k;
    for (int i = 0; i < k; ++i)
        cin >> workers[i].l >> workers[i].m >> workers[i].r;
    sort(workers, workers + k, [](const Worker &a, const Worker &b) -> bool {
        return a.m < b.m;
    });

    SegmentTree minR(n + 1), minM(n + 1);

    minR.upd(0, {-1, -1});
    minM.upd(0, {-1, -1});

    // for (int i = 0; i <= n; ++i)
        // cerr << minR.get(i, i + 1).first << ' ';
    // cerr << '\n';
    // for (int i = 0; i <= n; ++i)
        // cerr << minM.get(i, i + 1).first << ' ';
    // cerr << '\n';

    for (auto [m, l, r]: workers) {
        auto r1 = minR.get(l - 1, m);
        auto r2 = minM.get(l - 1, m);

        if (r1.first < m) {
            minR.upd(l, r + 1, {r, -1});
            minM.upd(l, r + 1, {m, r});
        }

        if (r2.first < l && r2.second < r) {
            minR.upd(r2.second + 1, r + 1, {r, -1});
            minM.upd(r2.second + 1, r + 1, {m, r});
        }
    }

    if (minR.get(n, n + 1).first != INF || minM.get(n, n + 1).first != INF) {
        cout << "YES\n";
    } else {
        cout << "NO\n";
    }
    // minR.clear();
    // minM.clear();
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

#ifdef LOCAL
    freopen("in.in", "r", stdin);
    freopen("out.out", "w", stdout);
#endif

    int t;
    cin >> t;
    while (t--)
        solve();
}
