#include <iostream>
#include <vector>
#include <deque>
#include <algorithm>

using namespace std;

typedef long long ll;

struct Item
{
	int st;
	int fn;
	int mid;

	bool operator<(const Item& it) const
	{
		if (fn == it.fn)
		{
			if (mid == it.mid)
				return st < it.st;
			return mid < it.mid;
		}
		return fn < it.fn;
	}
};

class SegmentTree
{
public:
	SegmentTree(int n) : tree(n * 4) {}

	int get(int v, int l, int r, int ql, int qr)
	{
		if (ql >= r || qr <= l)
			return 0;
		if (ql <= l && r <= qr)
			return tree[v].max;
		int m = (l + r) / 2;
		return max(get(v * 2 + 1, l, m, ql, qr), get(v * 2 + 2, m, r, ql, qr));
	}

	void set(int v, int l, int r, int p, int x)
	{
		if (p >= r || p < l)
			return;
		if (l + 1 == r)
		{
			tree[v].max = x;
			return;
		}
		int m = (l + r) / 2;
		set(v * 2 + 1, l, m, p, x);
		set(v * 2 + 2, m, r, p, x);
		tree[v].max = max(tree[v * 2 + 1].max, tree[v * 2 + 2].max);
	}

private:
	struct Node
	{
		int max = 0;
	};

	vector<Node> tree;
};

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	int tt;
	cin >> tt;
	for (int t = 0; t < tt; ++t)
	{
		int n, k;
		cin >> n >> k;
		vector<int> dp(n + 1);
		vector<Item> a(k);
		for (int i = 0; i < k; ++i)
			cin >> a[i].st >> a[i].mid >> a[i].fn;
		vector<vector<int>> ends(n + 1);
		for (int i = 0; i < k; ++i)
			ends[a[i].fn].push_back(i);
		SegmentTree tree(n + 1);
		for (int i = 1; i <= n; ++i)
		{
			dp[i] = dp[i - 1];
			for (int j : ends[i])
			{
				if (dp[a[j].mid - 1] >= a[j].st - 1)
				{
					dp[i] = i;
					tree.set(0, 0, n + 1, a[j].mid, i);
				}
				else if (tree.get(0, 0, n + 1, 0, a[j].st) >= a[j].st - 1)
				{
					dp[i] = i;
					tree.set(0, 0, n + 1, a[j].mid, i);
				}
			}
		}
		if (dp[n] == n)
			cout << "YES\n";
		else
			cout << "NO\n";
	}
	return 0;
}
