#include <iostream>
#include <vector>
#include <deque>
#include <algorithm>

using namespace std;

typedef long long ll;
typedef __int128 i128;

struct Line {
    i128 k;
    i128 b;

    Line() : k(0), b(0) {}
    Line(i128 _k, i128 _b) : k(_k), b(_b) {}

    bool operator<(const Line& l) const {
        if (k == l.k)
            return b < l.b;
        return k > l.k;
    }

    i128 get(i128 x) {
        return x * k + b;
    }
};

class CHT
{
public:
    void add(i128 k, i128 b)
    {
        lines.emplace_back(k, b);
    }

    void compute()
    {
        sort(lines.begin(), lines.end());
        for (int i = 0; i < lines.size(); ++i) {
            if (i > 0 && lines[i].k == lines[i - 1].k)
                continue;
            while (!points.empty() && bett(lines[i], end_lines.back(), points.back())) {
                end_lines.pop_back();
                points.pop_back();
            }
            if (!end_lines.empty()) {
                points.push_back(inter(lines[i], end_lines.back()));
            }
            end_lines.push_back(lines[i]);
        }
    }

    Line get(i128 point) {
        while (ans_ind < points.size() && point >= points[ans_ind])
            ++ans_ind;
        return end_lines[ans_ind];
    }

private:

    vector<Line> lines;
    vector<i128> points;
    vector<Line> end_lines;
    int ans_ind = 0;

    i128 inter(Line& a, Line& b) {
        if (a.k == b.k) {
            throw(0);
        }
		i128 res = (b.b - a.b) / (a.k - b.k);
		if (a.get(res) > b.get(res))
		{
			if (res >= 0)
				return res + 1;
			else
				return res - 1;
		}
		return res;
    }

    bool bett(Line& a, Line& b, i128 point) {
        if (a.k == b.k) {
            return a.b < b.b;
        }
        i128 ter = inter(a, b);
        return ter <= point;
    }
};

void generate_lines(int x0ind, ll d, vector<ll>& base, ll& x0, vector<ll>& x, CHT& cht1, CHT& cht2) {
    int xind = 0;
    while (xind != x.size() && x[xind] < x0)
        ++xind;
    int start_xind = xind;
    i128 summ_right2 = 0;
    i128 summ_right = 0;
    i128 summ_norm = 0;
    for (int i = xind; i < x.size(); ++i) {
        summ_right += x[i];
        summ_right2 += i128(x[i] - x0) * i128(x[i] - x0);
    }
    for (int i = x0ind; i < base.size(); ++i) {
        if (i != x0ind) {
            summ_right2 -= (i128(base[i - 1]) * base[i - 1]) * (x.size() - xind);
            summ_right2 += (i128(base[i]) * base[i]) * (x.size() - xind);
            summ_right2 -= 2 * i128(summ_right) * d;
        }
        while (xind != x.size() && x[xind] < base[i]) {
            if (i > x0ind) {
                summ_norm += min(base[i] - x[xind], x[xind] - base[i - 1]) * min(base[i] - x[xind], x[xind] - base[i - 1]);
            }
            summ_right2 -= i128(x[xind] - base[i]) * i128(x[xind] - base[i]);
            summ_right -= x[xind];
            ++xind;
        }

        cht1.add(i - x0ind, summ_right2 + summ_norm);
        cht2.add((i - x0ind) * 2, summ_right2 + summ_norm);
    }
}


int main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int n;
    cin >> n;
    vector<ll> x(n);
    for (int i = 0; i < n; ++i)
        cin >> x[i];
    sort(x.begin(), x.end());
    ll x0, d;
    cin >> x0 >> d;
    vector<ll> base(1);
    base[0] = x0;
    while (base.back() >= x[0]) {
        base.push_back(base.back() - d);
    }
    int x0ind = base.size() - 1;
    reverse(base.begin(), base.end());
    while (base.back() <= x.back()) {
        base.push_back(base.back() + d);
    }
    CHT right1, right2;
    generate_lines(x0ind, d, base, x0, x, right1, right2);
    reverse(base.begin(), base.end());
    reverse(x.begin(), x.end());
    x0ind = base.size() - x0ind - 1;
    ll newst = base[0];
    x0 = newst - x0;
    for (int i = 0; i < x.size(); ++i)
        x[i] = newst - x[i];
    for (int i = 0; i < base.size(); ++i)
        base[i] = newst - base[i];
    CHT left1, left2;
    generate_lines(x0ind, d, base, x0, x, left1, left2);
    right1.compute();
    right2.compute();
    left1.compute();
    left2.compute();
    int m;
    cin >> m;
    vector<pair<ll, int>> q(m);
    for (int i = 0; i < m; ++i) {
        cin >> q[i].first;
        q[i].second = i;
    }
    sort(q.begin(), q.end());
    vector<ll> result(m);
    for (int i = 0; i < m; ++i) {
        result[q[i].second] = min(right1.get(q[i].first).get(q[i].first) + left2.get(q[i].first).get(q[i].first), right2.get(q[i].first).get(q[i].first) + left1.get(q[i].first).get(q[i].first));
    }
    for (int i = 0; i < m; ++i)
        cout << result[i] << '\n';
    return 0;
}
