// olymp.cpp : This file contains the 'main' function. Program execution begins and ends there.
//

#include <iostream>
#include <vector>
#include <algorithm>

#include <cstdint>
struct node_t {

	int node = 0;
	int lazy_add = 0;
	bool lazy_set = false;
};
struct seg_tree {
	std::vector<node_t> nodes;
	int ext_size;

	seg_tree(int size) {
		ext_size = 1;
		while (ext_size < size)
		{
			ext_size *= 2;
		}
		nodes.resize(ext_size * 2);
	}
	void add_lazy(int node, int x, int size) {
		nodes[node].lazy_add += x;
		nodes[node].node += x * size;
	}
	void set_lazy(int node) {
		nodes[node].lazy_set = true;
		nodes[node].lazy_add = 0;
		nodes[node].node = 0;
	}
	void push(int node, int size) {
		if (nodes[node].lazy_set) {
			set_lazy(node * 2);
			set_lazy(node * 2 + 1);
			nodes[node].lazy_set = false;
		}
		if (nodes[node].lazy_add) {
			add_lazy(node * 2, nodes[node].lazy_add, size / 2);
			add_lazy(node * 2 + 1, nodes[node].lazy_add, size / 2);

			nodes[node].lazy_add = 0;
		}
	}
	void set(int l, int r, int node, int nl, int nr) {
		if (r < nl || nr < l)
			return;
		if (l <= nl && nr <= r) {
			set_lazy(node);
			return;
		}
		push(node, nr - nl + 1);
		int mid = (nl + nr) / 2;
		set(l, r, node * 2, nl, mid);
		set(l, r, node * 2 + 1, mid + 1, nr);
		nodes[node].node = nodes[node * 2].node + nodes[node * 2 + 1].node;

	}
	int add(int l, int r, int x, int node, int nl, int nr) {
		if (r < nl || nr < l)
			return 0;
		if (l <= nl && nr <= r) {
			add_lazy(node, x, nr - nl + 1);
			return nodes[node].node;
		}
		push(node, nr - nl + 1);
		int mid = (nl + nr) / 2;
		int result =
			add(l, r, x, node * 2, nl, mid) +
			add(l, r, x, node * 2 + 1, mid + 1, nr);
		nodes[node].node = nodes[node * 2].node + nodes[node * 2 + 1].node;
		return result;

	}
	int get(int l, int r, int node, int nl, int nr) {
		if (r < nl || nr < l)
			return 0;
		if (l <= nl && nr <= r)
			return nodes[node].node;
		push(node, nr - nl + 1);
		int mid = (nl + nr) / 2;
		return
			get(l, r, node * 2, nl, mid) +
			get(l, r, node * 2 + 1, mid + 1, nr);

	}
};
using namespace std;

struct employee {
	int l;
	int m;
	int r;
	bool operator<(const employee& other) const {
		if (l != other.l)
			return l < other.l;
		if (m != other.m)
			return m < other.m;
		return r < other.r;
	}
};
void test() {
	int n, k;
	cin >> n >> k;


	std::vector<employee> group;


	for (int i = 0; i < k; i++) {
		employee t;
		std::cin >> t.l >> t.m >> t.r;
		group.push_back(t);
	}

	int fact = 1;
	for (int i = 1; i <= k; i++)
		fact *= i;
	for (int j = 0; j < fact; j++, prev_permutation(group.begin(), group.end())) {
		seg_tree tree(n+1);
		tree.add(1, n, 1, 1, 0, tree.ext_size - 1);
		for (auto e : group) {
			if (tree.get(e.m, e.m, 1, 0, tree.ext_size - 1))
				tree.set(e.l, e.r, 1, 0, tree.ext_size - 1);
		}
		if (tree.get(1, n, 1, 0, tree.ext_size - 1) == 0) {
			std::cout << "YES\n";
			return;
		}
	}
	std::cout << "NO\n";
	return;


}
int main()
{
	int t;
	cin >> t;
	for (int i = 0; i < t; i++)
	{
		test();
	}
}

// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
// Debug program: F5 or Debug > Start Debugging menu

// Tips for Getting Started: 
//   1. Use the Solution Explorer window to add/manage files
//   2. Use the Team Explorer window to connect to source control
//   3. Use the Output window to see build output and other messages
//   4. Use the Error List window to view errors
//   5. Go to Project > Add New Item to create new code files, or Project > Add Existing Item to add existing code files to the project
//   6. In the future, to open this project again, go to File > Open > Project and select the .sln file
