#ifdef LOCAL
#define _GLIBCXX_DEBUG
#endif // LOCAL

#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>

using namespace std;

using ll = long long;
using ui = unsigned int;
using ull = unsigned long long;

#define szof(x) (int)x.size()

struct Segment_tree {
    int sz, mx;
    vector<int> st;
    void init(int n, int x) {
        sz = 1;
        while (sz < n) {
            sz *= 2;
        }
        mx = x;
        st.resize(2 * sz, mx);
        sz = n;
    }
    Segment_tree(int n, int x) {
        init(n, x);
    }
    void set(int v, int vl, int vr, int i, int x) {
        if (vl + 1 == vr) {
            st[v] = x;
            return;
        }
        int vm = (vl + vr) / 2;
        if (i < vm) {
            set(2 * v, vl, vm, i, x);
        } else {
            set(2 * v + 1, vm, vr, i, x);
        }
        st[v] = min(st[2 * v], st[2 * v + 1]);
    }
    void set(int i, int x) {
        set(1, 0, sz, i, x);
    }
    int get(int v, int vl, int vr, int ql, int qr) {
        if (vl >= qr || vr <= ql) {
            return mx;
        }
        if (vl >= ql && vr <= qr) {
            return st[v];
        }
        int vm = (vl + vr) / 2;
        return min(get(2 * v, vl, vm, ql, qr), get(2 * v + 1, vm, vr, ql, qr));
    }
    int get(int ql, int qr) {
        return get(1, 0, sz, ql, qr);
    }
};

struct Seg {
    int l, m, r;
};

void solve() {
    int n, k;
    cin >> n >> k;
    vector<Seg> s(k);
    for (auto& [l, m, r] : s) {
        cin >> l >> m >> r;
        --l, --m, --r;
    }
    vector<int> numb(k), numc(k);
    iota(numb.begin(), numb.end(), 0);
    sort(numb.begin(), numb.end(), [&s](int i, int j) { return s[i].m < s[j].m; });
    iota(numc.begin(), numc.end(), 0);
    sort(numc.begin(), numc.end(), [&s](int i, int j) { return s[i].r < s[j].r; });
    vector<int> pb(k), pc(k), vb(k), vc(k);
    vector<vector<int>> upd(n), add(n + 1), del(n + 1);
    for (int i = 0; i < k; ++i) {
        pb[numb[i]] = i;
        pc[numc[i]] = i;
        vb[i] = s[numb[i]].m;
        vc[i] = s[numc[i]].r;
        upd[s[i].l].push_back(i);
    }
    Segment_tree stb(k, n), stc(k, n);
    for (auto i : upd[0]) {
        if (s[i].r == n - 1) {
            cout << "YES\n";
            return;
        }
        stb.set(pb[i], s[i].r);
        stc.set(pc[i], s[i].r);
        del[s[i].r + 1].push_back(i);
    }
    for (int li = 1; li < n; ++li) {
        for (auto i : upd[li]) {
            int mi = s[i].m, ri = s[i].r;
            int resi = min(stb.get(0, lower_bound(vb.begin(), vb.end(), li) - vb.begin()),
                          stc.get(0, lower_bound(vc.begin(), vc.end(), mi) - vc.begin()));
            if (resi != n) {
                if (ri == n - 1) {
                    cout << "YES\n";
                    return;
                }
                add[min(max(resi, li), ri + 1)].push_back(i);
                del[ri + 1].push_back(i);
            }
        }
        for (auto i : add[li]) {
            stb.set(pb[i], s[i].r);
            stc.set(pc[i], s[i].r);
        }
        for (auto i : del[li]) {
            stb.set(pb[i], n);
            stc.set(pc[i], n);
        }
    }
    cout << "NO\n";
}

int main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
    freopen("error.txt", "w", stderr);
#endif // LOCAL
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int t = 1;
    cin >> t;
    while (t--) {
        solve();
    }
    return 0;
}
