#include <iostream>
#include <iomanip>
#include <set>
#include <map>
#include <algorithm>
#include <vector>
#include <cmath>
#include <deque>

#define all(v) v.begin(), v.end()
#define len(v) (int)v.size()

using namespace std;
using ll = long long;

const int INF = 2e9;
const int IINF = 5e6;

struct Node
{
    int sum, sc;
};

Node operator+(Node x, Node y)
{
    return {x.sum + y.sum, -1};
}

struct Seg_tree
{
    vector<Node> tree;
    int n;
    Seg_tree (int _n)
    {
        n = _n;
        tree.resize(4 * n, {IINF, -1});
    }
    void apply(int v, int l, int r)
    {
        tree[v].sum = tree[v].sc * (r - l);
    }
    void push(int v, int l, int r)
    {
        if (tree[v].sc != -1)
        {
            int m = (l + r) / 2;
            tree[2 * v + 1].sc = tree[v].sc;
            tree[2 * v + 2].sc = tree[v].sc;
            apply(2 * v + 1, l, m);
            apply(2 * v + 2, m, r);
            tree[v].sc = -1;
        }
    }
    void update(int v, int l, int r, int ql, int qr, ll x)
    {
        if (l >= qr || r <= ql) return;
        if (l >= ql && r <= qr)
        {
            tree[v].sc = x;
            apply(v, l, r);
            return;
        }
        push(v, l, r);
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, ql, qr, x);
        update(2 * v + 2, m, r, ql, qr, x);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }
    int get_sum(int v, int l, int r, int ql, int qr)
    {
        if (ql == qr) return 0;
        if (l >= qr || r <= ql) return 0;
        if (l >= ql && r <= qr)
        {
            return tree[v].sum;
        }
        push(v, l, r);
        int m = (l + r) / 2;
        return get_sum(2 * v + 1, l, m, ql, qr) + get_sum(2 * v + 2, m, r, ql, qr);
    }
};

int main()
{
    cin.tie(0)->sync_with_stdio(0);
    int n, m;
    cin >> n >> m;
    vector<vector<int>> mtx(n, vector<int>(m));
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < m; ++j)
        {
            char c;
            cin >> c;
            mtx[i][j] = c - '0';
        }
    }
    vector<vector<int>> dp(n, vector<int>(m, 0));
    vector<vector<int>> h(n, vector<int>(m, 0));
    for (int i = 0; i < n; ++i)
    {
        for (int j = m - 1; j >= 0; --j)
        {
            if (mtx[i][j] == 0)
            {
                h[i][j] = 0;
                continue;
            }
            if (i == 0)
            {
                h[i][j] = 1;
                continue;
            }
            h[i][j] = 1 + h[i - 1][j];
        }
    }
    for (int i = 0; i < n; ++i)
    {
        vector<int> rt(m);
        deque<int> dq;
        for (int j = m - 1; j >= 0; --j)
        {
            while (!dq.empty() && h[i][j] <= h[i][dq.back()])
            {
                dq.pop_back();
            }
            if (dq.empty())
            {
                rt[j] = m;
            } else
            {
                rt[j] = dq.back();
            }
            dq.push_back(j);
        }
        Seg_tree tree(m);
        for (int j = m - 1; j >= 0; --j)
        {
            dp[i][j] = h[i][j];
            if (j == m - 1)
            {
                tree.update(0, 0, m, j, m, h[i][j]);
                continue;
            }
            dp[i][j] += dp[i][j + 1];
            int k = rt[j] - 1;
            dp[i][j] -= tree.get_sum(0, 0, m, j + 1, k + 1) - (k + 1 - (j + 1)) * h[i][j];
            tree.update(0, 0, m, j, k + 1, h[i][j]);
        }
    }
    int ans = 0;
    for (int i = 0; i < n; ++i)
    {
        for (int j = m - 1; j >= 0; --j)
        {
            ans = max(ans, dp[i][j]);
        }
    }
    cout << ans;

    return 0;
}
