#include <iostream>
#include <iomanip>
#include <set>
#include <map>
#include <algorithm>
#include <vector>
#include <cmath>

#define all(v) v.begin(), v.end()
#define len(v) (int)v.size()

using namespace std;
using ll = long long;

struct obj
{
    ll l, m, r;
};

struct obj1
{
    ll l, r;
};

bool operator<(obj x, obj y)
{
    return x.r > y.r;
}

struct Node
{
    ll sum, sc;
};

Node operator+(Node x, Node y)
{
    return {x.sum + y.sum, 0};
}

struct Seg_tree
{
    vector<Node> tree;
    int n;
    Seg_tree (int _n)
    {
        n = _n;
        tree.resize(4 * n, {0, 0});
    }
    void apply(int v, int l, int r)
    {
        tree[v].sum = tree[v].sc * (r - l);
    }
    void push(int v, int l, int r)
    {
        if (tree[v].sc != 0)
        {
            int m = (l + r) / 2;
            tree[2 * v + 1].sc = tree[v].sc;
            tree[2 * v + 2].sc = tree[v].sc;
            apply(2 * v + 1, l, m);
            apply(2 * v + 2, m, r);
            tree[v].sc = 0;
        }
    }
    void update(int v, int l, int r, int ql, int qr, ll x)
    {
        if (l >= qr || r <= ql) return;
        if (l >= ql && r <= qr)
        {
            tree[v].sc += x;
            apply(v, l, r);
            return;
        }
        push(v, l, r);
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, ql, qr, x);
        update(2 * v + 2, m, r, ql, qr, x);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }
    int get_sum(int v, int l, int r, int ql, int qr)
    {
        if (l >= qr || r <= ql) return 0;
        if (l >= ql && r <= qr)
        {
            return tree[v].sum;
        }
        push(v, l, r);
        int m = (l + r) / 2;
        return get_sum(2 * v + 1, l, m, ql, qr) + get_sum(2 * v + 2, m, r, ql, qr);
    }
};

void solve()
{
    int n, k;
    cin >> n >> k;
    vector<obj> a(k);
    for (int i = 0; i < k; ++i)
    {
        cin >> a[i].l >> a[i].m >> a[i].r;
        --a[i].l;
        --a[i].m;
        --a[i].r;
    }
    sort(all(a));
    int lt = n;
    for (int i = 0; i < k; ++i)
    {
        if (a[i].r + 1 < lt)
        {
            cout << "NO\n";
            return;
        }
        lt = a[i].l;
    }
    if (lt != 0)
    {
        cout << "NO\n";
        return;
    }
    vector<obj1> b;
    vector<obj1> c;
    map<int, int> compr;
    vector<int> dr;
    for (int i = 0; i < k; ++i)
    {
        dr.push_back(a[i].l);
        dr.push_back(a[i].m);
        dr.push_back(a[i].r);
        b.push_back({a[i].l, a[i].m});
        c.push_back({a[i].m, a[i].r});
    }
    sort(all(dr));
    dr.resize(unique(all(dr)) - dr.begin());
    int num = 0;
    for (int x : dr)
    {
        compr[x] = num++;
    }
    Seg_tree tree(num);
    for (int i = 0; i < k; ++i)
    {
        tree.update(0, 0, num, compr[b[i].l], compr[b[i].r] + 1, 1);
    }
    for (int i = 0; i < k; ++i)
    {
        tree.update(0, 0, num, compr[b[i].l], compr[b[i].r] + 1, -1);
        int sum = tree.get_sum(0, 0, num, compr[c[i].l], compr[c[i].r] + 1);
        if (sum != 0)
        {
            cout << "NO\n";
            return;
        }
    }
    /*for (int i = 0; i < k; ++i)
    {
        for (int j = 0; j < k; ++j)
        {
            if (i == j) continue;
            int l = max(a[i].l, a[j].l);
            int r = min(a[i].r, a[j].r);
            bool cond1 = (l <= a[i].m && a[i].m <= r);
            bool cond2 = (l <= a[j].m && a[j].m <= r);
            if (cond1 && cond2)
            {
                cout << "NO\n";
                return;
            }
        }
    }*/
    cout << "YES\n";
}

int main()
{
    cin.tie(0)->sync_with_stdio(0);
    int t;
    cin >> t;
    while (t--)
    {
        solve();
    }

    return 0;
}

