#include <iostream>
#include <vector>
#include <algorithm>
#include <unordered_map>
using namespace std;
using ll = long long;

struct segTree {
	int size;
	vector<int> tree;

	void init(int n) {
		size = 1;
		while (size < n) size *= 2;
		tree.resize(2 * size - 1, 0);
	}
	void upd(int x, int lx, int rx, int pos, int val) {
		if (lx + 1 == rx) {
			tree[x] = val;
			return;
		}
		int m = (lx + rx) / 2;
		if (pos < m)
			upd(2 * x + 1, lx, m, pos, val);
		else
			upd(2 * x + 2, m, rx, pos, val);
		tree[x] = tree[2 * x + 1] + tree[2 * x + 2];
	}
	int get_sum(int x, int lx, int rx, int l, int r) {
		if (lx >= l && rx <= r)
			return tree[x];
		if (lx >= r || rx <= l)
			return 0;
		int m = (lx + rx) / 2;
		int left = get_sum(2 * x + 1, lx, m, l, r);
		int right = get_sum(2 * x + 2, m, rx, l, r);
		return left + right;
	}
};
struct fenvik {
	int size;
	vector<int> f;

	void init(int n) {
		size = n;
		f.resize(n, 0);
	}
	int getp(int r) {
		int s = 0;
		for (int i = r; i >= 0; i = (i & (i + 1)) - 1)
			s += f[i];
		return s;
	}
	void upd(int pos, int val) {
		for (int i = pos; i < size;  i = (i | (i + 1))) {
			f[i] += val;
			
		}
	}
	int get_sum(int l, int r) {
		int s = getp(r - 1);
		if (l != 0) s -= getp(l - 1);
		return s;
	}
};

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);

	int r, c;
	cin >> r >> c;
	vector<vector<int>> a(r, vector<int>(c));
	for (int i = 0; i < r; ++i) {
		for (int j = 0; j < c; ++j) {
			cin >> a[i][j];
		}
	}
	
	vector<vector<int>> dp(r + 1, vector<int>(c + 1, 0));
	fenvik tr1, tr_all;
	tr1.init(r * c + 1);
	tr_all.init(r * c + 1);
	
	tr_all.upd(a[r - 1][c - 1], 1);

	for (int i = r - 1; i >= 0; --i) {
		for (int j = c - 1; j >= 0; --j) {
			int cur = 0;
			for (int k = j; k < c; ++k) {
				cur += tr1.get_sum(a[i][k] + 1, r * c + 1);
				tr1.upd(a[i][k], 1);
				tr_all.upd(a[i][k], -1);
			}
			cur += dp[i + 1][j];
			for (int k = j; k < c; ++k) {
				cur += tr_all.get_sum(1, a[i][k]);
				tr1.upd(a[i][k], -1);
			}
			for (int k = j; k < c; ++k) {
				tr_all.upd(a[i][k], 1);
			}
			dp[i][j] = cur;
			
			cur = 0;
			for (int k = i; k < r; ++k) {
				cur += tr1.get_sum(a[k][j] + 1, r * c + 1);
				tr1.upd(a[k][j], 1);
				tr_all.upd(a[k][j], -1);
			}
			cur += dp[i][j + 1];
			for (int k = i; k < r; ++k) {
				cur += tr_all.get_sum(1, a[k][j]);
				tr1.upd(a[k][j], -1);
			}
			for (int k = i; k < r; ++k) {
				tr_all.upd(a[k][j], 1);
			}
			dp[i][j] = min(dp[i][j], cur);

			if (j != 0) {
				for (int k = i; k < r; ++k) {
					tr_all.upd(a[k][j - 1], 1);
				}
			}
			else {
				for (int k = i; k < r; ++k) {
					for (int z = j; z < c; ++z) {
						tr_all.upd(a[k][z], -1);
					}
				}
				if (i != 0) {
					for (int k = i - 1; k < r; ++k) {
						tr_all.upd(a[k][c - 1], 1);
					}
				}
			}
		}
	}
	cout << dp[0][0];

	return 0;
}