#include <iostream>
#include <vector>
#include <algorithm>
#include <unordered_map>
using namespace std;
using ll = long long;

struct segTree {
	int size;
	vector<int> tree;

	void init(int n) {
		size = 1;
		while (size < n) size *= 2;
		tree.resize(2 * size - 1, 0);
	}
	void upd(int x, int lx, int rx, int pos, int val) {
		if (lx + 1 == rx) {
			tree[x] = val;
			return;
		}
		int m = (lx + rx) / 2;
		if (pos < m)
			upd(2 * x + 1, lx, m, pos, val);
		else
			upd(2 * x + 2, m, rx, pos, val);
		tree[x] = tree[2 * x + 1] + tree[2 * x + 2];
	}
	int get_sum(int x, int lx, int rx, int l, int r) {
		if (lx >= l && rx <= r)
			return tree[x];
		if (lx >= r || rx <= l)
			return 0;
		int m = (lx + rx) / 2;
		int left = get_sum(2 * x + 1, lx, m, l, r);
		int right = get_sum(2 * x + 2, m, rx, l, r);
		return left + right;
	}
};
struct fenvik {
	int size;
	vector<int> f;

	void init(int n) {
		size = n;
		f.assign(n, 0);
	}
	int getp(int r) {
		int s = 0;
		for (int i = r; i >= 0; i = (i & (i + 1)) - 1)
			s += f[i];
		return s;
	}
	void upd(int pos, int val) {
		for (int i = pos; i < size;  i = (i | (i + 1))) {
			f[i] += val;
			
		}
	}
	int get_sum(int l, int r) {
		int s = getp(r - 1);
		if (l != 0) s -= getp(l - 1);
		return s;
	}
};

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);

	int r, c;
	cin >> r >> c;
	vector<vector<int>> a(r, vector<int>(c));
	for (int i = 0; i < r; ++i) {
		for (int j = 0; j < c; ++j) {
			cin >> a[i][j];
		}
	}
	
	if (r == 1) {
		fenvik tr1;
		tr1.init(r * c + 1);
		ll ans = 0;
		for (int j = c - 1; j >= 0; --j) {
			ans += tr1.get_sum(1, a[0][j]);
			tr1.upd(a[0][j], 1);
		}
		cout << ans;
	}
	else {
		fenvik tr1;
		tr1.init(r * c + 1);
		vector<ll> cnt_less(c, 0), cnt_more(c, 0);
		for (int j = c - 1; j >= 0; --j) {
			cnt_less[j] = tr1.get_sum(1, a[1][j]);
			cnt_more[j] = tr1.get_sum(a[1][j] + 1, r * c + 1);
			tr1.upd(a[0][j], 1);
		}
		ll cur = 0;
		tr1.init(r * c + 1);
		for (int i = 0; i < r; ++i) {
			for (int j = 0; j < c; ++j) {
				cur += tr1.get_sum(a[i][j] + 1, r * c + 1);
				tr1.upd(a[i][j], 1);
			}
		}
		ll ans = cur;
		for (int j = 0; j < c - 1; ++j) {
			cur += cnt_less[j] - cnt_more[j];
			ans = min(ans, cur);
		}
		cout << ans;
	}

	return 0;
}