#include <iostream>
#include <algorithm>
#include <functional>

using namespace std;
using ll = long long;

constexpr ll maxn = 1e5 + 10;
ll n, r;

namespace SNM {
    struct Node {
        ll par, sz;
        bool ok;
    };

    Node tree[maxn];

    void init() {
        for (ll i = 0; i < n; ++i) tree[i].par = i, tree[i].sz = 1, tree[i].ok = false;
    }

    ll get_root(ll a) {
        if (tree[a].par == a) return a;
        return tree[a].par = get_root(tree[a].par);
    }

    void merge(ll a, ll b) {
        a = get_root(a), b = get_root(b);
        if (a == b) return;

        if (tree[a].sz < tree[b].sz) swap(a, b);
        tree[a].sz += tree[b].sz;
        tree[a].ok |= tree[b].ok;
        tree[b].par = a;
    }

    void set_ok(ll a) {
        tree[get_root(a)].ok = true;
    }

    bool is_ok(ll a) {
        return tree[get_root(a)].ok;
    }
}

struct PV {
    ll x = 0, y = 0, id = 0;

    bool operator<(const PV &rhs) const {
        if (x != rhs.x) return x < rhs.x;
        return y < rhs.y;
    }

    PV(ll x, ll y, ll id): x(x), y(y), id(id) {
    }

    PV() = default;
};

PV points[maxn];
// set<PV>

ll dist(ll a, ll b) {
    ll fv = points[a].x - points[b].x;
    ll sv = points[a].y - points[b].y;
    return fv * fv + sv * sv;
}

bool is_neigh(ll a, ll b) {
    return dist(a, b) <= 1ll * r * r;
}

void rec_circle(ll i, const function<void(ll)> &f) {
    for (ll dx = -r; dx <= r; ++dx) {
        for (ll dy = -r; dy <= r; ++dy) {
            // if (1ll * dx * dx + 1ll * dy * dy > 1ll * r * r) continue;
            ll pos = lower_bound(points, points + n, PV(points[i].x + dx, points[i].y + dy, 0)) - points;
            if (pos >= i || pos == n || points[pos].x != points[i].x + dx ||
                points[pos].y != points[i].y + dy)
                continue;
            f(pos);
        }
    }
}

bool ans[maxn];

void solve() {
    cin >> n >> r;
    SNM::init();
    for (ll i = 0; i < n; ++i) cin >> points[i].x >> points[i].y, points[i].id = i;
    sort(points, points + n);
    for (ll i = 0; i < n; ++i) {
        rec_circle(i, [i](ll j) {
            if (!is_neigh(i, j)) return;
            SNM::merge(i, j);
            rec_circle(j, [i,j](ll k) {
                if (!is_neigh(i, k) || !is_neigh(j, k)) return;
                SNM::merge(i, k);
                SNM::set_ok(i);
            });
        });
    }
    for (ll i = 0; i < n; ++i) ans[points[i].id] = SNM::is_ok(i);
    for (ll i = 0; i < n; ++i) cout << (ans[i] ? '1' : '0');
}

int main() {
    ios::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
#endif
#ifdef TEST
    freopen("input.txt", "r",stdin);
#endif
    solve();
    return 0;
}
