#include <iostream>
#include <algorithm>

using namespace std;
using ll = long long;

constexpr int maxn = 1e5 + 10;
int n, r;

namespace SNM {
    struct Node {
        int par, sz;
        bool ok;
    };

    Node tree[maxn];

    void init() {
        for (int i = 0; i < n; ++i) tree[i].par = i, tree[i].sz = 1, tree[i].ok = false;
    }

    int get_root(int a) {
        if (tree[a].par == a) return a;
        return tree[a].par = get_root(tree[a].par);
    }

    void merge(int a, int b) {
        a = get_root(a), b = get_root(b);
        if (a == b) return;

        if (tree[a].sz < tree[b].sz) swap(a, b);
        tree[a].sz += tree[b].sz;
        tree[a].ok |= tree[b].ok;
        tree[b].par = a;
    }

    void set_ok(int a) {
        tree[get_root(a)].ok = true;
    }

    bool is_ok(int a) {
        return tree[get_root(a)].ok;
    }
}


struct PV {
    ll x = 0, y = 0, id = 0;

    bool operator<(const PV &rhs) const {
        if (x != rhs.x) return x < rhs.x;
        return y < rhs.y;
    }

    PV(ll x, ll y, ll id): x(x), y(y), id(id) {
    }

    PV() = default;
};
PV points[maxn];

ll dist(int a, int b) {
    ll fv = points[a].x - points[b].x;
    ll sv = points[a].y - points[b].y;
    return fv * fv + sv * sv;
}

bool is_neigh(int a, int b) {
    return dist(a, b) <= 1ll * r * r;
}


bool ans[maxn];

void solve() {
    cin >> n >> r;
    SNM::init();
    for (ll i = 0; i < n; ++i) cin >> points[i].x >> points[i].y, points[i].id = i;
    sort(points, points + n);
    for (int i = 0; i < n; ++i) {
        for (int j = i + 1; j < n; ++j) {
            if (!is_neigh(i, j)) continue;
            SNM::merge(i, j);
            for (int k = j + 1; k < n; ++k) {
                if (!is_neigh(i, k) || !is_neigh(j, k)) continue;
                SNM::merge(i, k);
                SNM::set_ok(i);
            }
        }
    }
    for (ll i = 0; i < n; ++i) ans[points[i].id] = SNM::is_ok(i);
    for (ll i = 0; i < n; ++i) cout << (ans[i] ? '1' : '0');
}

int main() {
    ios::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
#endif
#ifdef TEST
    freopen("input.txt", "r",stdin);
#endif
    solve();
    return 0;
}