#include <iostream>
#include <algorithm>
#include <functional>

using namespace std;
using ll = long long;

constexpr int maxn = 1e5 + 10;
int n, r;

namespace SNM {
    struct Node {
        int par, sz;
        bool ok;
    };

    Node tree[maxn];

    void init() {
        for (int i = 0; i < n; ++i) tree[i].par = i, tree[i].sz = 1, tree[i].ok = false;
    }

    int get_root(int a) {
        if (tree[a].par == a) return a;
        return tree[a].par = get_root(tree[a].par);
    }

    void merge(int a, int b) {
        a = get_root(a), b = get_root(b);
        if (a == b) return;

        if (tree[a].sz < tree[b].sz) swap(a, b);
        tree[a].sz += tree[b].sz;
        tree[a].ok |= tree[b].ok;
        tree[b].par = a;
    }

    void set_ok(int a) {
        tree[get_root(a)].ok = true;
    }

    bool is_ok(int a) {
        return tree[get_root(a)].ok;
    }
}

pair<int, int> points[maxn];

ll dist(int a, int b) {
    ll fv = points[a].first - points[b].first;
    ll sv = points[a].second - points[b].second;
    return fv * fv + sv * sv;
}

bool is_neigh(int a, int b) {
    return dist(a, b) <= 1ll * r * r;
}

void rec_circle(int i, const function<void(int)> &f) {
    for (int dx = 0; dx <= r; ++dx) {
        for (int dy = -r; dy <= r; ++dy) {
            if ((!dx && !dy) || 1ll * dx * dx + 1ll * dy * dy > 1ll * r * r) continue;
            int pos = lower_bound(points, points + n, make_pair(points[i].first + dx, points[i].second + dy)) - points;
            if (pos < i || pos == n || points[pos].first != points[i].first + dx || points[pos].second != points[i].
                second + dy)
                continue;
            f(pos);
        }
    }
}

void solve() {
    cin >> n >> r;
    SNM::init();
    for (int i = 0; i < n; ++i) cin >> points[i].first >> points[i].second;
    sort(points, points + n);
    for (int i = 0; i < n; ++i) {
        rec_circle(i, [i](int j) {
            SNM::merge(i, j);
            rec_circle(j, [i,j](int k) {
                if (!is_neigh(i, k)) return;
                SNM::merge(i, k);
                SNM::set_ok(i);
            });
        });
        // for (int j = i + 1; j < n; ++j) {
        //     if (!is_neigh(i, j)) continue;
        //     SNM::merge(i, j);
        //     for (int k = j + 1; k < n; ++k) {
        //         if (!is_neigh(i, k) || !is_neigh(j, k)) continue;
        //         SNM::merge(i, k);
        //         SNM::set_ok(i);
        //     }
        // }
    }
    for (int i = 0; i < n; ++i) cout << (SNM::is_ok(i) ? '1' : '0');
}

int main() {
    ios::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
#endif
#ifdef TEST
    freopen("input.txt", "r",stdin);
#endif
    solve();
    return 0;
}
