#include <iostream>
#include <algorithm>
#include <vector>
#include <map>

using namespace std;
using ll = long long;

constexpr ll maxn = 1e5 + 10;
ll n, r;

namespace SNM {
    struct Node {
        int par, sz;
        bool ok;
    };

    Node tree[maxn];

    void init() {
        for (int i = 0; i < n; ++i) tree[i].par = i, tree[i].sz = 1, tree[i].ok = false;
    }

    int get_root(int a) {
        if (tree[a].par == a) return a;
        return tree[a].par = get_root(tree[a].par);
    }

    void merge(int a, int b) {
        a = get_root(a), b = get_root(b);
        if (a == b) return;

        if (tree[a].sz < tree[b].sz) swap(a, b);
        tree[a].sz += tree[b].sz;
        tree[a].ok |= tree[b].ok;
        tree[b].par = a;
    }

    void set_ok(int a) {
        tree[get_root(a)].ok = true;
    }

    bool is_ok(int a) {
        return tree[get_root(a)].ok;
    }
}

struct PV {
    ll x = 0, y = 0, id = 0;

    bool operator<(const PV &rhs) const {
        if (x != rhs.x) return x < rhs.x;
        return y < rhs.y;
    }

    PV(ll x, ll y, ll id): x(x), y(y), id(id) {
    }

    PV() = default;
};

PV points[maxn];
// set<PV>

ll dist(ll a, ll b) {
    ll fv = points[a].x - points[b].x;
    ll sv = points[a].y - points[b].y;
    return fv * fv + sv * sv;
}

bool is_neigh(ll a, ll b) {
    return dist(a, b) <= 1ll * r * r;
}

bool ans[maxn];

map<int, map<int, int> > mps;

// vector<pair<int, int> > dcs{
//     {-2, 0}, {-1, 1}, {-1, 0}, {-1, -1}, {0, 2}, {0, 1}, {0, -1}, {0, -2}, {1, 1}, {1, 0}, {1, -1}, {2, 0}
// };

int find_by_coord(int x, int y) {
    auto pos = lower_bound(points, points + n, PV(x, y, 0)) - points;
    if (pos != n && points[pos].x == x && points[pos].y == y) return pos;
    return n;
}

void solve() {
    cin >> n >> r;
    SNM::init();
    for (ll i = 0; i < n; ++i) {
        cin >> points[i].x >> points[i].y, points[i].id = i;
        mps[points[i].x].emplace(points[i].y, i);
    }
    for (int i = 0; i < n; ++i) {
        for (int dx1 = -r; dx1 <= r; ++dx1) {
            for (int dy1 = -r; dy1 <= r; ++dy1) {
                if (1ll * dx1 * dx1 + 1ll * dy1 * dy1 > 1l * r * r) continue;
                int nx1 = points[i].x + dx1, ny1 = points[i].y + dy1;
                if (!mps[nx1].contains(ny1)) continue;
                int j = mps[nx1][ny1];
                if (j == i) continue;
                SNM::merge(i, j);
                for (int dx2 = -r; dx2 <= r; ++dx2) {
                    for (int dy2 = -r; dy2 <= r; ++dy2) {
                        if (1ll * dx2 * dx2 + 1ll * dy2 * dy2 > 1ll * r * r) continue;
                        int nx2 = points[j].x + dx2, ny2 = points[j].y + dy2;
                        if (!mps[nx2].contains(ny2)) continue;
                        int k = mps[nx2][ny2];
                        if (k == j || i == k) continue;
                        if (!is_neigh(i, k)) continue;
                        SNM::merge(i, k);
                        SNM::set_ok(i);
                    }
                }
            }
        }
    }
    // for (int i = 0; i + 2 < n; ++i) if (is_neigh(i, i + 2)) SNM::set_ok(i);
    // for (int i = 0; i + 1 < n; ++i) if (is_neigh(i, i + 1)) SNM::merge(i, i + 1);
    for (ll i = 0; i < n; ++i) ans[points[i].id] = SNM::is_ok(i);
    for (ll i = 0; i < n; ++i) cout << (ans[i] ? '1' : '0');
}

int main() {
    ios::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r",stdin);
    freopen("output.txt", "w",stdout);
#endif
#ifdef TEST
    freopen("input.txt", "r",stdin);
#endif
    solve();
    return 0;
}
