#ifdef _DEBUG
#define _CRT_SECURE_NO_WARNINGS
#endif
#include <iostream>
#include <vector>
#include <fstream>
#include <string>
#include <cmath>
#include <climits>
#include <iomanip>
#include <stack>
#include <queue>
#include <deque>
#include <algorithm>
#include <numeric>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <bitset>
#include <chrono>
#include <random>
#include <assert.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pli = pair<long long, int>;
using pil = pair<int, long long>;
using pll = pair<long long, long long>;
template <typename T>
using uset = unordered_set<T>;
template <typename T1, typename T2>
using umap = unordered_map<T1, T2>;

#ifdef _DEBUG
using i128 = long long;
#else
using i128 = __int128;
#endif

#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()

struct pnt {
	ll x, y;

	pnt() {}

	pnt(ll x, ll y) : x(x), y(y) {}
};

ll dist(pnt a, pnt b) {
	ll x = a.x - b.x;
	ll y = a.y - b.y;
	return x * x + y * y;
}

const int N = 1e5;
int pr[N];
vector<int> cmp[N];
int col[N];
bool odd[N];

int get(int a) {
	return pr[a] == a ? a : get(pr[a]);
}

bool same(int a, int b) {
	a = get(a);
	b = get(b);
	return a == b;
}

void set_odd(int a) {
	a = get(a);
	odd[a] = 1;
}

bool get_odd(int a) {
	a = get(a);
	return odd[a];
}

bool unite(int a, int b) {
	bool same_col = col[a] == col[b];
	a = get(a);
	b = get(b);
	if (a == b)
		return false;
	if (cmp[a].size() < cmp[b].size())
		swap(a, b);
	if (odd[b])
		odd[a] = 1;
	pr[b] = a;
	if (same_col) {
		for (int u : cmp[b])
			col[u] = !col[u];
	}
	for (int u : cmp[b])
		cmp[a].push_back(u);
	cmp[b].clear();
	return true;
}

mt19937 rnd(1337);

inline void solve() {
	int n;
	cin >> n;
	ll r;
	cin >> r;
	r *= 2;
	ll r2 = r * r;
	vector<pnt> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i].x >> a[i].y;
		a[i].x *= 2;
		a[i].y *= 2;
	}
	for (int i = 0; i < n; i++) {
		cmp[i].push_back(i);
		pr[i] = i;
	}
	ll B = r >> 1;
	vector<bool> ans(n);
	vector<pii> squares;
	vector<vector<int>> buc;
	for (int i = 0; i < n; i++) {
		pii id = { a[i].x / B, a[i].y / B };
		squares.push_back(id);
	}
	sort(all(squares));
	squares.resize(unique(all(squares)) - squares.begin());
	buc.resize(squares.size());
	for (int i = 0; i < n; i++) {
		pii id = { a[i].x / B, a[i].y / B };
		int idi = lower_bound(all(squares), id) - squares.begin();
		buc[idi].push_back(i);
	}
	for (int id = 0; id < (int)squares.size(); id++) {
		if (buc[id].size() == 1)
			continue;
		if (buc[id].size() == 2)
			unite(buc[id][0], buc[id][1]);
		if (buc[id].size() >= 3) {
			for (int i = 1; i < (int)buc[id].size(); i++)
				unite(buc[id][i - 1], buc[id][i]);
			set_odd(buc[id][0]);
		}
	}
	for (int id = 0; id < (int)buc.size(); id++) {
		pii sq = squares[id];
		for (int dx = -2; dx <= 0; dx++)
			for (int dy = -2; dy <= 2; dy++) {
				if (dx == 0 && dy >= 0)
					continue;
				pii to = sq;
				to.first += dx;
				to.second += dy;
				int idj = lower_bound(all(squares), to) - squares.begin();
				if (idj == squares.size() || squares[idj] != to)
					continue;
				if (buc[id].size() <= 2 && buc[idj].size() <= 2) {
					for (int i : buc[id])
						for (int j : buc[idj])
							if (dist(a[i], a[j]) <= r2) {
								if (same(i, j)) {
									if (col[i] == col[j])
										set_odd(i);
								}
								else {
									unite(i, j);
								}
							}
				} else {
					bool found = false;
					for (int i : buc[id]) {
						if (found)
							break;
						for (int j : buc[idj])
							if (dist(a[i], a[j]) <= r2) {
								found = true;
								unite(i, j);
								break;
							}
					}
				}
			}
	}
	for (int i = 0; i < n; i++)
		cout << get_odd(i);
	cout << '\n';
}

signed main() {
#ifdef _DEBUG
	freopen("01.dat", "r", stdin);
#endif
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	int tt = 1;
#ifdef _DEBUG
	cin >> tt;
#endif
	for (int test_id = 1; test_id <= tt; test_id++) {
#ifdef _DEBUG
		cout << "TESTCASE# " << test_id << ":" << '\n';
#endif
		solve();
	}
	return 0;
}