#ifdef _DEBUG
#define _CRT_SECURE_NO_WARNINGS
#endif
#include <iostream>
#include <vector>
#include <fstream>
#include <string>
#include <cmath>
#include <climits>
#include <iomanip>
#include <stack>
#include <queue>
#include <deque>
#include <algorithm>
#include <numeric>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <bitset>
#include <chrono>
#include <random>
#include <assert.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pli = pair<long long, int>;
using pil = pair<int, long long>;
using pll = pair<long long, long long>;
template <typename T>
using uset = unordered_set<T>;
template <typename T1, typename T2>
using umap = unordered_map<T1, T2>;

#ifdef _DEBUG
using i128 = long long;
#else
using i128 = __int128;
#endif

#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()

struct fenwick {
	vector<int> f;
	int n;
	int sum = 0;

	fenwick() {}

	fenwick(int _n) {
		n = _n + 2;
		f.resize(n);
	}

	void add(int i, int x) {
		i++;
		sum += x;
		for (; i < n; i += i & -i)
			f[i] += x;
	}
	
	int get(int i) {
		int res = 0;
		for (; i; i -= i & -i)
			res += f[i];
		return res;
	}

	int suf(int i) {
		return sum - get(i);
	}

	void clear() {
		sum = 0;
		fill(all(f), 0);
	}
};

const ll inf = 3e18;

void smin(ll& a, ll b) {
	if (a > b)
		a = b;
}

inline void solve() {
	int n, m;
	cin >> n >> m;
	vector<vector<int>> a(n, vector<int>(m));
	for (int i = 0; i < n; i++)
		for (int j = 0; j < m; j++) {
			cin >> a[i][j];
			a[i][j]--;
		}
	vector<vector<ll>> dp(n + 1, vector<ll>(m + 1, inf));
	vector<vector<ll>> row(n, vector<ll>(m)), col(n, vector<ll>(m));
	fenwick st(n * m);
	for (int i = 0; i < n; i++) {
		ll tmp = 0;
		for (int j = m - 1; j > -1; j--) {
			tmp += st.get(a[i][j]);
			row[i][j] += tmp;
			st.add(a[i][j], 1);
		}
		for (int j = 0; j < m; j++)
			st.add(a[i][j], -1);
	}
	for (int j = 0; j < m; j++) {
		ll tmp = 0;
		for (int i = n - 1; i > -1; i--) {
			tmp += st.get(a[i][j]);
			col[i][j] += tmp;
			st.add(a[i][j], 1);
		}
		for (int i = 0; i < n; i++)
			st.add(a[i][j], -1);
	}
	for (int i = 0; i < n; i++) {
		ll tmp = 0;
		for (int j = m - 1; j > -1; j--) {
			tmp += st.suf(a[i][j]);
			row[i][j] += tmp;
		}
		for (int j = 0; j < m; j++)
			st.add(a[i][j], 1);
	}
	st.clear();
	for (int j = 0; j < m; j++) {
		ll tmp = 0;
		for (int i = n - 1; i > -1; i--) {
			tmp += st.suf(a[i][j]);
			col[i][j] += tmp;
		}
		for (int i = 0; i < n; i++)
			st.add(a[i][j], 1);
	}
	st.clear();
	auto divide_row = [&](auto self, int l, int r) -> void {
		int mid = (l + r) / 2;
		for (int i = n - 1; i > -1; i--) {
			for (int j = l; j < mid; j++)
				st.add(a[i][j], 1);
			ll tmp = 0;
			for (int j = r - 1; j >= mid; j--) {
				tmp += st.suf(a[i][j]);
				row[i][j] += tmp;
			}
		}
		for (int i = n - 1; i > -1; i--)
			for (int j = l; j < mid; j++)
				st.add(a[i][j], -1);
		if (r - l == 1)
			return;
		self(self, l, mid);
		self(self, mid, r);
	};
	divide_row(divide_row, 0, m);
	auto divide_col = [&](auto self, int l, int r) -> void {
		int mid = (l + r) / 2;
		for (int i = l; i < mid; i++)
			for (int j = 0; j < m; j++)
				st.add(a[i][j], 1);
		for (int j = 0; j < m; j++) {
			ll tmp = 0;
			for (int i = r - 1; i >= mid; i--) {
				tmp += st.suf(a[i][j]);
				col[i][j] += tmp;
			}
		}
		for (int i = l; i < mid; i++)
			for (int j = 0; j < m; j++)
				st.add(a[i][j], -1);
		if (r - l == 1)
			return;
		self(self, l, mid);
		self(self, mid, r);
	};
	divide_col(divide_col, 0, n);
	dp[0][0] = 0;
	ll ans = inf;
	for (int i = 0; i < n; i++)
		for (int j = 0; j < m; j++) {
			smin(dp[i + 1][j], dp[i][j] + row[i][j]);
			smin(dp[i][j + 1], dp[i][j] + col[i][j]);
			if (i == n - 1)
				smin(ans, dp[i + 1][j]);
			if (j == m - 1)
				smin(ans, dp[i][j + 1]);
		}
	cout << ans << '\n';
}

signed main() {
#ifdef _DEBUG
	freopen("01.dat", "r", stdin);
#endif
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	int tt = 1;
#ifdef _DEBUG
	cin >> tt;
#endif
	for (int test_id = 1; test_id <= tt; test_id++) {
#ifdef _DEBUG
		cout << "TESTCASE# " << test_id << ":" << '\n';
#endif
		solve();
	}
	return 0;
}