#ifdef _DEBUG
#define _CRT_SECURE_NO_WARNINGS
#endif
#include <iostream>
#include <vector>
#include <fstream>
#include <string>
#include <cmath>
#include <climits>
#include <iomanip>
#include <stack>
#include <queue>
#include <deque>
#include <algorithm>
#include <numeric>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <bitset>
#include <chrono>
#include <random>
#include <assert.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pli = pair<long long, int>;
using pil = pair<int, long long>;
using pll = pair<long long, long long>;
template <typename T>
using uset = unordered_set<T>;
template <typename T1, typename T2>
using umap = unordered_map<T1, T2>;

#ifdef _DEBUG
using i128 = long long;
#else
using i128 = __int128;
#endif

#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()

const int N = 100;

struct query {
	int k, x, i;
};

const int inf = 1e9;

struct segtree {
	vector<int> tree;
	int sz;

	segtree() {}

	segtree(int n) {
		sz = n;
		tree.resize(4 * sz, inf);
	}

	void set(int i, int x, int v, int tl, int tr) {
		if (tr - tl == 1) {
			tree[v] = x;
			return;
		}
		int m = (tl + tr) / 2;
		if (i < m)
			set(i, x, 2 * v + 1, tl, m);
		else
			set(i, x, 2 * v + 2, m, tr);
		tree[v] = min(tree[2 * v + 1], tree[2 * v + 2]);
	}

	void set(int i, int x) {
		set(i, x, 0, 0, sz);
	}

	pii find(int l, int r, int v, int tl, int tr) {
		if (l >= tr || r <= tl)
			return { inf, -1 };
		if (tr - tl == 1)
			return { tree[v], tl };
		int m = (tl + tr) / 2;
		if (l <= tl && tr <= r) {
			if (tree[2 * v + 1] <= tree[2 * v + 2])
				return find(l, r, 2 * v + 1, tl, m);
			else
				return find(l, r, 2 * v + 2, m, tr);
		}
		pii s1 = find(l, r, 2 * v + 1, tl, m);
		pii s2 = find(l, r, 2 * v + 2, m, tr);
		return min(s1, s2);
	}

	pii find(int l, int r) {
		return find(l, r, 0, 0, sz);
	}
};

inline void solve() {
	int n, queries;
	cin >> n >> queries;
	vector<int> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i];
		a[i]--;
	}
	vector<query> q(queries);
	vector<vector<pii>> bucq(n + 1);
	vector<int> ans(queries);
	vector<int> ks;
	for (int i = 0; i < queries; i++) {
		int k, x;
		cin >> k >> x;
		x--;
		q[i] = { k, x, i };
		ks.push_back(k);
		bucq[k].push_back({ x, i });
	}
	vector<int> rge(n, n);
	{
		vector<int> st;
		for (int i = 0; i < n; i++) {
			while (!st.empty() && a[st.back()] < a[i]) {
				rge[st.back()] = i;
				st.pop_back();
			}
			st.push_back(i);
		}
	}
	vector<int> suf = a;
	for (int i = n - 2; i > -1; i--)
		suf[i] = max(suf[i], suf[i + 1]);
	segtree st(n);
	for (int i = 0; i < n; i++)
		st.set(i, a[i]);
	sort(all(ks));
	ks.resize(unique(all(ks)) - ks.begin());
	for (int k : ks) {
		vector<int> b;
		int i = 0;
		for (int p = 0; p < k; p++) {
			if (p == k - 1) {
				b.push_back(suf[i]);
				break;
			}
			int j = rge[i];
			j = min(j, n - k + 1 + p + 1);
			if (j == i + 1) {
				b.push_back(a[i]);
				i++;
				continue;
			}
			pii mn = st.find(i + 1, j);
			b.push_back(a[i]);
			i = mn.second;
		}
		for (pii qi : bucq[k])
			ans[qi.second] = b[qi.first];
	}
	for (int i = 0; i < queries; i++)
		cout << ans[i] + 1 << '\n';
}

signed main() {
#ifdef _DEBUG
	freopen("01.dat", "r", stdin);
#endif
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	int tt = 1;
#ifdef _DEBUG
	cin >> tt;
#endif
	for (int test_id = 1; test_id <= tt; test_id++) {
#ifdef _DEBUG
		cout << "TESTCASE# " << test_id << ":" << '\n';
#endif
		solve();
	}
	return 0;
}