#include <bits/stdc++.h>
using namespace std;

struct SegmentTree {
    vector<int> t;
    int SZ = 1, origN;
    vector<int> changedNodes;
    bool saveChanges = false;
    SegmentTree(int n, bool fastClearMode = false) {
        origN = n;
        saveChanges = fastClearMode;
        while (SZ < n) {
            SZ *= 2;
        }
        t.resize(2 * SZ);
    }
    void add(int i, int x) {
        int l = 0, r = SZ, v = 0;
        while (r - l > 1) {
            t[v] += x;
            if (saveChanges) {
                changedNodes.push_back(v);
            }
            int m = (l + r) / 2;
            if (i < m) {
                v = v * 2 + 1;
                r = m;
            } else {
                v = v * 2 + 2;
                l = m;
            }
        }
        if (saveChanges) {
            changedNodes.push_back(v);
        }
        t[v] += x;
    }
    int get(int l, int r) {
        if (l == 0) {
            return get(0, 0, SZ, r);
        }
        if (r >= origN) {
            return t[0] - get(0, 0, SZ, l);
        }
        return get(0, 0, SZ, r) - get(0, 0, SZ, l);
    }
    int get(int v, int l, int r, int i) {
        if (r <= i) {
            return t[v];
        } else if (l >= i) {
            return 0;
        } else {
            int m = (l + r) / 2;
            return get(v * 2 + 1, l, m, i) + get(v * 2 + 2, m, r, i);
        }
    }
    void clear() {
        if (saveChanges) {
            for (int v : changedNodes) {
                t[v] = 0;
            }
            changedNodes.clear();
        } else {
            t.assign(2 * SZ, 0);
            cerr << "Warning! Clearing not in fast clear mode.\n";
        }
    }
};

using ll = long long;

int main() {
    int n, m;
    cin >> n >> m;
    vector<vector<int>> a(n, vector<int>(m));
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            cin >> a[i][j];
            a[i][j]--;
        }
    }
    SegmentTree tmp{n * m, true};
    vector<vector<ll>> dp(n + 1, vector<ll>(m + 1, n * m * n * m));
    // dp[i][j] = minimal number of inversions if i lines and j columns deleted.
    dp[0][0] = 0;
    for (int i = 0; i <= n; ++i) {
        SegmentTree all{n * m};
        for (int ii = 0; ii < i; ++ii) {
            for (int j = 0; j < m; ++j) {
                all.add(a[ii][j], 1);
            }
        }
        for (int j = 0; j <= m; ++j) {
            // line removing:
            if (i != n) {
                ll val = dp[i][j];
                for (int jj = j; jj < m; ++jj) {
                    val += all.get(a[i][jj], n * m) + tmp.get(a[i][jj], n * m);
                    tmp.add(a[i][jj], 1);
                }
                tmp.clear();
                dp[i + 1][j] = min(dp[i + 1][j], val);
            }
            // column removing
            if (j != m) {
                ll val = dp[i][j];
                for (int ii = i; ii < n; ++ii) {
                    val += all.get(a[ii][j], n * m) + tmp.get(a[ii][j], n * m);
                    tmp.add(a[ii][j], 1);
                }
                dp[i][j + 1] = min(dp[i][j + 1], val);
                tmp.clear();
            }
            if (j != m) {
                for (int ii = i; ii < n; ++ii) {
                    all.add(a[ii][j], 1);
                }
            }
        }
    }
    cout << dp[n][m] << "\n";
}