#include <bits/stdc++.h>

#define all(x) x.begin(), x.end()
#define len(x) ((ll)(x.size()))
#define endl '\n'
#ifdef LOCAL
    #define debug(x) cout << (#x) << " = " << x << endl;
#else
    #define debug(x)
#endif

using namespace std;
using ll = long long;

const ll INF = 1e15 + 7;

template<typename T>
ostream &operator<<(ostream &out, vector<T> &v) {
    for (auto &item : v) cout << item << " ";
    return out;
}

struct Fenwick {
    ll n;
    vector<ll> f;
 
    Fenwick(ll _n): n(_n) {
        f.assign(n + 1, 0);
    }
 
    void update(ll i, ll x) {
        for (; i <= n; i += i & -i) f[i] += x;
    }

    ll get(ll i) {
        ll res = 0;
        for (; i > 0; i -= i & -i) res += f[i];
        return res;
    }
 
    ll query(ll ql, ll qr) {
        return get(qr) - get(ql - 1);
    }
};

int main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    ios_base::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);

    ll r, c; cin >> r >> c;

    vector<vector<ll>> lst(r, vector<ll>(c));

    for (ll i = 0; i < r; i++) {
        for (ll j = 0; j < c; j++) {
            cin >> lst[i][j];
        }
    }

    vector<vector<ll>> right(r, vector<ll>(c)), down(r, vector<ll>(c));

    vector<Fenwick> trees(r, Fenwick(r * c));
    for (ll j = c - 1; j >= 0; j--) {
        for (ll i = r - 1; i >= 0; i--) {
            if (j + 1 < c) {
                right[i][j] += right[i][j + 1];
            }
            for (ll p = i; p < r; p++) {
                right[i][j] += trees[p].query(1, lst[i][j]);
            }
            for (ll p = i + 1; p < r; p++) {
                right[i][j] += trees[i].query(lst[p][j], r * c);
            }
            trees[i].update(lst[i][j], 1);
        }
    }

    // for (auto i : right) {
    //     cout << i << endl;
    // }

    for (ll p = 0; p < r; p++) {
        Fenwick tree(r * c);
        for (ll j = c - 1; j >= 0; j--) {
            for (ll i = r - 1; i >= p; i--) {
                down[p][j] += tree.query(1, lst[i][j]);
                tree.update(lst[i][j], 1);
            }
        }
    }

    vector<vector<ll>> dp(r, vector<ll>(c, INF));
    dp[r - 1][c - 1] = 0;
    for (ll i = r - 1; i >= 0; i--) {
        for (ll j = c - 1; j >= 0; j--) {
            if (i + 1 < r) {
                dp[i][j] = min(dp[i][j], dp[i + 1][j] + right[i][j]);
            }
            if (j + 1 < c) {
                dp[i][j] = min(dp[i][j], dp[i][j + 1] + down[i][j]);
            }
        }
    }

    cout << dp[0][0] << endl;
}
