#include <iostream>
#include <vector>

struct Tree
{
  int n;
  std::vector<std::pair<int, int>> tree;

  Tree(const std::vector<int> &a) : n(a.size()), tree(2 * n)
  {
    for (int i = 0; i < n; ++i) {
      tree[i + n] = {a[i], i};
    }
    for (int i = n - 1; i > 0; --i) {
      tree[i] = std::min(tree[2 * i], tree[2 * i + 1]);
    }
  }

  std::pair<int, int> get(int ql, int qr)
  {
    std::pair<int, int> res = {1e9, 1e9};
    for (ql += n, qr += n; ql < qr; ql >>= 1, qr >>= 1) {
      if (ql & 1)
        res = std::min(res, tree[ql++]);
      if (qr & 1)
        res = std::min(res, tree[--qr]);
    }
    return res;
  }
};

struct Tree_M
{
  int n;
  std::vector<std::pair<int, int>> tree;

  Tree_M(const std::vector<int> &a) : n(a.size()), tree(2 * n)
  {
    for (int i = 0; i < n; ++i) {
      tree[i + n] = {a[i], i};
    }
    for (int i = n - 1; i > 0; --i) {
      tree[i] = std::max(tree[2 * i], tree[2 * i + 1]);
    }
  }

  std::pair<int, int> get(int ql, int qr)
  {
    std::pair<int, int> res = {-1, -1};
    for (ql += n, qr += n; ql < qr; ql >>= 1, qr >>= 1) {
      if (ql & 1)
        res = std::max(res, tree[ql++]);
      if (qr & 1)
        res = std::max(res, tree[--qr]);
    }
    return res;
  }
};

void solve()
{
  int n, q;
  std::cin >> n >> q;
  std::vector<int> a(n);
  for (int i = 0; i < n; ++i)
    std::cin >> a[i];
  std::vector<int> nxt(n, n), stack;
  for (int i = 0; i < n; ++i) {
    while (!stack.empty() && a[stack.back()] < a[i]) {
      nxt[stack.back()] = i;
      stack.pop_back();
    }
    stack.push_back(i);
  }
  stack.clear();
  Tree tree(a);
  Tree_M tree_m(a);
  int r1 = std::min(nxt[0], n - 2);
  int res1 = a[0];
  int r2 = r1 == 1 ? 1 : tree.get(0, r1).second;
  if (nxt[r2] == n)
    nxt[r2]--;
  int res2 = -1;
  for (int i = r2; i < nxt[r2]; ++i) {
    res2 = std::max(res2, a[i]);
  }
  int res3 = -1;
  for (int i = nxt[r2]; i < n; ++i) {
    res3 = std::max(res3, a[i]);
  }
  for (; q > 0; --q) {
    int k, i;
    std::cin >> k >> i;
    if (i == 1)
      std::cout << res1 << '\n';
    else if (i == 2)
      std::cout << res2 << '\n';
    else
      std::cout << res3 << '\n';
  }
}

int main()
{
  int t = 1;
#ifdef LOCAL
  freopen("in/d.txt", "r", stdin);
  freopen("out/d.txt", "w", stdout);
  std::cin >> t;
#else
  std::ios_base::sync_with_stdio(false);
  std::cin.tie(nullptr);
#endif
  for (int i_t = 0; i_t < t; ++i_t) {
#ifdef LOCAL
    std::cout << "Test case: " << i_t + 1 << '\n';
#endif
    solve();
  }
  std::cout.flush();
  return 0;
}