#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>

using namespace std;
using namespace __gnu_pbds;

#define int long long
#define all(a) (a).begin(), (a).end()
#define rall(a) (a).rbegin(), (a).rend()

template<typename T>
using indexed_set = tree<T, null_type, less<>, rb_tree_tag, tree_order_statistics_node_update>;

struct Fenwick {
    int n;
    vector<int> a;
    Fenwick(int _n = 0) : n(_n), a(n) {}
    void add(int i, int x) {
        for (i++; i <= n; i += i & -i) {
            a[i - 1] += x;
        }
    }
    int sum(int i) {
        int res = 0;
        for (; i > 0; i -= i & -i) {
            res += a[i - 1];
        }
        return res;
    }
    int sum(int l, int r) {
        return sum(r) - sum(l);
    }
};

void solve_case() {
    int r, c; cin >> r >> c;
    vector a(r, vector<int>(c));
    for (int i = 0; i < r; i++) {
        for (int j = 0; j < c; j++) {
            cin >> a[i][j];
            a[i][j]--;
        }
    }
    vector<Fenwick> row_set(r + 1, Fenwick(r * c)), col_set(c + 1, Fenwick(r * c));
    for (int i = 0; i < r; i++) {
        row_set[i + 1] = row_set[i];
        for (int j = 0; j < c; j++) {
            row_set[i + 1].add(a[i][j], 1);
        }
    }
    for (int j = 0; j < c; j++) {
        col_set[j + 1] = col_set[j];
        for (int i = 0; i < r; i++) {
            col_set[j + 1].add(a[i][j], 1);
        }
    }
    vector row_add(r, vector<int>(c)), col_add(r, vector<int>(c));
    for (int i = 0; i < r; i++) {
        for (int j = 0; j < c; j++) {
            row_add[i][j] += row_set[i].sum(a[i][j] + 1, r * c);
        }
    }
    for (int j = 0; j < c; j++) {
        for (int i = 0; i < r; i++) {
            col_add[i][j] += col_set[j].sum(a[i][j] + 1, r * c);
        }
    }
    vector row_dec(r, vector<int>(c)), col_dec(r, vector<int>(c));
    {
        Fenwick st(r * c);
        for (int r1 = 0; r1 < r; r1++) {
            for (int c1 = 0; c1 < c; c1++) {
                for (int j = c1; j < c; j++) {
                    row_dec[r1][c1] += st.sum(a[r1][j] + 1, r * c);
                }
                for (int i = r1; i < r; i++) {
                    col_dec[r1][c1] += st.sum(a[i][c1] + 1, r * c);
                }
                for (int i = 0; i < r1; i++) {
                    st.add(a[i][c1], 1);
                }
            }
            for (int c1 = 0; c1 < c; c1++) {
                for (int i = 0; i < r1; i++) {
                    st.add(a[i][c1], -1);
                }
            }
        }
    }
    const int inf = 1e18;
    vector dp(r + 1, vector<int>(c + 1, inf));
    dp[0][0] = 0;
    for (int r1 = 0; r1 < r; r1++) {
        for (int c1 = 0; c1 < c; c1++) {
            // dp[r1][c1] -> dp[r1+1][c1]
            {
                int add = 0;
                indexed_set<int> st;
                for (int j = c1; j < c; j++) {
                    add += row_add[r1][j];
                    add += col_set[c1].sum(a[r1][j] + 1, r * c);
                    add += (int) st.size() - st.order_of_key(a[r1][j]);
                    st.insert(a[r1][j]);
                }
                add -= row_dec[r1][c1];
                dp[r1 + 1][c1] = min(dp[r1 + 1][c1], dp[r1][c1] + add);
            }
            // dp[r1][c1] -> dp[r1][c1+1]
            {
                int add = 0;
                indexed_set<int> st;
                for (int i = r1; i < r; i++) {
                    add += col_add[i][c1];
                    add += row_set[r1].sum(a[i][c1] + 1, r * c);
                    add += (int) st.size() - st.order_of_key(a[i][c1]);
                    st.insert(a[i][c1]);
                }
                add -= col_dec[r1][c1];
                dp[r1][c1 + 1] = min(dp[r1][c1 + 1], dp[r1][c1] + add);
            }
        }
    }
    int ans = inf;
    for (int j = 0; j < c; j++) {
        ans = min(ans, dp[r][j]);
    }
    for (int i = 0; i < r; i++) {
        ans = min(ans, dp[i][c]);
    }
    cout << ans << '\n';
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int t = 1;
    // cin >> t;
    while (t--) {
        solve_case();
    }
}