#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>
#include <set>
#include <map>

using namespace std;

using ll = long long;

struct node {
	node* left = nullptr;
	node* right = nullptr;
	ll x = 0;

	node* clone() {
		node* nw = new node();
		nw->left = left;
		nw->right = right;
		nw->x = x;
		return nw;
	}

	node* get_left() {
		if (left == nullptr) left = new node();
		return left;
	}

	node* get_right() {
		if (right == nullptr) right = new node();
		return right;
	}

	void recalc() {
		x = get_left()->x + get_right()->x;
	}

	ll get(ll l, ll r, ll ql, ll qr) {
		if (l >= ql && r <= qr) return x;
		if (l >= qr || r <= ql) return 0;
		ll m = (l + r) / 2;
		return get_left()->get(l, m, ql, qr) + get_right()->get(m, r, ql, qr);
	}

	node* inc(ll l, ll r, ll id) {
		node* n = clone();
		if (r - l == 1) {
			n->x++;
			return n;
		}
		ll m = (l + r) / 2;
		if (id < m) n->left = n->get_left()->inc(l, m, id);
		else n->right = n->get_right()->inc(m, r, id);
		n->recalc();
		return n;
	}
};

const ll MAXRC = 10010;

ll invCnt(vector<ll> vec) {
	node* st = new node();
	ll ans = 0;
	for (auto p : vec) {
		ans += st->get(0, MAXRC, p, 1e18);
		st = st->inc(0, MAXRC, p);
	}
	return ans;
}

int main() {
	node* segmentTree = new node();
	ll r, c; cin >> r >> c;
	vector<vector<ll>> vec(r, vector<ll>(c));
	for (int i = 0; i < r; i++) {
		for (int j = 0; j < c; j++) {
			cin >> vec[i][j];
		}
	}
	if (r * c * (r + c) * 20 <= 1e8) {
		vector<vector<node*>> trees(r + 1, vector<node*>(c + 1, segmentTree));
		for (int i = r - 1; i >= 0; i--) {
			for (int j = c - 1; j >= 0; j--) {
				node* st = trees[i][j + 1];
				for (int ni = i; ni < r; ni++) {
					st = st->inc(0, MAXRC, vec[ni][j]);
				}
				trees[i][j] = st;
			}
		}
		vector<vector<ll>> dp(r + 1, vector<ll>(c + 1, 0));
		for (int i = r - 1; i >= 0; i--) {
			for (int j = c - 1; j >= 0; j--) {
				ll ans = 1e18;
				node* st;
				ll lans;
				vector<node*> newNodes;

				st = trees[i][j + 1];
				lans = dp[i][j + 1];
				for (int ni = r - 1; ni >= i; ni--) {
					lans += st->get(0, MAXRC, 0, vec[ni][j]);
					st = st->inc(0, MAXRC, vec[ni][j]);
					newNodes.push_back(st);
				}
				ans = min(ans, lans);

				st = trees[i + 1][j];
				lans = dp[i + 1][j];
				for (int nj = c - 1; nj >= j; nj--) {
					lans += st->get(0, MAXRC, 0, vec[i][nj]);
					st = st->inc(0, MAXRC, vec[i][nj]);
					newNodes.push_back(st);
				}
				ans = min(ans, lans);
				dp[i][j] = ans;
			}
		}
		cout << dp[0][0] << endl;
		return 0;
	}
	ll i = 0, j = 0;
	vector<ll> ans;
	while (i < r && j < c) {
		vector<ll> v1, v2;
		for (int t = i; t < r; t++) v1.push_back(vec[t][j]);
		for (int t = j; t < c; t++) {
			v1.push_back(vec[i][t]);
			v2.push_back(vec[i][t]);
		}
		for (int t = i; t < r; t++) v2.push_back(vec[t][j]);
		ll c1 = invCnt(v1), c2 = invCnt(v2);
		if (c1 < c2) {
			for (int t = i; t < r; t++) ans.push_back(vec[t][j]);
			j++;
		}
		else {
			for (int t = j; t < c; t++) ans.push_back(vec[i][t]);
			i++;
		}
	}
	cout << invCnt(ans) << endl;
}