#include <iostream>
#include <set>
#include <vector>
#include <ext/pb_ds/assoc_container.hpp>

using namespace std;
using namespace __gnu_pbds;

typedef long long ll;

const int INF = 1e9;

struct Point {
    ll x, y;

    Point(ll x = 0, ll y = 0) : x(x), y(y) {}

    bool operator<(const Point &pt) const {
        return x < pt.x || (x == pt.x && y < pt.y);
    }

    bool operator==(const Point &pt) const {
        return x == pt.x && y == pt.y;
    }
};

ll get_sqr_dist(const Point &a, const Point &b) {
    ll dx = a.x - b.x;
    ll dy = a.y - b.y;
    return dx * dx + dy * dy;
}

struct Node {
    int p;

    Node(int p = INF) : p(p) {}

    Node operator+(const Node &node) const {
        return min(p, node.p);
    }
};

struct SegmentTree {
    vector<Node> data;

    SegmentTree(int n) : data(4 * n) {}

    Node get(int v, int l, int r, int lq, int rq) {
        if (rq <= l || r <= lq) {
            return {};
        }
        if (lq <= l && r <= rq) {
            return data[v];
        }
        int m = (l + r) / 2;
        auto p1 = get(2 * v + 1, l, m, lq, rq);
        auto p2 = get(2 * v + 2, m, r, lq, rq);
        return p1 + p2;
    }

    void update(int v, int l, int r, int p, int x) {
        if (l + 1 == r) {
            data[v] = x;
            return;
        }
        int m = (l + r) / 2;
        if (p < m) {
            update(2 * v + 1, l, m, p, x);
        } else {
            update(2 * v + 2, m, r, p, x);
        }
        data[v] = data[2 * v + 1] + data[2 * v + 2];
    }
};

int main() {
    ios_base::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    int n, r;
    cin >> n >> r;
    vector<Point> pts(n);
    for (int i = 0; i < n; ++i) {
        auto &[x, y] = pts[i];
        cin >> x >> y;
    }

    vector<int> id(n);
    vector<Point> a = pts;
    sort(a.begin(), a.end());
    a.resize(unique(a.begin(), a.end()) - a.begin());
    gp_hash_table<int, int> mp;
    for (int i = 0; i < n; ++i) {
        id[i] = lower_bound(a.begin(), a.end(), pts[i]) - a.begin();
        //cout << i << ' ' << id[i] << endl;
        mp[id[i]] = i;
    }

    SegmentTree tree(n);
    vector<SegmentTree> g(2, SegmentTree(n));
    for (int i = 0; i < n; ++i) {
        tree.update(0, 0, n, id[i], i);
    }
    /*for (int i = 0; i < n; ++i) {
        cout << tree.get(0, 0, n, i, i + 1).p << ' ';
    }
    cout << endl;*/
    vector<int> col(n, -1);
    auto dfs = [&] (auto &&self, int v, int c) -> bool {
        col[v] = c;
        tree.update(0, 0, n, id[v], INF);
        /*for (int i = 0; i < n; ++i) {
            cout << tree.get(0, 0, n, i, i + 1).p << ' ';
        }
        cout << endl;*/
        int left = int(lower_bound(a.begin(), a.end(), Point{pts[v].x - r, 0}) - a.begin());
        int right = int(upper_bound(a.begin(), a.end(), Point{pts[v].x + r, 0}) - a.begin());
        while (true) {
            auto u = tree.get(0, 0, n, left, right);
            if (u.p == INF) {
                break;
            }
            //cout << v << ' ' << u.p << endl;
            self(self, u.p, c ^ 1);
        }
        bool find = (g[c & 1].get(0, 0, n, left, right).p != INF);
        g[c & 1].update(0, 0, n, id[v], id[v]);
        return find;
    };
    vector<int> f;
    for (int v = 0; v < n; ++v) {
        if (col[v] == -1) {
            bool find = dfs(dfs, v, 2 * (int) f.size());
            f.emplace_back(find);
        }
    }
    for (int v = 0; v < n; ++v) {
        cout << f[col[v] / 2];
    }
    cout << '\n';
    return 0;
}
