#include <iostream>
#include <set>
#include <vector>

using namespace std;

typedef long long ll;

const int INF = 2e9;

struct Fenwick {
    vector<int> f;

    Fenwick(int n) : f(n + 1) {}

    void add(int p, int x) {
        while (p < (int) f.size()) {
            f[p] += x;
            p += p & -p;
        }
    }

    int get(int p) {
        int ans = 0;
        while (p > 0) {
            ans += f[p];
            p -= p & -p;
        }
        return ans;
    }
};

int main() {
    ios_base::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    int r, c;
    cin >> r >> c;
    vector<vector<int>> a(r, vector<int> (c));
    for (auto &i : a) {
        for (int &j : i) {
            cin >> j;
        }
    }
    vector<vector<int>> dp(r + 1, vector<int> (c + 1, INF));
    dp[0][0] = 0;
    vector<vector<Fenwick>> f(r + 1, vector<Fenwick> (c + 1, r * c + 1));
    vector<vector<int>> s(r + 1, vector<int> (c + 1));
    for (int i = 0; i < r; ++i) {
        for (int j = 0; j < c; ++j) {
            {
                int x = 0;
                f[i][j + 1] = f[i][j];
                s[i][j + 1] = s[i][j];
                //cout << dp[i][j] << endl;
                for (int k = i; k < r; ++k) {
                    x += s[i][j + 1] - f[i][j + 1].get(a[k][j]);
                    //cout << i << ' ' << j << ' ' << k << ' ' << a[k][j] << ' ' << s[i][j + 1] - f[i][j + 1].get(a[k][j]) << ' ' << x << endl;
                    f[i][j + 1].add(a[k][j], 1);
                    s[i][j + 1]++;
                }
                dp[i][j + 1] = min(dp[i][j + 1], dp[i][j] + x);
            }
            {
                int x = 0;
                f[i + 1][j] = f[i][j];
                s[i + 1][j] = s[i][j];
                for (int k = j; k < c; ++k) {
                    x += s[i + 1][j] - f[i + 1][j].get(a[i][k]);
                    f[i + 1][j].add(a[i][k], 1);
                    s[i + 1][j]++;
                }
                dp[i + 1][j] = min(dp[i + 1][j], dp[i][j] + x);
            }
            //cout << endl;
        }
    }
    /*for (auto &i : dp) {
        for (auto &j : i) {
            cout << j << ' ';
        }
        cout << '\n';
    }*/
    dp[r][c] = min(dp[r - 1][c], dp[r][c - 1]);
    cout << dp[r][c] << '\n';
    return 0;
}
