#include <iostream>
#include <vector>
#include <map>
#include <unordered_map>
#include <random>
using namespace std;

mt19937 rnd(5252343);

#define int long long

struct DSU {
	int n;
	vector <int> p;
	vector <int> sz;
	vector <int> col;
	vector <bool> bad;

	DSU(int n) {
		this->n = n;
		p.resize(n);
		for (int i = 0; i < n; i++) {
			p[i] = i;
		}
		sz.resize(n, 1);
		col.resize(n);
		bad.resize(n);
	}

	pair <int, int> get(int x) {
		if (p[x] == x) return { p[x], col[x] };
		auto [ppar, pcol] = get(p[x]);
		p[x] = ppar;
		col[x] ^= pcol;
		return { p[x], col[x] };
	}

	bool merge(int x, int y) {
		auto [xpar, xcol] = get(x);
		auto [ypar, ycol] = get(y);
		if (bad[xpar] || bad[ypar]) {
			bad[xpar] = bad[ypar] = 1;
			return 0;
		}
		if (xpar == ypar) {
			if (xcol == ycol) {
				bad[xpar] = 1;
				return 0;
			}
			return 1;
		}
		if (sz[xpar] > sz[ypar]) {
			swap(xpar, ypar);
		}
		p[xpar] = ypar;
		col[xpar] ^= col[ypar];
		if (xcol == ycol) {
			col[xpar] ^= 1;
		}
		return 1;
	}

	bool isbad(int x) {
		auto [par, col] = get(x);
		return bad[par];
	}
};

bool check(pair <int, int> a, pair <int, int> b, int r) {
	return
		(a.first - b.first) * (a.first - b.first) +
		(a.second - b.second) * (a.second - b.second)
		<= r * r;
}

signed main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	int n, r;
	cin >> n >> r;

	vector <pair <int, int>> deltas;
	for (int i = 0; i <= 10; i++) {
		for (int j = -10; j <= 10; j++) {
			if (i == 0 && j == 0) continue;
			if (i * i + j * j <= r * r) {
				deltas.push_back({ i, j });
			}
		}
	}

	vector <pair <int, int>> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i].first >> a[i].second;
	}

	DSU dsu(n);
	for (int att = 0; att < 10000000; att++) {
		int i = rnd() % (n - 1) + 1;
		int j = rnd() % n;
		if (i == j) continue;
		if (check(a[i], a[j], r)) {
			dsu.merge(i, j);
		}
	}

	int sqr = r / 2;
	map <pair <int, int>, int> cnt1;
	map <pair <int, int>, int> cnt2;
	for (int i = 0; i < n; i++) {
		auto [x, y] = a[i];
		cnt1[{x / sqr, y / sqr}]++;
		cnt2[{(x + sqr / 2) / sqr, (y + sqr / 2) / sqr}]++;
	}

	for (int i = 0; i < n; i++) {
		if (dsu.isbad(i)) {
			cout << 1;
			continue;
		}
		auto [x, y] = a[i];
		if (cnt1[{x / sqr, y / sqr}] >= 3) {
			dsu.bad[dsu.get(i).first] = 1;
		}
		if (cnt2[{(x + sqr / 2) / sqr, (y + sqr / 2) / sqr}] >= 3) {
			dsu.bad[dsu.get(i).first] = 1;
		}
		if (dsu.isbad(i)) {
			cout << 1;
			continue;
		}
		for (int att = 0; att < 1000; att++) {
			int j = rnd() % n;
			if (i == j) continue;
			if (check(a[i], a[j], r)) {
				if (!dsu.merge(i, j)) break;
			}
		}
		cout << dsu.isbad(i);
	}
}