#include <iostream>
#include <vector>
#include <map>
#include <unordered_map>
#include <random>
#include <algorithm>
#include <cmath>
using namespace std;

mt19937 rnd(5252343);

#define int long long

struct DSU {
	int n;
	vector <int> p;
	vector <int> sz;
	vector <int> col;
	vector <bool> bad;

	DSU(int n) {
		this->n = n;
		p.resize(n);
		for (int i = 0; i < n; i++) {
			p[i] = i;
		}
		sz.resize(n, 1);
		col.resize(n);
		bad.resize(n);
	}

	pair <int, int> get(int x) {
		if (p[x] == x) return { p[x], col[x] };
		auto [ppar, pcol] = get(p[x]);
		p[x] = ppar;
		col[x] ^= pcol;
		return { p[x], col[x] };
	}

	bool merge(int x, int y) {
		auto [xpar, xcol] = get(x);
		auto [ypar, ycol] = get(y);
		if (bad[xpar] || bad[ypar]) {
			bad[xpar] = bad[ypar] = 1;
			return 0;
		}
		if (xpar == ypar) {
			if (xcol == ycol) {
				bad[xpar] = 1;
				return 0;
			}
			return 1;
		}
		if (sz[xpar] > sz[ypar]) {
			swap(xpar, ypar);
		}
		p[xpar] = ypar;
		col[xpar] ^= col[ypar];
		if (xcol == ycol) {
			col[xpar] ^= 1;
		}
		return 1;
	}

	bool isbad(int x) {
		auto [par, col] = get(x);
		return bad[par];
	}
};

struct crd {
	int x, y, ind;
};

bool check(crd a, crd b, int r) {
	return
		(a.x - b.x) * (a.x - b.x) +
		(a.y - b.y) * (a.y - b.y)
		<= r * r;
}

bool operator<(crd a, crd b) {
	return make_pair(a.x, a.y) < make_pair(b.x, b.y);
}

signed main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	int n, r;
	cin >> n >> r;

	vector <crd> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i].x >> a[i].y;
		a[i].ind = i;
	}

	DSU dsu(n);

	sort(a.begin(), a.end());

	for (int i = 0; i < n; i++) {
		for (int j = i - 5; j < i; j++) {
			if (j < 0) continue;
			if (check(a[j], a[i], r)) {
				dsu.merge(a[i].ind, a[j].ind);
			}
		}
	}

	for (int i = 0; i < n; i++) {
		cout << dsu.isbad(i);
	}
}