#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

#define int long long
const int oo = 1e18;

struct SegmentTree {
	vector <int> t;
	int n;

	SegmentTree(int n) {
		this->n = n;
		t.resize(4 * n);
	}

	void add(int v, int l, int r, int pos, int x) {
		t[v] += x;
		if (l + 1 == r) return;
		int m = (l + r) / 2;
		if (pos < m) {
			add(v * 2 + 1, l, m, pos, x);
		}
		else {
			add(v * 2 + 2, m, r, pos, x);
		}
	}

	void add(int pos, int x) {
		add(0, 0, n, pos, x);
	}

	int get(int v, int l, int r, int ql, int qr) {
		if (qr <= l || r <= ql) return 0;
		if (ql <= l && r <= qr) return t[v];
		int m = (l + r) / 2;
		return
			get(v * 2 + 1, l, m, ql, qr) +
			get(v * 2 + 2, m, r, ql, qr);
	}

	int get(int ql, int qr) {
		return get(0, 0, n, ql, qr);
	}
};

signed main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);

	int n, m;
	cin >> n >> m;
	vector <vector <int>> a(n, vector <int>(m));
	for (int i = 0; i < n; i++) {
		for (int j = 0; j < m; j++) {
			cin >> a[i][j];
		}
	}

	int mxmask = 1 << (max(n, m) + 1);

	int answer = +oo;
	for (int mask = 0; mask < mxmask; mask++) {
		int ci = 0;
		int cj = 0;
		int cmask = mask;
		SegmentTree dero(n + 10);
		int curr = 0;
		while (ci < n && cj < m) {
			if (cmask % 2 == 0) {
				for (int i = ci; i < n; i++) {
					curr += dero.get(a[i][cj], +oo);
					dero.add(a[i][cj], 1);
				}
				cj++;
			}
			if (cmask % 2 == 1) {
				for (int j = cj; j < m; j++) {
					curr += dero.get(a[ci][j], +oo);
					dero.add(a[ci][j], 1);
				}
				ci++;
			}
			cmask /= 2;
		}
		answer = min(answer, curr);
	}
	cout << answer;
}