#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

const int oo = 1e9;

struct Query {
	int k, ti, ind;
};

bool operator<(Query a, Query b) {
	if (a.k == b.k) return a.ti < b.ti;
	return a.k > b.k;
}

struct SegmentTree {
	vector <int> t;
	int n;

	SegmentTree(int n) {
		this->n = n;
		t.resize(4 * n, +oo);
	}
	
	SegmentTree(vector <int>& a) {
		this->n = a.size();
		t.resize(4 * n, +oo);
		build(0, 0, n, a);
	}

	void build(int v, int l, int r, vector <int>& a) {
		if (l + 1 == r) {
			t[v] = a[l];
			return;
		}
		int m = (l + r) / 2;
		build(v * 2 + 1, l, m, a);
		build(v * 2 + 2, m, r, a);
		t[v] = min(t[v * 2 + 1], t[v * 2 + 2]);
	}

	void set(int v, int l, int r, int pos, int x) {
		if (l + 1 == r) {
			t[v] = x;
			return;
		}
		int m = (l + r) / 2;
		if (pos < m) {
			set(v * 2 + 1, l, m, pos, x);
		}
		else {
			set(v * 2 + 2, m, r, pos, x);
		}
		t[v] = min(t[v * 2 + 1], t[v * 2 + 2]);
	}

	void set(int pos, int x) {
		set(0, 0, n, pos, x);
	}

	int get(int v, int l, int r, int ql, int qr) {
		if (qr <= l || r <= ql) return +oo;
		if (ql <= l && r <= qr) return t[v];
		int m = (l + r) / 2;
		return min(
			get(v * 2 + 1, l, m, ql, qr),
			get(v * 2 + 2, m, r, ql, qr)
		);
	}

	int get(int ql, int qr) {
		return get(0, 0, n, ql, qr);
	}
};

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);

	int n, q;
	cin >> n >> q;
	vector <int> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i];
	}

	vector <int> bypos(n + 1);
	for (int i = 0; i < n; i++) {
		bypos[a[i]] = i;
	}

	vector <int> suffmax(n + 1);
	for (int i = n - 1; i >= 0; i--) {
		suffmax[i] = max(suffmax[i + 1], a[i]);
	}

	vector <pair <int, int>> qs;
	vector <int> diffk;
	for (int i = 0; i < q; i++) {
		int k, ti;
		cin >> k >> ti;
		ti--;
		qs.push_back({ k, ti });
		diffk.push_back(k);
	}

	sort(diffk.begin(), diffk.end());
	diffk.resize(unique(diffk.begin(), diffk.end()) - diffk.begin());

	SegmentTree dero(a);

	vector <pair <int, int>> st;
	vector <int> rgh(n);
	st.push_back({ +oo, n });
	for (int i = n - 1; i >= 0; i--) {
		while (st.size() && st.back().first <= a[i]) {
			st.pop_back();
		}
		rgh[i] = st.back().second;
		st.push_back({ a[i], i });
	}

	vector <vector <int>> ans(n + 1);
	for (auto ck : diffk) {
		vector <int> cres;
		int rst = n - ck;
		int i = 0;
		cres.push_back(a[i]);
		while (i < n - 1) {
			int mnval = a[i];
			int mnj = i + 1;
			if (cres.size() + 1 < ck) {
				int lb = i + 1;
				int rb = min(n, min(i + rst + 2, rgh[i]));
				if (lb < rb) {
					mnval = dero.get(lb, rb);
					mnj = bypos[mnval];
				}
				rst -= mnj - i - 1;
				i = mnj;
				cres.push_back(a[i]);
			}
			else {
				for (int j = i + 1; j < min(n, i + rst + 2); j++) {
					if (a[j] > a[i]) break;
					int caj = suffmax[j];
					if (caj < mnval) {
						mnval = caj;
						mnj = j;
					}
				}
				rst -= mnj - i - 1;
				i = mnj;
				cres.push_back(suffmax[mnj]);
			}
		}
		i = cres.size();
		while (i > ck) {
			cres[i - 2] = max(cres[i - 2], cres[i - 1]);
			i--;
		}
		ans[ck] = cres;
	}

	for (auto p : qs) {
		cout << ans[p.first][p.second] << '\n';
	}
}
