#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <unordered_map>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<lng>(x->size())

using lng = long long;

struct DSU {
	int N;
	vector<int> boss, size;
	DSU(int n = 1) : N(n), boss(n), size(n, 1) {
		iota(all(boss), 0);
	}
	int get(int v) {
		if (boss[v] == v) {
			return v;
		}
		boss[v] = get(boss[v]);
		return boss[v];
	}
	void unite(int v, int u) {
		v = get(v), u = get(u);
		if (v == u) {
			return;
		}
		if (size[v] < size[u]) {
			swap(v, u);
		}
		boss[u] = v;
		size[v] += size[u];
	}
};

lng get_dist(int i, int j, const vector<pair<lng, lng>>& pts) {
	return (pts[i].first - pts[j].first) * (pts[i].first - pts[j].first) + (pts[i].second - pts[j].second) * (pts[i].second - pts[j].second);
}

void solve() {
	lng n, r; cin >> n >> r;
	vector<pair<lng, lng>> points(n);
	for (pair<lng, lng>& p : points) {
		cin >> p.first >> p.second;
		p.first *= 2ll;
		p.second *= 2ll;
	}
	lng grid_sz = r;
	r *= 2ll;
	unordered_map<lng, vector<int>*> grid;
	for (int i = 0; i < n; i++) {
		lng gx = points[i].first / grid_sz, gy = points[i].second / grid_sz;
		if (grid.find((gx << 30) | gy) == grid.end()) {
			grid[(gx << 30) | gy] = new vector<int>{};
		}
		grid[(gx << 30) | gy]->push_back(i);
	}
	DSU d(2 * n);
	for (const auto& cell : grid) {
		lng gx = (cell.first >> 30);
		lng gy = (cell.first & ((1ll << 30) - 1ll));
		vector<int>* plist = cell.second;
		if (sz(plist) > 2) {
			for (auto it = plist->begin(); it != plist->end(); it++) {
				int id = *it;
				d.unite(2 * id, 2 * id + 1);
				d.unite(2 * id, 2 * plist->at(0));
			}
		}
		else if (sz(plist) == 2) {
			d.unite(2 * plist->at(0), 2 * plist->at(1) + 1);
			d.unite(2 * plist->at(1), 2 * plist->at(0) + 1);
		}
	}
	for (const auto& cell : grid) {
		lng gx = (cell.first >> 30);
		lng gy = (cell.first & ((1ll << 30) - 1ll));
		vector<int>* plist = cell.second;
		for (lng dx = -2; dx <= 2; dx++) {
			for (lng dy = -2; dy <= 2; dy++) {
				if (abs(dx) + abs(dy) == 0ll) {
					continue;
				}
				lng cid = (((gx + dx) << 30) | (gy + dy));
				if (grid.find(cid) == grid.end()) {
					continue;
				}
				for (auto it1 = plist->begin(); it1 != plist->end(); it1++) {
					int id1 = *it1;
					for (auto it2 = grid[cid]->begin(); it2 != grid[cid]->end(); it2++) {
						int id2 = *it2;
						if (get_dist(id1, id2, points) <= r * r) {
							if (sz(plist) > 2 && sz(grid[cid]) > 2) {
								d.unite(2 * id1, 2 * id2);
							}
							else if (sz(plist) > 2) {
								d.unite(2 * id1, 2 * id2);
								d.unite(2 * id1, 2 * id2 + 1);
							}
							else if (sz(grid[cid]) > 2) {
								d.unite(2 * id1, 2 * id2);
								d.unite(2 * id1 + 1, 2 * id2);
							}
							else {
								d.unite(2 * id1, 2 * id2 + 1);
								d.unite(2 * id1 + 1, 2 * id2);
							}
						}
					}
				}
			}
		}
	}
	for (int i = 0; i < n; i++) {
		if (d.get(2 * i) == d.get(2 * i + 1)) {
			cout << 1;
		}
		else {
			cout << 0;
		}
	}
}

int main() {
	cin.tie(nullptr)->sync_with_stdio(false);
	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
	}
	return 0;
}

/*
6 5
4 1
4 4
1 5
5 9
9 6
10 2
*/