#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <unordered_map>
#include <cmath>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<lng>(x->size())
#define Vec(a, b) (b - a)

using lng = long long;

struct Point {
	lng X, Y;
	Point(lng x = 0, lng y = 0) : X(x), Y(y) {}
	bool operator< (Point other) {
		if (Y != other.Y) {
			return (Y < other.Y);
		} 
		return (X < other.X);
	}
	lng len2() {
		return X * X + Y * Y;
	}
	Point operator- (Point other) {
		return Point(X - other.X, Y - other.Y);
	}
	lng operator% (Point other) {
		return X * other.Y - Y * other.X;
	}
};

struct Hull {
	vector<Point> hull;
	int m;
	Hull(vector<pair<lng, lng>>& tmp) : hull(0), m(0) {
		vector<Point> pts;
		for (auto& p : tmp) {
			pts.emplace_back(p.first, p.second);
		}
		int pos = min_element(all(pts)) - pts.begin();
		swap(pts[0], pts[pos]);
		sort(all(pts), [&](Point a, Point b) {
			lng cross = Vec(pts[0], a) % Vec(pts[0], b);
			if (cross != 0ll) {
				return (cross > 0ll);
			}
			return (Vec(pts[0], a).len2() < Vec(pts[0], b).len2());
		});
		for (Point& p : pts) {
			while (m >= 2 && Vec(hull[m - 2], hull[m - 1]) % Vec(hull[m - 1], p) <= 0ll) {
				hull.pop_back();
				m--;
			}
			hull.push_back(p);
			m++;
		}
	}
	lng get_near(Point q) {
		const int lg = static_cast<int>(ceil(log2(m + 1)));
		int a = 0;
		lng da = Vec(q, hull[0]).len2();
		for (int k = lg - 1; k >= 0; k--) {
			int b = (a + (1 << k)) % m;
			int c = (a - (1 << k) + 4 * k) % m;
			lng db = Vec(q, hull[b]).len2();
			lng dc = Vec(q, hull[c]).len2();
			if (min({ da, db, dc }) == db) {
				a = b;
				da = db;
			}
			else if (min({ da, db, dc }) == dc) {
				a = c;
				da = dc;
			}
		}
		return da;
	}
};

struct DSU {
	int N;
	vector<int> boss, size;
	DSU(int n = 1) : N(n), boss(n), size(n, 1) {
		iota(all(boss), 0);
	}
	int get(int v) {
		if (boss[v] == v) {
			return v;
		}
		boss[v] = get(boss[v]);
		return boss[v];
	}
	void unite(int v, int u) {
		v = get(v), u = get(u);
		if (v == u) {
			return;
		}
		if (size[v] < size[u]) {
			swap(v, u);
		}
		boss[u] = v;
		size[v] += size[u];
	}
};

lng get_dist(int i, int j, const vector<pair<lng, lng>>& pts) {
	return (pts[i].first - pts[j].first) * (pts[i].first - pts[j].first) + (pts[i].second - pts[j].second) * (pts[i].second - pts[j].second);
}

void solve() {
	lng n, r; cin >> n >> r;
	vector<pair<lng, lng>> points(n);
	for (pair<lng, lng>& p : points) {
		cin >> p.first >> p.second;
		p.first *= 2ll;
		p.second *= 2ll;
	}
	lng grid_sz = r;
	r *= 2ll;
	unordered_map<lng, vector<int>*> grid;
	unordered_map<lng, Hull*> hulls;
	for (int i = 0; i < n; i++) {
		lng gx = points[i].first / grid_sz, gy = points[i].second / grid_sz;
		if (grid.find((gx << 30) | gy) == grid.end()) {
			grid[(gx << 30) | gy] = new vector<int>{};
		}
		grid[(gx << 30) | gy]->push_back(i);
	}
	DSU d(2 * n);
	for (const auto& cell : grid) {
		lng gx = (cell.first >> 30);
		lng gy = (cell.first & ((1ll << 30) - 1ll));
		vector<int>* plist = cell.second;
		if (sz(plist) > 2) {
			vector<pair<lng, lng>> tmppts;
			for (auto it = plist->begin(); it != plist->end(); it++) {
				int id = *it;
				tmppts.push_back(points[id]);
				d.unite(2 * id, 2 * id + 1);
				d.unite(2 * id, 2 * plist->at(0));
			}
			hulls[(gx << 30) | gy] = new Hull(tmppts);
		}
		else if (sz(plist) == 2) {
			d.unite(2 * plist->at(0), 2 * plist->at(1) + 1);
			d.unite(2 * plist->at(1), 2 * plist->at(0) + 1);
		}
	}
	for (const auto& cell : grid) {
		lng gx = (cell.first >> 30);
		lng gy = (cell.first & ((1ll << 30) - 1ll));
		vector<int>* plist = cell.second;
		for (lng dx = -2; dx <= 2; dx++) {
			for (lng dy = -2; dy <= 2; dy++) {
				if (abs(dx) + abs(dy) == 0ll) {
					continue;
				}
				lng cid = (((gx + dx) << 30) | (gy + dy));
				if (grid.find(cid) == grid.end()) {
					continue;
				}
				if (sz(grid[cid]) > 2) {
					for (auto it1 = plist->begin(); it1 != plist->end(); it1++) {
						int id1 = *it1;
						lng best_dist = hulls[cid]->get_near(Point(points[id1].first, points[id1].second));
						if (best_dist <= r * r) {
							d.unite(2 * id1, 2 * grid[cid]->at(0));
							d.unite(2 * id1 + 1, 2 * grid[cid]->at(0));
						}
					}
				}
				else {
					for (auto it1 = plist->begin(); it1 != plist->end(); it1++) {
						int id1 = *it1;
						for (auto it2 = grid[cid]->begin(); it2 != grid[cid]->end(); it2++) {
							int id2 = *it2;
							if (get_dist(id1, id2, points) <= r * r) {
								if (sz(plist) > 2) {
									d.unite(2 * id1, 2 * id2);
									d.unite(2 * id1, 2 * id2 + 1);
								}
								else {
									d.unite(2 * id1, 2 * id2 + 1);
									d.unite(2 * id1 + 1, 2 * id2);
								}
							}
						}
					}
				}
			}
		}
	}
	for (int i = 0; i < n; i++) {
		if (d.get(2 * i) == d.get(2 * i + 1)) {
			cout << 1;
		}
		else {
			cout << 0;
		}
	}
}

int main() {
	cin.tie(nullptr)->sync_with_stdio(false);
	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
	}
	return 0;
}

/*
6 5
4 1
4 4
1 5
5 9
9 6
10 2
*/