#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <unordered_map>
#include <cmath>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<lng>(x.size())

using lng = long long;
using ull = unsigned long long;

static const int INF = 2e9;
static const ull BASE = 200'039;

struct Sequence {
	int size;
	vector<int> perm;
	vector<ull> pref_hash;
	Sequence(vector<int> p) : size(sz(p)), perm(p), pref_hash(sz(p) + 1, 0) {
		ull P = 1;
		for (int i = 1; i <= sz(p); i++) {
			pref_hash[i] = pref_hash[i - 1] + static_cast<ull>(perm[i - 1]) * P;
			P *= BASE;
		}
	}
	int lcp(Sequence& other) {
		int L = 0, R = min(size, other.size) + 1;
		while (R - L > 1) {
			int M = (L + R) / 2;
			if (pref_hash[M] == other.pref_hash[M]) {
				L = M;
			}
			else {
				R = M;
			}
		}
		return L;
	}
	bool operator<(Sequence other) {
		int l = lcp(other);
		if (l < min(size, other.size)) {
			return (perm[l] < other.perm[l]);
		}
		return (size < other.size);
	}
	Sequence operator+ (Sequence other) {
		copy(all(other.perm), back_inserter(perm));
		return Sequence(perm);
	}
};

#define custom_min(x, y) (x < y ? x : y) 

void solve_good(int n, int q, vector<int> p) {
	for (int t = 0; t < q; t++) {
		int x, y; cin >> x >> y;
		if (x == 1) {
			cout << n << '\n';
		}
		else {
			cout << p[y - 1] << '\n';
		}
	}
}

void solve() {
	int n, q; cin >> n >> q;
	vector<int> p(n);
	for (int& i : p) {
		cin >> i;
	}
	bool flag = true;
	for (int i = 0; i < n; i++) {
		if (i % 2 == 0 && i / 2 + 1 != p[i]) {
			flag = false;
		}
		if (i % 2 == 1 && i / 2 + 1 != n - p[i]) {
			flag = false;
		}
	}
	if (flag) {
		solve_good(n, q, p);
		return;
	}
	vector<pair<int, int>> queries(q);
	int max_k = 0;
	for (int t = 0; t < q; t++) {
		cin >> queries[t].first >> queries[t].second;
		max_k = max(max_k, queries[t].first);
	}
	if (max_k == 2) {
		pair<int, int> ans{ INF, INF };
		vector<int> pref_max(n + 1, -1), suf_max(n + 1, -1);
		for (int i = n - 1; i >= 0; i--) {
			suf_max[i] = max(p[i], suf_max[i + 1]);
		}
		for (int i = 1; i <= n; i++) {
			pref_max[i] = max(p[i - 1], pref_max[i - 1]);
		}
		for (int i = 1; i + 1 < n; i++) {
			ans = min(ans, { pref_max[i], suf_max[i] });
		}
		for (int t = 0; t < q; t++) {
			if (queries[t].first == 1) {
				cout << n << '\n';
			}
			else {
				if (queries[t].second == 1) {
					cout << ans.first;
				}
				else {
					cout << ans.second;
				}
				cout << '\n';
			}
		}
		return;
	}
	vector<vector<int>> seg_max(n, vector<int>(n, -1));
	for (int i = 0; i < n; i++) {
		seg_max[i][i] = p[i];
	}
	for (int l = 2; l <= n; l++) {
		for (int i = 0; i + l - 1 < n; i++) {
			seg_max[i][i + l - 1] = max(seg_max[i][i + l - 2], p[i + l - 1]);
		}
	}
	vector<vector<Sequence>> dp(max_k + 1, vector<Sequence>(n + 1, Sequence({ INF })));
	dp[0][0] = Sequence({ 0 });
	for (int k = 0; k < max_k; k++) {
		for (int l = 0; l < n; l++) {
			for (int r = l; r < n; r++) {
				if (dp[k][n - r - 1].perm[0] == INF) {
					continue;
				}
				if (dp[k][n - l].perm[0] == INF) {
					dp[k + 1][n - l] = Sequence({ seg_max[l][r] }) + dp[k][n - r - 1];
					continue;
				}
				dp[k + 1][n - l] = custom_min(dp[k + 1][n - l], Sequence({seg_max[l][r]}) + dp[k][n - r - 1]);
			}
		}
	}
	for (int t = 0; t < q; t++) {
		cout << dp[queries[t].first][n].perm[queries[t].second - 1] << '\n';
	}
}

int main() {
	cin.tie(nullptr)->sync_with_stdio(false);
	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
	}
	return 0;
}

/*
7 4
6 4 2 3 1 7 5
7 4
1 1
4 2
5 3
*/