#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_map>
#include <stack>
   
using namespace std;
 
 
struct tree{
    vector<long long> tr;
 
    tree() {}
    tree(long long n) {
        tr.resize(n * 4, 0);
    }
     
    void add(long long id, long long l, long long r, long long k) {
        if (r - l == 1) {
            tr[id]++;
            return;
        }
        long long mid = (l + r) / 2;
        if (k < mid) {
            add(id * 2 + 1, l, mid, k);
        } else {
            add(id * 2 + 2, mid, r, k);
        }
        tr[id] = tr[id * 2 + 1] + tr[id * 2 + 2];
    }
 
    long long ask(long long id, long long l, long long r, long long ql, long long qr) {
        if (ql <= l && r <= qr) {
            return tr[id];
        }
        if (r <= ql || qr <= l) {
            return 0;
        }
        long long mid = (l + r) / 2;
        return ask(id * 2 + 1, l, mid, ql, qr) + ask(id * 2 + 2, mid, r, ql, qr);
    }
 
    void clear(long long id, long long l, long long r) {
        if (tr[id] == 0) {
            return;
        }
        if (r - l == 0) {
            tr[id]--;
            return;
        }
        long long mid = (l + r) / 2;
        clear(id, l, mid);
        clear(id, mid, r);
        tr[id] = 0;
    }
};
 
vector<vector<long long>> v;
 
long long calc(long long x, long long l1, long long l2, long long r1, long long r2) {
    long long ans = 0;
    for (long long i = l1; i <= l2; i++) {
        for (long long j = r1; j <= r2; j++) {
            ans += (v[i][j] < x);
        }
    }
    return ans;
}
 
long long sz;
 
long long calc_inv(vector<long long> &v) {
    tree tr(sz);
    long long ans = 0;
    for (long long i = v.size() - 1; i >= 0; i--) {
        long long x = v[i];
        ans += tr.ask(0, 0, sz, 0, x);
        tr.add(0, 0, sz, x);
    }
    return ans;
}
 
vector<long long> calc_inv_v(vector<long long> v) {
    set<long long> st;
    for (auto i : v) {
        st.insert(i);
    }
    map<long long, long long> mp;
    long long it = 1;
    for (auto i : st) {
        mp[i] = it++;
    }
 
    for (long long i = 0; i < v.size(); i++) {
        v[i] = mp[v[i]];
    }
 
    tree tr(it + 10);
    long long ans = 0;
    vector<long long> res;
    for (long long i = v.size() - 1; i >= 0; i--) {
        long long x = v[i];
        ans += tr.ask(0, 0, it + 10, 0, x);
        res.push_back(ans);
        tr.add(0, 0, it + 10, x);
    }
    reverse(res.begin(), res.end());
    return res;
}
   
int main()
{
    cin.tie(0); cout.tie(0); ios_base::sync_with_stdio(false);
    long long r, c;
    cin >> r >> c;
    sz = r * c + 1;
    v.resize(r, vector<long long>(c));
    for (long long i = 0; i < r; i++) {
        for (long long j = 0; j < c; j++) {
            cin >> v[i][j];
        }            
    }
    vector<vector<long long>> dp(r, vector<long long>(c));
     
    vector<vector<long long>> invh(r, vector<long long>(c));
    vector<vector<long long>> invv(r, vector<long long>(c));
    for (long long i = 0; i < r; i++) {
        invh[i] = calc_inv_v(v[i]);
    }
    for (long long i = 0; i < c; i++) {
        vector<long long> cur;
        for (long long j = 0; j < r; j++) {
            cur.push_back(v[j][i]);
        }
        vector<long long> res = calc_inv_v(cur);
        for (long long j = 0; j < r; j++) {
            invv[j][i] = res[j];
        }
    }
 
    tree tr1(sz);
    tree tr2(sz);
    vector<vector<pair<long long, long long>>> prc(r, vector<pair<long long, long long>>(c));
    for (long long i = 0; i < r; i++) {
        tr1.clear(0, 0, sz);
        tr2.clear(0, 0, sz);
        long long ans1 = 0;
        for (long long j = c - 1; j >= 0; j--) {
            long long b = v[i][j];
            long long ans2 = 0;
            for (long long k = i + 1; k < r; k++) {
                long long x = v[k][j];
                ans1 += tr2.ask(0, 0, sz, x, sz);
            }
             
            for (long long k = i; k < r; k++) {
                long long x = v[k][j];
                ans2 += tr1.ask(0, 0, sz, 0, x);
                ans2 += tr2.ask(0, 0, sz, 0, x);
            }
 
 
            for (long long k = i + 1; k < r; k++) {
                tr1.add(0, 0, sz, v[k][j]);
            }
            ans1 += tr1.ask(0, 0, sz, 0, b);
            tr2.add(0, 0, sz, b);
            prc[i][j] = {ans1, ans2};
        }
    }
 
    for (long long i = r - 1; i >= 0; i--) {
        for (long long j = c - 1; j >= 0; j--) {
            if (i == r - 1) {
                dp[i][j] = invh[i][j];
                continue;
            }
            if (j == c - 1) {
                dp[i][j] = invv[i][j];
                continue;
            }
            long long s1 = invh[i][j], s2 = invv[i][j];
            s1 += prc[i][j].first;
            s2 += prc[i][j].second;
            dp[i][j] = min(dp[i + 1][j] + s1, dp[i][j + 1] + s2);
        }
    }
    cout << dp[0][0];
    return 0;
}