#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_map>
#include <stack>
  
using namespace std;


struct tree{
    vector<int> tr;

    tree() {}
    tree(int n) {
        tr.resize(n * 4, 0);
    }
    
    void add(int id, int l, int r, int k) {
        if (r - l == 1) {
            tr[id]++;
            return;
        }
        int mid = (l + r) / 2;
        if (k < mid) {
            add(id * 2 + 1, l, mid, k);
        } else {
            add(id * 2 + 2, mid, r, k);
        }
        tr[id] = tr[id * 2 + 1] + tr[id * 2 + 2];
    }

    int ask(int id, int l, int r, int ql, int qr) {
        if (ql <= l && r <= qr) {
            return tr[id];
        }
        if (r <= ql || qr <= l) {
            return 0;
        }
        int mid = (l + r) / 2;
        return ask(id * 2 + 1, l, mid, ql, qr) + ask(id * 2 + 2, mid, r, ql, qr);
    }

    void clear(int id, int l, int r) {
        if (tr[id] == 0) {
            return;
        }
        if (r - l == 0) {
            tr[id]--;
            return;
        }
        int mid = (l + r) / 2;
        clear(id, l, mid);
        clear(id, mid, r);
        tr[id] = 0;
    }
};

vector<vector<long long>> v;

int calc(int x, int l1, int l2, int r1, int r2) {
    int ans = 0;
    for (int i = l1; i <= l2; i++) {
        for (int j = r1; j <= r2; j++) {
            ans += (v[i][j] < x);
        }
    }
    return ans;
}

int sz;

long long calc_inv(vector<int> &v) {
    tree tr(sz);
    long long ans = 0;
    for (int i = v.size() - 1; i >= 0; i--) {
        int x = v[i];
        ans += tr.ask(0, 0, sz, 0, x);
        tr.add(0, 0, sz, x);
    }
    return ans;
}

vector<long long> calc_inv_v(vector<long long> v) {
    set<int> st;
    for (auto i : v) {
        st.insert(i);
    }
    map<int, int> mp;
    int it = 0;
    for (auto i : st) {
        mp[i] = it++;
    }

    for (int i = 0; i < v.size(); i++) {
        v[i] = mp[v[i]];
    }

    tree tr(it + 10);
    long long ans = 0;
    vector<long long> res;
    for (int i = v.size() - 1; i >= 0; i--) {
        int x = v[i];
        ans += tr.ask(0, 0, sz, 0, x);
        res.push_back(ans);
        tr.add(0, 0, sz, x);
    }
    reverse(res.begin(), res.end());
    return res;
}
  
int main()
{
    int r, c;
    cin >> r >> c;
    sz = r * c + 1;
    v.resize(r, vector<long long>(c));
    for (int i = 0; i < r; i++) {
        for (int j = 0; j < c; j++) {
            cin >> v[i][j];
        }            
    }
    vector<vector<long long>> dp(r, vector<long long>(c));
    
    vector<vector<long long>> invh(r, vector<long long>(c));
    vector<vector<long long>> invv(r, vector<long long>(c));
    for (int i = 0; i < r; i++) {
        invh[i] = calc_inv_v(v[i]);
    }
    for (int i = 0; i < c; i++) {
        vector<long long> cur;
        for (int j = 0; j < r; j++) {
            cur.push_back(v[j][i]);
        }
        vector<long long> res = calc_inv_v(cur);
        for (int j = 0; j < r; j++) {
            invv[j][i] = res[j];
        }
    }

    vector<vector<pair<int, int>>> prc(r, vector<pair<int, int>>(c));
    for (int i = 0; i < r; i++) {
        tree tr1(sz);
        tree tr2(sz);
        int ans1 = 0;
        for (int j = c - 1; j >= 0; j--) {
            int b = v[i][j];
            int ans2 = 0;
            for (int k = i + 1; k < r; k++) {
                int x = v[k][j];
                ans1 += tr2.ask(0, 0, sz, x, sz);
            }
            
            for (int k = i; k < r; k++) {
                int x = v[k][j];
                ans2 += tr1.ask(0, 0, sz, 0, x);
                ans2 += tr2.ask(0, 0, sz, 0, x);
            }


            for (int k = i + 1; k < r; k++) {
                tr1.add(0, 0, sz, v[k][j]);
            }
            ans1 += tr1.ask(0, 0, sz, 0, b);
            tr2.add(0, 0, sz, b);
            prc[i][j] = {ans1, ans2};
        }
    }

    for (int i = r - 1; i >= 0; i--) {
        for (int j = c - 1; j >= 0; j--) {
            if (i == r - 1) {
                dp[i][j] = invh[i][j];
                continue;
            }
            if (j == c - 1) {
                dp[i][j] = invv[i][j];
                continue;
            }
            int s1 = invh[i][j], s2 = invv[i][j];
            s1 += prc[i][j].first;
            s2 += prc[i][j].second;
            dp[i][j] = min(dp[i + 1][j] + s1, dp[i][j + 1] + s2);
        }
    }
    cout << dp[0][0];
    return 0;
}