#ifdef LOCAL
#define _GLIBCXX_DEBUG
#define debug(x) cerr << __LINE__ << ": " << (#x) << " = " << (x) << endl
#else
#define debug(...) 42
#endif

#pragma GCC optimize("Ofast")
#pragma GCC optimize("unroll-loops")

#include <bits/stdc++.h>

using namespace std;
using ll = long long;
using ld = long double;
using LL = __int128_t;
#define all(x) (x).begin(), (x).end()
mt19937 rng(chrono::high_resolution_clock::now().time_since_epoch().count());

template<typename T>
istream& operator >>(istream& in, vector<T> &a) {
    for (auto &elem : a) {
        in >> elem;
    }
    return in;
}

template<typename T>
ostream& operator <<(ostream& out, const vector<T> &a) {
    for (const auto &elem : a) {
        out << elem << ' ';
    }
    return out;
}

struct Req {
    int k, i;
    int id;

    constexpr Req() = default;
};

int n, q;
vector<int> p;
vector<Req> reqs;

constexpr int N = 3e5;
int st[__lg(N) + 1][N];

bool cmp(int i, int j) {
    return p[i] < p[j];
}

void build_sparse_table() {
    for (int i = 0; i < n; ++i) {
        st[0][i] = i;
    }
    for (int t = 1; t <= __lg(N); ++t) {
        for (int i = 0; i + (1 << t) <= n; ++i) {
            st[t][i] = min(st[t - 1][i], st[t - 1][i + (1 << (t - 1))], cmp);
        }
    }
}

int get_min(int l, int r) {
    const int t = __lg(r - l + 1);
    return min(st[t][l], st[t][r - (1 << t) + 1], cmp);
}

vector<int> slow() {
    build_sparse_table();
    vector nxt(n, n);
    {
        set<int, decltype([](int i, int j){return p[i] < p[j];})> s;
        for (int i = 0; i < n; ++i) {
            while (!s.empty()) {
                int id = *s.begin();
                if (p[id] < p[i]) {
                    nxt[id] = i;
                    s.erase(id);
                    continue;
                }
                break;
            }
            s.insert(i);
        }
    }
    sort(all(reqs), [](const Req &r1, const Req &r2){return r1.k < r2.k;});
    vector<int> res(q);
    int prv = -1;
    vector<int> b;

    for (const auto &[k, num, id] : reqs) {
        if (prv != k) {
            prv = k;
            b.clear();
            if (k == 1) {
                b.push_back(n);
            } else {
                int cur = k;
                int l = 0, r;
                while (cur > 1) {
                    b.push_back(p[l]);
                    r = min(nxt[l], n - cur + 1);
                    l = get_min(l + 1, r);
                    cur--;
                }
                b.push_back(*max_element(p.begin() + r, p.end()));
            }
        }
        res[id] = b[num];
    }
    return res;
}

vector<int> solve() {
    build_sparse_table();
    vector nxt(n, n);
    {
        set<int, decltype([](int i, int j){return p[i] < p[j];})> s;
        for (int i = 0; i < n; ++i) {
            while (!s.empty()) {
                int id = *s.begin();
                if (p[id] < p[i]) {
                    nxt[id] = i;
                    s.erase(id);
                    continue;
                }
                break;
            }
            s.insert(i);
        }
    }
    vector<int> suff(n);
    suff[n - 1] = p[n - 1];
    for (int i = n - 2; i >= 0; --i) {
        suff[i] = max(suff[i + 1],p[i]);
    }
    sort(all(reqs), [](const Req &r1, const Req &r2){return r1.k < r2.k;});
    vector<int> res(q);
    int prv = -1;
    vector<int> b;

    for (const auto &[k, num, id] : reqs) {
        if (k == 1) {
            res[id] = n;
        } else if (num + 1 == k) {
            res[id] = max(p[n - 1], p[num]);
        } else {
            res[id] = p[num];
        }
    }
    return res;
}

void stress() {
    for (int t = 0; t < 100; ++t) {
        n = rng() % 10 + 1;
        q = 5;
        p.resize(n);
        for (int i = 0; i < n; ++i) {
            p[i] = i & 1 ? n - i / 2 : i / 2 + 1;
        }
        reqs.resize(q);
        for (int i = 0; i < q; ++i) {
            int k = rng() % n + 1;
            int num = rng() % k;
            reqs[i].k = k;
            reqs[i].i = num;
            reqs[i].id = i;
        }
        if (solve() != slow()) {
            cout << n << ' ' << q << '\n';
            cout << p << '\n';
            sort(all(reqs), [](const Req &r1, const Req &r2){return r1.id < r2.id;});
            for (auto [k, i, id] : reqs) {
                cout << k << ' ' << i + 1 << '\n';
            }
            cout << "Out: " << solve() << '\n';
            cout << "Cor: " << slow() << '\n';
            exit(0);
        }
    }
}
int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cin >> n >> q;
    p.resize(n);
    cin >> p;
    reqs.resize(q);
    for (int i = 0; i < q; ++i) {
        cin >> reqs[i].k >> reqs[i].i;
        reqs[i].i--;
        reqs[i].id = i;
    }
    cout << solve();
    // stress();
}