#include <bits/stdc++.h>

using namespace std;

constexpr long long INF = (long long)2e18 + 7;

struct Fenwick2 {
    int r, c;
    vector<vector<int>> f;

    Fenwick2(int _r, int _c) {
        r = _r, c = _c;
        f.assign(r, vector<int>(c));
    }

    void add(int pos1, int pos2) {
        for (int i = pos1; i < r; i += i & -i) {
            for (int j = pos2; j < c; j += j & -j) {
                f[i][j]++;
            }
        }
    }

    int get(int pos1, int pos2) {
        int ans = 0;
        for (int i = pos1; i > 0; i -= i & -i) {
            for (int j = pos2; j > 0; j -= j & -j) {
                ans += f[i][j];
            }
        }
        return ans;
    }
};

struct Fenwick {
    int n;
    vector<int> f;

    Fenwick(int _n) {
        n = _n;
        f.assign(n, 0);
    }

    void add(int pos) {
        for (int i = pos; i < n; i += i & -i) {
            f[i]++;
        }
    }

    int get(int pos) {
        int ans = 0;
        for (int i = pos; i > 0; i -= i & -i) {
            ans += f[i];
        }
        return ans;
    }
};

void solve() {
    int r, c;
    cin >> r >> c;
    vector<vector<int>> a(r, vector<int>(c));
    vector<pair<int, int>> ord;
    for (int i = 0; i < r; ++i) {
        for (int j = 0; j < c; ++j) {
            cin >> a[i][j];
            ord.emplace_back(i, j);
        }
    }
    if (r < c) {
        vector<vector<int>> a2(c, vector<int>(r));
        for (int i = 0; i < r; ++i) {
            for (int j = 0; j < c; ++j) {
                a2[j][i] = a[i][j];
            }
        }
        swap(r, c);
        a = a2;
        for (int i = 0; i < r * c; ++i) {
            swap(ord[i].first, ord[i].second);
        }
    }
    sort(ord.begin(), ord.end(), [&](pair<int, int> p1, pair<int, int> p2) -> bool {
        return a[p1.first][p1.second] < a[p2.first][p2.second];
    });
    Fenwick2 f(r + 1, c + 1);
    vector<Fenwick> f1(c, Fenwick(r + 1));
    vector<vector<long long>> vals1(r, vector<long long>(c)), vals2(r, vector<long long>(c)), sum_vals1(r, vector<long long>(c)), sum_vals2(r, vector<long long>(c));
    long long ans = 0;
    vector<int> cnt(c);
    for (auto [i, j] : ord) {
        ans += f.get(r, c) - f.get(r, j) - f.get(i, c) + f.get(i, j);
        for (int j2 = 0; j2 < j; ++j2) {
            vals1[i][j2] += cnt[j2] - f1[j2].get(i + 1);
        }
        f.add(i + 1, j + 1);
        f1[j].add(i + 1);
        cnt[j]++;
    }
    vector<vector<long long>> dp(r, vector<long long>(c));
    for (int i = r - 1; i >= 0; --i) {
        for (int j = c - 1; j >= 0; --j) {
            vals2[i][j] = (r - i - 1) * (c - j - 1) - vals1[i][j];
            sum_vals1[i][j] = vals1[i][j];
            sum_vals2[i][j] = vals2[i][j];
            if (i == r - 1 && j == c - 1) {
                continue;
            }
            if (i + 1 < r) {
                sum_vals2[i][j] += sum_vals2[i + 1][j];
            }
            if (j + 1 < c) {
                sum_vals1[i][j] += sum_vals1[i][j + 1];
            }
            if (i + 1 == r) {
                dp[i][j] = dp[i][j + 1] + sum_vals2[i][j];
            } else if (j + 1 == c) {
                dp[i][j] = dp[i + 1][j] + sum_vals1[i][j];
            } else {
                // if (vals1[i][j] <= vals2[i][j]) {
                //     dp[i][j] = dp[i + 1][j] + sum_vals1[i][j];
                // } else {
                //     dp[i][j] = dp[i][j + 1] + sum_vals2[i][j];
                // }
                dp[i][j] = min(dp[i + 1][j] + sum_vals1[i][j], dp[i][j + 1] + sum_vals2[i][j]);
            }
        }
    }
    cout << dp[0][0] + ans << '\n';
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int t = 1;
    // cin >> t;
    while (t--) {
        solve();
    }
    return 0;
}
