#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#include<map>
#include <set>
using namespace std;
using ll = long long;
using ull = unsigned long long;
const ll LINF = 1e18 + 7;
struct fenvik
{
	vector<ll> a;
	int n;
	fenvik(int _n) : n(_n)
	{
		a.resize(n + 1);
	}
	void add(int i, int x)
	{
		for (i; i <= n; i += i & -i)
		{
			a[i] += x;
		}
	}
	ll get(int i)
	{
		ll ans = 0;
		for (i; i > 0; i -= i & -i)
		{
			ans += a[i];
		}
		return ans;
	}
};


int main()
{
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	int n, m;
	cin >> n >> m;
	vector<vector<int>> a(n, vector<int>(m));
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++) cin >> a[i][j];
	}
	vector<vector<ll>> row(n, vector<ll>(m)), col(n, vector<ll>(m));
	fenvik fen(n * m);
	for (int i = 0; i < n; i++)
	{
		for (int j = m - 1; j >= 0; j--)
		{
			row[i][j] = fen.get(a[i][j] - 1);
			fen.add(a[i][j], 1);
			if (j + 1 < m) row[i][j] += row[i][j + 1];
		}
		for (int j = m - 1; j >= 0; j--)
		{
			fen.add(a[i][j], -1);
		}
	}
	for (int j = 0; j < m; j++)
	{
		for (int i = n - 1; i >= 0; i--)
		{
			col[i][j] = fen.get(a[i][j] - 1);
			fen.add(a[i][j], 1);
			if (i + 1 < n) col[i][j] += col[i + 1][j];
		}
		for (int i = n - 1; i >= 0; i--)
		{
			fen.add(a[i][j], -1);
		}
	}
	vector<vector<ll>> dp(n, vector<ll>(m, LINF));
	for (int x = 0; x < n; x++)
	{
		for (int y = 0; y < m; y++)
		{
			fen.add(a[x][y], 1);
		}
	}
	fenvik toprow(n*m), bottom(n*m);
	for (int x = 0; x < n; x++)
	{
		for (int y = 0; y < m; y++)
		{
			bottom.add(a[x][y], 1);
		}
	}
	
	dp[0][0] = 0;
	for (int i = 0; i < n; i++)
	{
		ll topsum = row[i][0];
		for (int y = 0; y < m; y++)
		{
			toprow.add(a[i][y], 1);
			bottom.add(a[i][y], -1);
		}
		for (int y = 0; y < m; y++)
		{
			topsum += bottom.get(a[i][y]);
		}
		for (int j = 0; j < m; j++)
		{
			if (i + 1 < n) dp[i + 1][j] = min(dp[i + 1][j], topsum + dp[i][j]);

			for (int x = i+1; x < n; x++)
			{
				fen.add(a[x][j], -1);
				topsum -= toprow.get(n * m) - toprow.get(a[x][j]);
			}
			fen.add(a[i][j], -1);
			toprow.add(a[i][j], -1);
			topsum -= toprow.get(a[i][j]);
			ll sum = 0;
			for (int x = i; x < n; x++)
			{
				sum += fen.get(a[x][j]);
			}
			if (j + 1 < m) dp[i][j + 1] = min(dp[i][j + 1], sum + col[i][j] + dp[i][j]);
		}
		for (int j = 0; j < m; j++)
		{
			for (int x = i; x < n; x++)
			{
				fen.add(a[x][j], +1);
			}
		}
		for (int y = 0; y < m; y++)
		{
			fen.add(a[i][y], -1);
		}
	}
	cout << dp[n - 1][m - 1] << '\n';
}
// n*m*(n+m)
//n*m*m;