#include <iostream>
#include <iomanip>
#include <cmath>
#include <algorithm>
#include <numeric>
#include <random>
#include <ctime>
#include <chrono>
#include <cassert>
#include <vector>
#include <string>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <deque>
#include <bitset>
using namespace std;
mt19937_64 rnd(69);

const long long INF = 1e18, MOD = 1e9 + 7;

struct fenwick
{
	long long n;
	vector<long long> ft;

	fenwick() {}

	fenwick(long long in)
	{
		n = in;
		ft.resize(n + 1);
	}

	void add(long long k)
	{
		k++;
		for (; k <= n; k += k & -k)
		{
			ft[k]++;
		}
	}

	long long get(long long k)
	{
		k++;
		long long res = 0;
		for (; k > 0; k -= k & -k)
		{
			res += ft[k];
		}
		return res;
	}
};

long long calc_inv(vector<long long>& v)
{
	vector<pair<long long, long long>> pr(v.size());
	for (long long i = 0; i < v.size(); i++)
	{
		pr[i] = { v[i], i };
	}
	sort(pr.rbegin(), pr.rend());
	fenwick ft(v.size());
	long long res = 0;
	for (auto& i : pr)
	{
		res += ft.get(i.second);
		ft.add(i.second);
	}
	return res;
}

long long calc_inv2(vector<long long>& a, vector<long long>& b)
{
	vector<pair<long long, long long>> mrg;
	mrg.reserve(a.size() + b.size());
	for (auto& i : a)
	{
		mrg.push_back({ i, 0 });
	}
	for (auto& i : b)
	{
		mrg.push_back({ i, 1 });
	}
	sort(mrg.rbegin(), mrg.rend());
	long long res = 0, cnt0 = 0;
	for (auto& i : mrg)
	{
		if (i.second == 0)
		{
			cnt0++;
		}
		else
		{
			res += cnt0;
		}
	}
	return res;
}

void solve()
{
	long long n, m;
	vector<vector<long long>> v;
	cin >> n >> m;
	v.resize(n, vector<long long>(m));
	for (long long i = 0; i < n; i++)
	{
		for (long long j = 0; j < m; j++)
		{
			cin >> v[i][j];
			v[i][j]--;
		}
	}
	vector<vector<long long>> dp(n + 1, vector<long long>(m + 1, INF));
	for (long long i = 0; i < n + 1; i++)
	{
		dp[i][m] = 0;
	}
	for (long long j = 0; j < m + 1; j++)
	{
		dp[n][j] = 0;
	}
	for (long long i = n - 1; i > -1; i--)
	{
		for (long long j = m - 1; j > -1; j--)
		{
			vector<long long> row;
			for (long long k = j; k < m; k++)
			{
				row.push_back(v[i][k]);
			}
			vector<long long> col;
			for (long long k = i; k < n; k++)
			{
				col.push_back(v[k][j]);
			}
			long long invr = calc_inv(row);
			long long invc = calc_inv(col);
			vector<long long> other;
			other.reserve((n - i) * (m - j));
			for (long long ki = i + 1; ki < n; ki++)
			{
				for (long long kj = j; kj < m; kj++)
				{
					other.push_back(v[ki][kj]);
				}
			}
			long long btr = calc_inv2(row, other);
			other.clear();
			for (long long ki = i; ki < n; ki++)
			{
				for (long long kj = j + 1; kj < m; kj++)
				{
					other.push_back(v[ki][kj]);
				}
			}
			long long btc = calc_inv2(col, other);
			dp[i][j] = min(dp[i + 1][j] + invr + btr, dp[i][j + 1] + invc + btc);
		}
	}
	cout << dp[0][0] << "\n";
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(NULL);
	cout.tie(NULL);

	solve();

	return 0;
}

/*

























*/
