#pragma GCC optimize("Ofast")

#include <iostream>
#include <iomanip>
#include <cmath>
#include <algorithm>
#include <numeric>
#include <random>
#include <ctime>
#include <chrono>
#include <cassert>
#include <vector>
#include <string>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <deque>
#include <bitset>
using namespace std;
mt19937_64 rnd(69);

const int INF = 1e9, MOD = 1e9 + 7;

struct fenw2d
{
	int n, m;
	vector<vector<int>> f;
	bool rev = false;

	fenw2d() {}

	fenw2d(int _n, int _m, bool rv = false)
	{
		n = _n;
		m = _m;
		rev = rv;
		f.resize(n + 1, vector<int>(m + 1));
	}

	void upd(int x, int y)
	{
		if (rev)
		{
			x = n - x - 1;
			y = m - y - 1;
		}
		x++;
		y++;
		for (int xx = x; xx <= n; xx += xx & -xx)
		{
			for (int yy = y; yy <= m; yy += yy & -yy)
			{
				f[xx][yy]++;
			}
		}
	}

	int get1(int x, int y)
	{
		if (rev)
		{
			x = n - x - 1;
			y = m - y - 1;
		}
		if (x < 0 || y < 0)
		{
			return 0;
		}

		x++;
		y++;
		int res = 0;
		for (int xx = x; xx > 0; xx -= xx & -xx)
		{
			for (int yy = y; yy > 0; yy -= yy & -yy)
			{
				res += f[xx][yy];
			}
		}
		return res;
	}

	int get2(int x, int y)
	{
		if (x < 0 || y < 0)
		{
			return 0;
		}

		x++;
		y++;
		int res = 0;
		for (int xx = x; xx > 0; xx -= xx & -xx)
		{
			for (int yy = y; yy > 0; yy -= yy & -yy)
			{
				res += f[xx][yy];
			}
		}
		return res;
	}
	
	int get(int x1, int y1, int x2, int y2)
	{
		if (rev)
		{
			x1 = n - x1 - 1;
			y1 = m - y1 - 1;
			x2 = n - x2 - 1;
			y2 = m - y2 - 1;
			if (x1 > x2)
			{
				swap(x1, x2);
			}
			if (y1 > y2)
			{
				swap(y1, y2);
			}
		}

		return get2(x2, y2) - get2(x1 - 1, y2) - get2(x2, y1 - 1) + get2(x1 - 1, y1 - 1);
	}
};

struct fenwick
{
	long long n;
	vector<int> f;
	bool rev = false;

	fenwick() {}

	fenwick(long long in, bool rv = false)
	{
		n = in;
		rev = rv;
		f.resize(n + 1);
	}

	void upd(int k)
	{
		if (rev)
		{
			k = n - k - 1;
		}
		k++;
		for (; k <= n; k += k & -k)
		{
			f[k]++;
		}
	}

	int get(int k)
	{
		if (rev)
		{
			k = n - k - 1;
		}
		if (k < 0)
		{
			return 0;
		}
		k++;
		int res = 0;
		for (; k > 0; k -= k & -k)
		{
			res += f[k];
		}
		return res;
	}
};

void solve()
{
	int n, m;
	vector<vector<int>> v;
	cin >> n >> m;
	v.resize(n, vector<int>(m));
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			cin >> v[i][j];
			v[i][j]--;
		}
	}
	if (n > m)
	{
		vector<vector<int>> to(m, vector<int>(n));
		for (int i = 0; i < n; i++)
		{
			for (int j = 0; j < m; j++)
			{
				to[j][i] = v[i][j];
			}
		}
		swap(to, v);
		swap(n, m);
	}

	vector<vector<int>> inv_sub_col(n, vector<int>(m)), inv_sub_row(n, vector<int>(m));
	vector<pair<int, int>> pos(n * m);
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			pos[v[i][j]] = { i, j };
		}
	}
	fenw2d ft2d(n, m, true);
	for (int val = 0; val < n * m; val++)
	{
		auto& [x, y] = pos[val];
		inv_sub_col[x][y] = ft2d.get1(x, y + 1);
		inv_sub_row[x][y] = ft2d.get1(x + 1, y);
		ft2d.upd(x, y);
	}

	vector<vector<long long>> inv2_row(n, vector<long long>(m)), inv2_col(n, vector<long long>(m));
	vector<pair<int, int>> below;
	for (long long i = n - 1; i > -1; i--)
	{
		vector<pair<int, int>> row(m);
		for (long long j = 0; j < m; j++)
		{
			row[j] = { v[i][j], j };
		}
		sort(row.begin(), row.end());
		vector<pair<int, int>> tmp;
		swap(tmp, below);
		below.resize(tmp.size() + m);
		merge(tmp.begin(), tmp.end(), row.begin(), row.end(), below.begin());

		fenwick ft(m, true);
		for (auto& [val, j] : below)
		{
			if (v[i][j] == val)
			{
				ft.upd(j);
				continue;
			}

			inv2_col[i][j] += ft.get(j + 1);
		}
	}
	for (long long i = 0; i < n; i++)
	{
		for (long long j = 0; j < m; j++)
		{
			long long all_pairs = (n - i - 1) * (m - j - 1);
			inv2_row[i][j] = all_pairs - inv2_col[i][j];
		}
	}
	for (long long i = n - 1; i > -1; i--)
	{
		for (long long j = 0; j < m; j++)
		{
			inv2_col[i][j] += inv_sub_col[i][j];
			if (i + 1 < n)
			{
				inv2_col[i][j] += inv2_col[i + 1][j];
			}
		}
	}
	for (long long j = m - 1; j > -1; j--)
	{
		for (long long i = 0; i < n; i++)
		{
			inv2_row[i][j] += inv_sub_row[i][j];
			if (j + 1 < m)
			{
				inv2_row[i][j] += inv2_row[i][j + 1];
			}
		}
	}

	vector<vector<long long>> inv_col(n, vector<long long>(m)), inv_row = inv_col;
	for (int i = 0; i < n; i++)
	{
		vector<pair<int, int>> row(m);
		for (int j = 0; j < m; j++)
		{
			row[j] = { v[i][j], j };
		}
		sort(row.begin(), row.end());
		fenwick ft(m, true);
		for (auto& [val, idx] : row)
		{
			inv_row[i][idx] = ft.get(idx);
			ft.upd(idx);
		}
		for (int j = m - 2; j > -1; j--)
		{
			inv_row[i][j] += inv_row[i][j + 1];
		}
	}
	for (int j = 0; j < m; j++)
	{
		vector<pair<int, int>> col(n);
		for (int i = 0; i < n; i++)
		{
			col[i] = { v[i][j], i };
		}
		sort(col.begin(), col.end());
		fenwick ft(n, true);
		for (auto& [val, idx] : col)
		{
			inv_col[idx][j] = ft.get(idx);
			ft.upd(idx);
		}
		for (int i = n - 2; i > -1; i--)
		{
			inv_col[i][j] += inv_col[i + 1][j];
		}
	}

	vector<vector<long long>> dp(n + 1, vector<long long>(m + 1, INF));
	for (long long i = 0; i < n + 1; i++)
	{
		dp[i][m] = 0;
	}
	for (long long j = 0; j < m + 1; j++)
	{
		dp[n][j] = 0;
	}
	for (long long i = n - 1; i > -1; i--)
	{
		for (long long j = m - 1; j > -1; j--)
		{
			long long invr = inv_row[i][j];
			long long invc = inv_col[i][j];
			long long btr = inv2_row[i][j];
			long long btc = inv2_col[i][j];
			dp[i][j] = min(dp[i + 1][j] + invr + btr, dp[i][j + 1] + invc + btc);
		}
	}
	cout << dp[0][0] << "\n";
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(NULL);
	cout.tie(NULL);

	solve();

	return 0;
}

/*

























*/
