#include <bits/stdc++.h>

using namespace std;

#ifdef LOCAL
#pragma GCC optimize("O3,unroll-loops,no-stack-protector")
#pragma GCC target("avx2,bmi,bmi2,popcnt,lzcnt,tune=native")
#endif

using ll = long long;

const int MAX_NODES = 4e6;

vector<int> graph[MAX_NODES];

int vert_cnt = 0;

int new_vert() {
    return vert_cnt++;
}

void new_edge(int a, int b) {
    graph[a].push_back(b);
}

int nodes_cnt = 0;

ll sqr(ll x) {
    return x * x;
}

ll r, r_sqr;

int new_node(int x1, int x2, int y1, int y2);

bool are_near(int x, int y, int x1, int y1) {
    return sqr(x - x1) + sqr(y - y1) <= r_sqr;
}

struct Node {
    int x1, x2, y1, y2;
    int v = -1, to_v = -1;
    int l_l = -1, l_r = -1, r_l = -1, r_r = -1;

    void create_children();

    bool is_in_circle(int x, int y) const {
        return are_near(x, y, x1, y1) && are_near(x, y, x1, y2) &&
            are_near(x, y, x2, y1) && are_near(x, y, x2, y2);
    }

    bool is_intersecting(int x, int y) const {
        return are_near(x, y, x1, y1) || are_near(x, y, x1, y2) ||
               are_near(x, y, x2, y1) || are_near(x, y, x2, y2) ||
               (x1 <= x && x <= x2 && y1 - r <= y && y <= y2 + r) ||
               (y1 <= y && y <= y2 && x1 - r <= x && x <= x2 + r);
    }

    bool is_point_in_square(int x, int y) const {
        return x1 <= x && x <= x2 && y1 <= y && y <= y2;
    }
};

Node nodes[MAX_NODES];

int new_node(int x1, int x2, int y1, int y2) {
    nodes[nodes_cnt] = {x1, x2, y1, y2, new_vert()};
    return nodes_cnt++;
}

void Node::create_children() {
    int mid_x = (x1 + x2) / 2;
    int mid_y = (y1 + y2) / 2;
    if (l_l == -1) {
        l_l = new_node(x1, mid_x, y1, mid_y);
        new_edge(v, nodes[l_l].v);
    }
    if (l_r == -1 && mid_y < y2) {
        l_r = new_node(x1, mid_x, mid_y + 1, y2);
        new_edge(v, nodes[l_r].v);
    }
    if (r_l == -1 && mid_x < x2) {
        r_l = new_node(mid_x + 1, x2, y1, mid_y);
        new_edge(v, nodes[r_l].v);
    }
    if (r_r == -1 && mid_x < x2 && mid_y < y2) {
        r_r = new_node(mid_x + 1, x2, mid_y + 1, y2);
        new_edge(v, nodes[r_r].v);
    }
}

void get(int x, int y, int v, vector<int> &in_range) {
    if (v == -1) return;
    Node &nd = nodes[v];
    if (nd.is_in_circle(x, y)) {
        in_range.push_back(v);
        return;
    }
    if (!nd.is_intersecting(x, y)) {
        return;
    }
    nd.create_children();
    get(x, y, nd.l_l, in_range);
    get(x, y, nd.l_r, in_range);
    get(x, y, nd.r_l, in_range);
    get(x, y, nd.r_r, in_range);
}

void add(int x, int y, int v, int vert) {
    if (v == -1) return;
    Node &nd = nodes[v];
    if (!nd.is_point_in_square(x, y)) {
        return;
    }
    if (nd.x1 == nd.x2) {
        assert(nd.y1 == nd.y2);
        nd.to_v = vert;
        return;
    }
    nd.create_children();
    add(x, y, nd.l_l, vert);
    add(x, y, nd.l_r, vert);
    add(x, y, nd.r_l, vert);
    add(x, y, nd.r_r, vert);
}

int comp_color[MAX_NODES], color[MAX_NODES];
int n;

void dfs(int v, int comp_col, bool col) {
    comp_color[v] = comp_col;
    color[v] = col;
    bool other_col = v < n ? !col : col;
    for (int x : graph[v]) {
        if (comp_color[x] != -1) {
            if (color[x] != other_col) {
                color[v] = -2;
            }
        } else {
            dfs(x, comp_col, other_col);
        }
    }
}

void solve() {
    cin >> n >> r;
    r_sqr = r * r;
    for (int i = 0; i < n; ++i) new_vert();
    vector<pair<int, int>> points(n);
    // int root = new_node(0, int(5e8), 0, int(5e8));
    for (int i = 0; i < n; ++i) {
        int x, y;
        cin >> x >> y;
        points[i] = {x, y};
        // add(x, y, root, i);
    }
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            if (i != j && are_near(points[i].first, points[i].second, points[j].first, points[j].second)) {
                new_edge(i, j);
            }
        }
    }
    // for (int i = 0; i < nodes_cnt; ++i) {
    //     if (nodes[i].to_v != -1) {
    //         new_edge(nodes[i].v, nodes[i].to_v);
    //     }
    // }
    // for (int i = 0; i < n; ++i) {
    //     auto [x, y] = points[i];
    //     vector<int> in_range;
    //     get(x, y, root, in_range);
    //     for (int v : in_range) {
    //         new_edge(i, nodes[v].v);
    //     }
    // }
    memset(comp_color, -1, sizeof(color[0]) * vert_cnt);
    int components_cnt = 0;
    for (int i = 0; i < n; ++i) {
        if (comp_color[i] == -1) {
            dfs(i, components_cnt++, false);
        }
    }
    vector<vector<int>> component_vertices(components_cnt);
    vector<bool> is_bad_comp(components_cnt);
    for (int i = 0; i < vert_cnt; ++i) {
        if (comp_color[i] != -1) {
            component_vertices[comp_color[i]].push_back(i);
            if (color[i] == -2)
                is_bad_comp[comp_color[i]] = true;
        }
    }
    string ans(n, '0');
    for (int i = 0; i < components_cnt; ++i) {
        if (is_bad_comp[i]) {
            for (int j : component_vertices[i]) {
                if (j < n) {
                    ans[j] = '1';
                }
            }
        }
    }
    cout << ans << "\n";
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
#ifdef LOCAL
    freopen("../input.txt", "r", stdin);
#endif
    int tt = 1;
    // cin >> tt;
    while (tt--) solve();
}
