#include <algorithm>
#include <array>
#include <cassert>
#include <iostream>
#include <vector>
#include <unordered_map>

using namespace std;

typedef long long int lint;
typedef long double ld;

struct Vector2d {
    lint x, y;

    Vector2d(int x = 0, int y = 0): x(x), y(y) {
    }

    Vector2d operator+(const Vector2d other) const {
        return Vector2d(x + other.x, y + other.y);
    }

    Vector2d operator-(const Vector2d other) const {
        return Vector2d(x - other.x, y - other.y);
    }

    lint mod() const {
        return x * x + y * y;
    }

    bool operator<(const Vector2d other) const {
        return x < other.x || x == other.x && y < other.y;
    }

    friend istream &operator>>(istream &in, Vector2d &v);

    friend ostream &operator<<(ostream &out, const Vector2d v);
};

typedef Vector2d v2d;

istream &operator>>(istream &in, Vector2d &v) {
    in >> v.x >> v.y;
    return in;
}

ostream &operator<<(ostream &out, const Vector2d v) {
    out << "(" << v.x << ", " << v.y << ")";
    return out;
}


vector<vector<int> > gr;
vector<int> clr;
vector<int> used;
vector<int> add;
vector <int> flag;

void resize(const size_t n) {
    gr.resize(n);
    clr.resize(n, 0);
    used.resize(n, 0);
    flag.resize(n, false);
}


bool dfs(const int v) {
    bool res = false;
    used[v] = true;
    add.push_back(v);
    for (const auto u: gr[v]) {
        if (clr[u] == 0) {
            clr[u] = 3 - clr[v];
            res = dfs(u) || res;
        } else if (clr[u] == clr[v]) {
            res = true;
        }
        if (flag[u]) res = true;
    }
    return res;
}

void dfs_f(const int v) {
    flag[v] = true;
    while (!gr[v].empty()) {
        int u = gr[v].back();
        if (!flag[u]) dfs_f(u);
        gr[v].pop_back();
    }
}

int main() {
    cin.tie(nullptr);
    ios_base::sync_with_stdio(false);
    int n;
    cin >> n;
    lint r;
    cin >> r;
    const lint r2 = r * r;
    vector<pair<v2d, int> > a(n);
    unordered_map<int, vector<pair<v2d, int>>> um;
    for (int i = 0; i < n; ++i) {
        cin >> a[i].first;
        a[i].second = i;
        um[static_cast<int>(a[i].first.x)].push_back(a[i]);
    }
    for (auto &[key, arr]: um) sort(arr.begin(), arr.end());
    resize(n);
    // make gr
    for (int i = 0; i < n; ++i) {
        for (int x = a[i].first.x - r; x <= a[i].first.x + r; ++x) {
            int L = lower_bound(um[x].begin(), um[x].end(), make_pair(v2d(x, a[i].first.y - r), -1)) - um[x].begin();
            for (int k = L; k < um[x].size(); ++k) {
                int j = um[x][k].second;
                if (i == j) continue;
                if (a[j].first.y > a[i].first.y + r) break;
                if ((a[i].first - a[j].first).mod() <= r2) {
                    gr[i].push_back(j);
                }
            }
        }
    }
    // for (int i = 0; i < n; ++i) {
    //     cout << i << "\t"; for (auto u: gr[i]) cout << u << " ";
    //     cout << endl;
    // }

    // O(n + m) ~= O(n) (degv <= 5)
    for (int i = 0; i < n; ++i)
        if (!used[i]) {
            add.clear();
            clr[i] = 1;
            bool y = dfs(i);
            if (y) for (auto u: add) flag[a[u].second] = true;
        }
    for (int i = 0; i < n; ++i) cout << flag[i];
    return 0;
}
