#include <iostream>
#include <string> 
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <deque>


using namespace std;
using ll = long long;

struct point{
    ll x, y;
    int i;
    point(): x(0), y(0), i(-1){}
    point(ll x, ll y, int i): x(x), y(y), i(i){}
};

ll dist2(point a, point b){
    return (b.x - a.x) * (b.x - a.x) + (b.y - a.y) * (b.y - a.y);
}


void dfs(vector<int> &comp,  vector<point> &a, vector<int> &color, vector<bool> &good, int i, int c, int clr, int n, ll r){
    comp[i] = c;
    color[i] = clr;
    for(int j = 0; j < n; j++){
        if(i == j || dist2(a[i], a[j]) > r * r)
            continue;
        if(color[j] == 3 - clr)
            continue;
        if(color[j] == clr){
            good[comp[i]] = true;
            continue;
        } 
        dfs(comp, a, color, good, j, c, 3 - clr, n, r);

    }
}

void solve_linear(ll n, ll r, vector<point> &a){
    sort(a.begin(), a.end(), [&](point a, point b){return a.x < b.x;});
    vector<bool> good(n);
    for(int i = 2; i < n; i++){
        if(a[i].x - a[i - 2].x <= r){
            good[i] = good[i - 1] = good[i - 2] = true;
        }
    }
    deque<int> q;
    for(int i = 0; i < n; i++){
        if(good[i]){
            q.push_back(i);
        }
    }
    while(!q.empty()){
        int i = q.front();
        q.pop_front();
        if(i && !good[i - 1] && a[i].x - a[i - 1].x <= r){
            good[i - 1] = true;
            q.push_back(i - 1);
        }
        if(i < n - 1 && !good[i + 1] && a[i + 1].x - a[i].x <= r){
            good[i + 1] = true;
            q.push_back(i + 1);
        }
    }
    string ans(n, '0');
    for(int i = 0; i < n; i++){
        ans[a[i].i] += good[i];
    }
    cout << ans << endl;
}

void solve(){
    ll n, r;
    cin >> n >> r;
    vector<point> a(n);
    bool flag = true;
    for(int i = 0; i < n; i++){
        cin >> a[i].x >> a[i].y;
        a[i].i = i;
        if(a[i].y)
            flag = false;
    }
    if(flag){
        solve_linear(n, r, a);
        return;
    }
    vector<int> comp(n);
    vector<int> color(n);
    vector<bool> good(n + 1);
    int c = 1;
    for(int i = 0; i < n; i++){
        if(!comp[i]){
            dfs(comp, a, color, good, i, c, 1, n, r);
            c++;
        }
    }
    for(int i = 0; i < n; i++){
        char c = '0' + (good[comp[i]]);
        cout << c ;
    }
    cout << endl;
}

signed main(){
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    #ifdef LOCAL
    freopen("input.txt", "r", stdin);
    #endif
    int t = 1;
    // cin >> t;
    while(t--){
        solve();
    }
}