#include "bits/extc++.h"

using namespace std;
using namespace __gnu_pbds;
using ll = long long;

struct Node {
    int x, v;

    Node(int x = 0, int v = 0) : x(x), v(v) {}

    friend Node operator+(Node L, Node R) {
        return Node(L.x + R.x, L.v + R.v);
    }
};

struct Segtree {
    int n;
    vector<Node> t;

    Segtree(int n, vector<Node> a) : n(n) {
        t.resize(4 * n + 1);
        build(0, 0, n, a);
    }

    void build(int v, int l, int r, vector<Node> &a) {
        if (r - l == 1) {
            t[v] = a[l];
            return;
        }
        int m = (l + r) / 2;
        build(2 * v + 1, l, m, a);
        build(2 * v + 2, m, r, a);
        t[v] = t[2 * v + 1] + t[2 * v + 2];
    }

    void update(int v, int l, int r, int i, int x) {
        if (r - l == 1) {
            t[v].v += x;
            t[v].x = min(1, t[v].v);
            return;
        }
        int m = (l + r) / 2;
        if (i < m) update(2 * v + 1, l, m, i, x);
        else update(2 * v + 2, m, r, i, x);
        t[v] = t[2 * v + 1] + t[2 * v + 2];
    }

    Node get(int v, int l, int r, int ql, int qr) {
        if (l >= ql && r <= qr) return t[v];
        if (l >= qr || r <= ql) return Node();
        int m = (l + r) / 2;
        return get(2 * v + 1, l, m, ql, qr) + get(2 * v + 2, m, r, ql, qr);
    }
};

signed main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#else
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
#endif

    int n, m;
    cin >> n >> m;

    vector<vector<int>> a(n, vector<int>(m));
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            cin >> a[i][j];
        }
    }

    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            a[i][j]--;
        }
    }

    vector<vector<ll>> dp(n + 1, vector<ll>(m + 1, 1e18));
    dp[0][0] = 0;
    Segtree tree(n * m, vector<Node>(n * m));
    for (int del_i = 0; del_i < n; ++del_i) {
        for (int del_j = 0; del_j < m; ++del_j) {
            ll cnt_a = 0;
            ll cnt_b = 0;
            for (int j = del_j; j < m; ++j) {
                cnt_a += tree.get(0, 0, n * m, a[del_i][j], n * m).x;
                tree.update(0, 0, n*m, a[del_i][j], 1);
            }
            for (int j = del_j; j < m; ++j) {
                tree.update(0, 0, n*m, a[del_i][j], -1);
            }

            for (int i = del_i; i < n; ++i) {
                cnt_b += tree.get(0, 0, n * m, a[i][del_j], n * m).x;
                tree.update(0, 0, n * m, a[i][del_j], 1);
            }
            for (int i = del_i; i < n; ++i) {
                tree.update(0, 0, n * m, a[i][del_j], -1);
            }
            dp[del_i + 1][del_j] = min(dp[del_i + 1][del_j], dp[del_i][del_j] + cnt_a);
            dp[del_i][del_j + 1] = min(dp[del_i][del_j + 1], dp[del_i][del_j] + cnt_b);

            for (int i = del_i; i < n; ++i) {
                tree.update(0, 0, n * m, a[i][del_j], 1);
            }
        }
        for (int del_j = 0; del_j < m; ++del_j) {
            for (int i = del_i; i < n; ++i) {
                tree.update(0, 0, n * m, a[i][del_j], -1);
            }
        }
        for (int j = 0; j < m; ++j) {
            tree.update(0, 0, n * m, a[del_i][j], 1);
        }
    }

    ll ans = 1e18;
    for (int i = 0; i < m; ++i) {
        ans = min(ans, dp[n][i]);
    }
    for (int i = 0; i < n; ++i) {
        ans = min(ans, dp[i][m]);
    }
    cout << ans << "\n";
}