#include <bits/stdc++.h>

using namespace std;

using ll = long long;

const ll INF = 1e18;

struct Segment_tree {
    struct Node {
        ll sum;

        ll l, r;

        Node() {
            sum = 0;
            l = -1;
            r = -1;
        }
    };

    ll n;
    vector<Node> nodes;
    ll root;

    void pull(ll now) {
        nodes[now].sum = nodes[nodes[now].l].sum + nodes[nodes[now].r].sum;
    }

    ll build(ll l, ll r) {
        ll now = nodes.size();
        nodes.push_back({});

        if (l < r - 1) {
            ll mid = (l + r) / 2;

            nodes[now].l = build(l, mid);
            nodes[now].r = build(mid, r);

            pull(now);
        }

        return now;
    }

    Segment_tree(ll n_) {
        n = n_;

        root = build(0, n);
    }

    void upd(ll now, ll l, ll r, ll pos, ll val) {
        if (l == r - 1) {
            nodes[now].sum += val;
            return;
        }

        ll mid = (l + r) / 2;

        if (pos < mid) {
            upd(nodes[now].l, l, mid, pos, val);
        } else {
            upd(nodes[now].r, mid, r, pos, val);
        }
        pull(now);
    }

    void upd(ll pos, ll val) {
        upd(root, 0, n, pos, val);
    }

    ll get_sum(ll now, ll l, ll r, ll ql, ll qr) {
        if (qr <= l || r <= ql) {
            return 0;
        }

        if (ql <= l && r <= qr) {
            return nodes[now].sum;
        }

        ll mid = (l + r) / 2;

        return get_sum(nodes[now].l, l, mid, ql, qr) + get_sum(nodes[now].r, mid, r, ql, qr);
    }

    ll get_sum(ll ql, ll qr) {
        return get_sum(root, 0, n, ql, qr);
    }
};

void solve() {
    ll n, m;
    cin >> n >> m;

    vector<vector<ll>> tab(n, vector<ll>(m));
    for (ll i = 0; i < n; i++) {
        for (ll j = 0; j < m; j++) {
            cin >> tab[i][j];
            tab[i][j]--;
        }
    }

    vector<vector<ll>> dp(n + 1, vector<ll>(m + 1, INF));
    for (ll i = 0; i <= n; i++) {
        Segment_tree seg_tree = Segment_tree(n * m);
        for (ll i_1 = 0; i_1 < i; i_1++) {
            for (ll j_1 = 0; j_1 < m; j_1++) {
                seg_tree.upd(tab[i_1][j_1], 1);
            }
        }

        for (ll j = 0; j <= m; j++) {
            if (j == 0) {
                if (i == 0) {
                    dp[i][j] = 0;
                }
            } else {
                ll ans_now = dp[i][j - 1];
                for (ll i_1 = i; i_1 < n; i_1++) {
                    ans_now += seg_tree.get_sum(tab[i_1][j - 1], n * m);
                    seg_tree.upd(tab[i_1][j - 1], 1);
                }

                dp[i][j] = min(dp[i][j], ans_now);
            }

            if (i < n) {
                ll ans_now = dp[i][j];
                for (ll j_1 = j; j_1 < m; j_1++) {
                    ans_now += seg_tree.get_sum(tab[i][j_1], n * m);
                    seg_tree.upd(tab[i][j_1], 1);
                }
                dp[i + 1][j] = ans_now;

                for (ll j_1 = j; j_1 < m; j_1++) {
                    seg_tree.upd(tab[i][j_1], -1);
                }
            }
        }
    }

    cout << dp[n][m] << '\n';
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    cout << fixed << setprecision(20);


    solve();
    cout << endl;
    return 0;
}
