#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#include <set>
#include <functional>
#include <map>
#include <climits>
#define int long long

using namespace std;

struct point {
    int x, y;
    point() = default;
    point(int x, int y) : x(x), y(y) {}
};

int power2(int x) {
    return x * x;
}

struct fenwick {
    unordered_map<int, int> t;
    int n;
    fenwick(int n) : n(n) {
    }
    void modify(int i, int val) {
        while (i < n) {
            t[i] += val;
            i += i&-i;
        }
    }
    int get(int i) {
        int res=0;
        while (i) {
            res += t[i];
            i -= i&-i;
        }
        return res;
    }
};

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(0);
#ifdef LOCAL
    freopen("input", "r", stdin);
#endif
    int n, m;
    cin >> n >> m;
    vector<vector<int>> a(n, vector<int>(m));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            cin >> a[i][j];
        }
    }
    const int MAX = n*m+11;
    vector<vector<int>> col(n, vector<int>(m)), row(n, vector<int>(m));
    for (int i = 0; i < n; i++) {
        fenwick f(MAX);
        int inv = 0;
        for (int j = m - 1; j >= 0; j--) {
            int x = a[i][j];
            inv += f.get(x);
            row[i][j] = inv;
            f.modify(x,1);
        }
    }
    for (int j = 0; j < m; j++) {
        int inv = 0;
        fenwick f(MAX);
        for (int i = n - 1; i >= 0; i--) {
            int x = a[i][j];
            inv += f.get(x);
            col[i][j] = inv;
            f.modify(x,1);
        }
    }
    vector<vector<int>> f1(n, vector<int>(m));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            fenwick f(MAX);

        }
    }
    vector<vector<int>> dp(n + 1, vector<int>(m + 1,LLONG_MAX));
    dp[0][0] = 0;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            {
                fenwick f(MAX);
                for (int k = j; k < m; k++) f.modify(a[i][k],1);
                int add = row[i][j];
                for (int x = 0; x < n; x++) {
                    for (int y = 0; y < m; y++) {
                        if (x < i || y < j) {
                            add += f.get(a[x][y]);
                        }
                    }
                }
                dp[i + 1][j] = min(dp[i + 1][j], dp[i][j] + add);
            }
            {
                fenwick f(MAX);
                for (int k = i; k < n; k++) f.modify(a[k][j],1);
                int add = col[i][j];
                for (int x = 0; x < n; x++) {
                    for (int y = 0; y < m; y++) {
                        if (x < i || y < j) {
                            add += f.get(a[x][y]);
                        }
                    }
                }
                dp[i][j + 1] = min(dp[i][j + 1], dp[i][j] + add);
            }
        }
    }
    int ans = LLONG_MAX;
    for (int i = 0; i <= n; i++) {
        for (int j = 0; j <= m; j++) {
            if (i == n || j == m) {
                ans = min(ans, dp[i][j]);
            }
        }
    }
    cout << ans << '\n';
}