#include "bits/extc++.h"

using namespace std;
using namespace __gnu_pbds;

template<class T>
using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;

template<class T>
istream &operator>>(istream &is, vector<T> &a) {
      for (T &elem: a) is >> elem;
      return is;
}

template<class T>
ostream &operator<<(ostream &os, vector<T> &a) {
      for (T &elem: a) os << elem << ' ';
      return (os << '\n');
}

template<typename Node>
struct Segtree {
      int size;
      vector<Node> tree;

      Segtree(int n) {
            size = 1;
            while (size < n) size <<= 1;
            tree.resize(size << 1);
      }

      Segtree(vector<int> &a) : Segtree(a.size()) {
            for (int i = 0; i < a.size(); ++i) tree[i + size] = {a[i], i};
            for (int i = size - 1; i > 0; --i) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }

      void set(int i, int v) {
            tree[i += size].apply(v);
            for (i >>= 1; i > 0; i >>= 1) tree[i] = tree[i << 1] + tree[i << 1 | 1];
      }

      Node get(int l, int r) {
            Node resl, resr;
            for (l += size, r += size - 1; l <= r; l >>= 1, r >>= 1) {
                  if (l & 1) resl = resl + tree[l++];
                  if (r & 1 ^ 1) resr = tree[r--] + resr;
            }

            return resl + resr;
      }
};

struct Node {
      int val, id;

      Node(int val = 1e9, int id = -1) : val(val), id(id) {}

      friend Node operator+(Node &a, Node &b) {
            if (a.val > b.val) return b;
            return a;
      }

      void apply(int v) {
            val = v;
      }
};

signed main() {
#ifdef LOCAL
      freopen("input.txt", "r", stdin);
      freopen("ans.txt", "w", stdout);
#else
      ios_base::sync_with_stdio(false);
      cin.tie(nullptr);
#endif
      int n, q;
      cin >> n >> q;
      vector<int> a(n);
      cin >> a;

      vector<int> mxs(n);
      for (int i = n - 1; i >= 0; --i) {
            if (i + 1 < n) mxs[i] = mxs[i + 1];
            mxs[i] = max(mxs[i], a[i]);
      }
      Segtree<Node> sts(mxs);
      vector<int> s = {n - 1};
      vector<int> r(n, n);
      for (int i = n - 2; i >= 0; --i) {
            while (!s.empty() and a[s.back()] < a[i]) s.pop_back();
            if (!s.empty()) r[i] = s.back();
            s.push_back(i);
      }
      Segtree<Node> st(a);
      while (q--) {
            int k, i;
            cin >> k >> i;
            if (k == i) {
                  int j = k - 2;
                  int rg = n;
                  rg = min(rg, r[j]);
                  if (rg == j + 1) {
                        cout << a[j + 1] << endl;
                        continue;
                  }
                  Node t = sts.get(j + 1, rg);
                  j = t.id;
                  cout << t.val << endl;
                  continue;
            } else cout << a[i - 1] << endl;
      }
}

