#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <set>
#include <map>
#include <unordered_map>

using namespace std;
using ll = long long;

const int INF = 1000000000;

bool check(pair<int, int>& a, pair<int, int>& b, int r) {
	if ((int)r * r >= (int)(a.first - b.first) * (a.first - b.first) + (int)(a.second - b.second) * (a.second - b.second)) {
		return true;
	}
	return false;
}

bool dfs(int v, vector<int>& used, vector<vector<int>>& graph, int col) {
	used[v] = col;
	for (auto to : graph[v]) {
		if (used[to] == col) {
			return false;
		}
		if (used[to] == 0) {
			if (!dfs(to, used, graph, -col)) {
				return false;
			}
		}
	}
	return true;
}

void gfs(int v, vector<int>& used, vector<vector<int>>& graph, vector<int>& ans) {
	used[v] = 1;
	ans[v] = 1;
	for (auto to : graph[v]) {
		if (used[to] == 0) {
			gfs(to, used, graph, ans);
		}
	}
}

struct Coord {
	int first;
	int second;
	int ind;
};

bool comp(Coord a, Coord b) {
	if (a.second < b.second) {
		return true;
	}
	else if (a.second == b.second && a.first < b.first) {
		return true;
	}
	return false;
}

vector<pair<int, int>> mover;

void precalc(int r) {
	for (int i = 0; i <= r; i++) {
		for (int j = 0; j <= r; j++) {
			if (i == 0 && j == 0) {
				continue;
			}
			if (i * i + j * j <= r * r) {
				mover.push_back({ i, j });
				if (j != 0) {
					mover.push_back({ i, -j });
				}
			}
		}
	}
}

void solve() {
	int n, r;
	cin >> n >> r;
	precalc(r);
	vector<Coord> coords(n);
	for (int i = 0; i < n; i++) {
		int x, y;
		cin >> x >> y;
		coords[i] = { x, y, i };
	}
	sort(coords.begin(), coords.end(), comp);
	unordered_map<pair<int, int>, int> mp;
	for (int i = 0; i < n; i++) {
		mp[{coords[i].first, coords[i].second}] = i;
	}
	vector<vector<int>> graph(n);
	for (int i = n - 1; i > -1; i--) {
		for (auto [dx, dy] : mover) {
			pair<int, int> cur = { coords[i].first + dx, coords[i].second + dy };
			if (mp.find(cur) != mp.end()) {
				int j = mp[cur];
				graph[i].push_back(j);
				graph[j].push_back(i);
			}
		}
	}
	vector<int> used(n, 0);
	vector<int> used2(n, 0);
	vector<int> ans(n, 0);
	int col = 1;
	for (int i = 0; i < n; i++) {
		if (used[i] == 0) {
			if (!dfs(i, used, graph, col)) {
				gfs(i, used2, graph, ans);
			}
			col += 1;
		}
	}
	vector<int> output(n, 0);
	for (int i = 0; i < n; i++) {
		output[coords[i].ind] = ans[i];
	}
	for (auto it : output) {
		cout << it;
	}
}

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	int t = 1;
	//cin >> t;
	//precalc();
	int i = 0;
	while (t-- > 0) {
		solve();
		i += 1;
	}
}