#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <set>
#include <map>

using namespace std;
using ll = long long;

const ll INF = 1000000000;

bool check(pair<ll, ll>& a, pair<ll, ll>& b, ll r) {
	if ((ll)r * r >= (ll)(a.first - b.first) * (a.first - b.first) + (ll)(a.second - b.second) * (a.second - b.second)) {
		return true;
	}
	return false;
}

bool dfs(ll v, vector<ll>& used, vector<vector<ll>>& graph, ll col) {
	used[v] = col;
	for (auto to : graph[v]) {
		if (used[to] == col) {
			return false;
		}
		if (used[to] == 0) {
			if (!dfs(to, used, graph, -col)) {
				return false;
			}
		}
	}
	return true;
}

void gfs(ll v, vector<ll>& used, vector<vector<ll>>& graph, vector<ll>& ans) {
	used[v] = 1;
	ans[v] = 1;
	for (auto to : graph[v]) {
		if (used[to] == 0) {
			gfs(to, used, graph, ans);
		}
	}
}

struct Coord {
	ll first;
	ll second;
	ll ind;
};

bool comp(Coord a, Coord b) {
	if (a.second < b.second) {
		return true;
	}
	else if (a.second == b.second and a.first < b.first) {
		return true;
	}
	return false;
}

vector<pair<ll, ll>> mover;

void precalc(ll r) {
	for (ll i = 0; i <= r; i++) {
		for (ll j = 0; j <= r; j++) {
			if (i == 0 and j == 0) {
				continue;
			}
			if (i * i + j * j <= r * r) {
				mover.push_back({ i, j });
				if (j != 0) {
					mover.push_back({ i, -j });
				}
			}
		}
	}
}

void solve() {
	ll n, r;
	cin >> n >> r;
	precalc(r);
	vector<Coord> coords(n);
	for (ll i = 0; i < n; i++) {
		ll x, y;
		cin >> x >> y;
		coords[i] = { x, y, i };
	}
	sort(coords.begin(), coords.end(), comp);
	map<pair<ll, ll>, ll> mp;
	for (ll i = 0; i < n; i++) {
		mp[{coords[i].first, coords[i].second}] = i;
	}
	vector<vector<ll>> graph(n);
	for (ll i = n - 1; i > -1; i--) {
		for (auto [dx, dy] : mover) {
			pair<ll, ll> cur = { coords[i].first + dx, coords[i].second + dy };
			if (mp.find(cur) != mp.end()) {
				ll j = mp[cur];
				graph[i].push_back(j);
				graph[j].push_back(i);
			}
		}
	}
	vector<ll> used(n, 0);
	vector<ll> used2(n, 0);
	vector<ll> ans(n, 0);
	ll col = 1;
	for (ll i = 0; i < n; i++) {
		if (used[i] == 0) {
			if (!dfs(i, used, graph, col)) {
				gfs(i, used2, graph, ans);
			}
			col += 1;
		}
	}
	vector<ll> output(n, 0);
	for (ll i = 0; i < n; i++) {
		output[coords[i].ind] = ans[i];
	}
	for (auto it : output) {
		cout << it;
	}
}

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	ll t = 1;
	//cin >> t;
	//precalc();
	ll i = 0;
	while (t --> 0) {
		solve();
		i += 1;
	}
}