from math import sqrt
from collections import deque, defaultdict
from functools import cache

import sys
input = sys.stdin.readline

@cache
def able_to_move(x, y, x2, y2, r):
    ax = abs(x-x2)
    ay = abs(y-y2)
    
    distance = sqrt(ay*ay + ax*ax)
    
    return distance <= r

def bfs(graph, start):
    visited = set()
    colors = dict()

    colors[start] = 1
    visited.add(start)

    q = deque()
    for u in graph[start]:
        q.appendleft((u, -1, True))

    while q:
        v, color, offset = q.pop()
        if v not in visited or offset:
            if v in visited and offset:
                if color != colors[v]:
                    return visited, False
            else:
                colors[v] = color
                visited.add(v)

                for u in graph[v]:
                    q.appendleft((u, -color, True))
    
    return visited, True

def main():
    n, r = map(int, input().split())
    points = dict()
    for i in range(1, n+1):
        points[i] = tuple(map(int, input().split()))

    # строим граф
    g = defaultdict(set)
    for p1 in points:
        x, y = points[p1]
        for p2 in points:
            if p1 == p2:
                continue
            x2, y2 = points[p2]
            ability = able_to_move(x, y, x2, y2, r)
            if ability:
                g[p1].add(p2)
                g[p2].add(p1)

    # чек каждую компоненту на 2-colorability
    # если точка в компоненте, которая True, то 1, иначе 0
    # чек каждую точку, если мы уже знаем о компоненте, то скип
    Gvisited = dict()
    for v in g:
        if v not in Gvisited:
            comp, colorability = bfs(g, v)
            for u in comp:
                Gvisited[u] = colorability

    ans = []
    for p in Gvisited:
        if Gvisited[p] == False:
            ans.append("1")
        else:
            ans.append("0")
    
    print("".join(ans))

main()