#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <cmath>
#include <random>

#define all(a) a.begin(), a.end()

using namespace std;
using ll = long long;
using ull = unsigned long long;
using ld = long double;
using pll = pair<ll, ll>;
using pii = pair<int, int>;

template <typename T>
struct Point {
    T x = 0, y = 0;

    Point() = default;

    Point(T const &x, T const &y) : x(x), y(y) {}

    Point operator+(Point const &p) const {
        return {x + p.x, y + p.y};
    }

    Point operator-(Point const &p) const {
        return {x - p.x, y - p.y};
    }

    T operator*(Point const &p) const {
        return x * p.x + y * p.y;
    }

    T operator%(Point const &p) const {
        return x * p.y - p.x * y;
    }

    T len2() const {
        return x * x + y * y;
    }

    ld len() const {
        return sqrtl(len2());
    }

    Point ort() const {
        return {-y, x};
    }

    bool operator<(Point const &p) const {
        if (x != p.x) return x < p.x;
        return y < p.y;
    }
};

int n;
ll r;
bool f;
vector<Point<ll>> p;
vector<vector<int>> g;
vector<int> ans, color;
vector<int> stack;
map<Point<ll>, int> q;

void dfs(int id) {
    stack.push_back(id);

    for (ll dx = -r; dx <= r; ++dx) {
        for (ll dy = -r; dy <= r; ++dy) {
            if (dx * dx + dy * dy > r * r) continue;
            if (dx == 0 and dy == 0) continue;

            auto it = q.find({p[id].x + dx, p[id].y + dy});
            if (it == q.end()) continue;

            int i = it->second;
            if (color[i]) {
                if (color[i] == color[id]) {
                    f = true;
                }
            } else {
                color[i] = 3 - color[id];
                dfs(i);
            }
        }
    }
}

void solve() {
    cin >> n >> r;
    p.resize(n);
    for (int i = 0; i < n; ++i) {
        cin >> p[i].x >> p[i].y;
        p[i].x = p[i].x * 2 / r;
        p[i].y = p[i].y * 2 / r;
        q.emplace(p[i], i);
    }
    r = 2;

    g.resize(n);
    ans.resize(n, -1);
    color.resize(n);

    for (int i = 0; i < n; ++i) {
        if (color[i]) continue;
        stack.clear();
        f = false;
        color[i] = 1;
        dfs(i);
        for (int const &e : stack) {
            ans[e] = f;
        }
    }

    for (int const &e : ans) cout << e;
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    solve();
}