#include <iostream>
#include <vector>
#include <map>
#include <cmath>
#include <algorithm>
#include <random>
#include <set>

using namespace std;
typedef long long ll;

const int maxn = 1e5;
ll x[maxn], y[maxn], us[maxn], fl[maxn], cr[maxn];
vector<int> g[maxn];
map<pair<int, int>, vector<int>> mp;

void dfs(int v, int cl, int crc) {
	us[v] = cl;
	cr[v] = crc;
	for (auto u : g[v]) {
		if (!us[u]) {
			dfs(u, 3 - cl, crc);
		}
		else if (us[v] == us[u]) {
			fl[crc] = 1;
		}
	}
}

struct pt {
	ll x, y;
	pt(ll x_, ll y_) : x(x_), y(y_) {}
	pt() {}
	pt operator-(const pt& oth) const {
		return pt(x - oth.x, y - oth.y);
	}
	ll operator%(const pt& oth) const {
		return x * oth.y - y * oth.x;
	}
	ll len2() {
		return x * x + y * y;
	}
};
pt p[maxn];

vector<int> convex_hull(vector<int>& v) {
	int n = v.size();
	for (int i = 1; i < n; ++i) {
		if (p[v[i]].x < p[v[0]].x || (p[v[i]].x == p[v[0]].x && p[v[i]].y < p[v[0]].y)) {
			swap(v[i], v[0]);
		}
	}
	sort(v.begin() + 1, v.end(), [&](int a, int b) {
		if ((p[a] - p[0]) % (p[b] - p[0]) == 0) {
			return (p[a] - p[0]).len2() < (p[b] - p[0]).len2();
		}
		return (p[a] - p[0]) % (p[b] - p[0]) > 0;
		});
	vector<int> st;
	for (int i = 0; i < n; ++i) {
		while (st.size() >= 2 && (p[st[st.size() - 2]] - p[st.back()]) % (p[st.back()] - p[v[i]]) <= 0) {
			st.pop_back();
		}
		st.push_back(v[i]);
	}
	return st;
}

bool dst(vector<int>& a, vector<int>& b, ll r) {
	int ia = 0, ib = 0;
	a.push_back(a[0]);
	b.push_back(b[0]);
	while (ia + 1 < a.size() || ib + 1 < b.size()) {
		if ((p[a[ia]] - p[b[ib]]).len2() <= r * r) return 1;
		if (ia + 1 == a.size() || (ib + 1 != b.size() && (p[b[ib + 1]] - p[b[ib]]) % (p[a[ia + 1]] - p[a[ia]]) >= 0)) {
			++ib;
		}
		else {
			++ia;
		}
	}
	return 0;
}

signed main() {
	cin.tie(0);
	ios::sync_with_stdio(0);

	ll n, r;
	cin >> n >> r;
	vector<pair<int, int>> dd;
	for (int i = 0; i < n; ++i) {
		cin >> x[i] >> y[i];
		p[i] = pt(x[i], y[i]);
		mp[{x[i] / r, y[i] / r}].push_back(i);
		dd.push_back({ x[i] / r, y[i] / r });
	}
	vector<vector<int>> vc;
	for (int i = 0; i < n; ++i) {
		int xx = x[i] / r;
		int yy = y[i] / r;
		for (int dx = -1; dx <= 1; ++dx) {
			for (int dy = -1; dy <= 1; ++dy) {
				if ((dx != 0 || dy != 0) && mp[{xx + dx, yy + dy}].size() > 3 && mp[{xx, yy}].size() > 3) {
					if (dx > 0 || (dy > 0 && dx == 0)) {
						vc.push_back({ xx, yy, xx + dx, yy + dy });
					}
					continue;
				}
				int cn = 0;
				for (auto j : mp[{xx + dx, yy + dy}]) {
					if (i != j && (x[i] - x[j]) * (x[i] - x[j]) + (y[i] - y[j]) * (y[i] - y[j]) <= r * r) {
						g[i].push_back(j);
						g[j].push_back(i);
						++cn;
					}
					if (cn == 3) {
						break;
					}
				}
			}
		}
	}
	sort(dd.begin(), dd.end());
	dd.resize(unique(dd.begin(), dd.end()) - dd.begin());

	for (auto i : dd) {
		if (mp[i].size() >= 3) {
			mp[i] = convex_hull(mp[i]);
		}
	}
	for (auto i : vc) {
		if (dst(mp[{i[0], i[1]}], mp[{i[2], i[3]}], r)) {
			g[mp[{i[0], i[1]}][0]].push_back(mp[{i[2], i[3]}][0]);
			g[mp[{i[2], i[3]}][0]].push_back(mp[{i[0], i[1]}][0]);
		}
	}
	int pp = 0;
	for (int i = 0; i < n; ++i) {
		if (!us[i]) {
			dfs(i,  1, pp);
			++pp;
		}
		cout << fl[cr[i]];
	}

	return 0;
}
