#pragma GCC optimize("O3,unroll-loops")
#include <bits/stdc++.h>
#pragma GCC target("avx,avx2")

using namespace std;

#define all(x) (x).begin(),(x).end()

#ifdef DBG
#define debug(x) cout << #x << " = " << x << endl
#define $(x) {x}
#else
#define debug(x)
#define $(x)
#endif

using ll = long long;

struct Point {
    int id = 0;
    int x = 0, y = 0;
    Point(int id_, int x_, int y_): id(id_), x(x_), y(y_) {

    }
};

struct SegTree {
    vector<int> t;

    void add(int i, int l, int r, int q, int v) {
        if (q < l || r <= q) return;
        if (l + 1 == r) {
            t[i] += v;
            return;
        }

        int mid = (l + r) / 2;
        add(i * 2 + 1, l, mid, q, v);
        add(i * 2 + 2, mid, r, q, v);
        t[i] = t[i * 2 + 1] + t[i * 2 + 2];
    }

    int get(int i, int l, int r, int ql, int qr) {
        if (r <= ql || qr <= l) return 0;
        if (ql <= l && r <= qr) return t[i];
        int mid = (l + r) / 2;
        return get(i * 2 + 1, l, mid, ql, qr) + get(i * 2 + 2, mid, r, ql, qr);
    }

    int n;

    SegTree(int n_): n(n_) {
        t.assign(n * 4 + 10, 0);
    }

    void add(int q, int v) {
        add(0, 0, n, q, v);
    }

    int get(int l, int r) {
        return get(0, 0, n, l, r);
    }
};

const ll INF = 1e18;

void solve() {
    int n, m;
    cin >> n >> m;
    int u = n * m;
    vector<vector<int>> t(n, vector<int> (m));

    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            cin >> t[i][j];
            t[i][j]--;
        }
    }

    vector<vector<ll>> dp(n, vector<ll>(m, INF));
    vector<vector<ll>> dr(n, vector<ll>(m, 0));
    vector<vector<ll>> dd(n, vector<ll>(m, 0));

    SegTree st(u);
    for (int i = 0; i < n; ++i) {
        vector<int> adds;
        for (int j = m - 1; j >= 0; --j) {
            for (int c = i; c < n; ++c) {
                dr[i][j] += st.get(t[c][j], u);                
            }
            for (int c = 0; c < i; ++c) {
                st.add(t[c][j], 1);
                adds.push_back(t[c][j]);
            }
        }
        for (int c : adds) {
            st.add(c, -1);
        }
    }
    for (int j = 0; j < m; ++j) {
        vector<int> adds;
        for (int i = n - 1; i >= 0; --i) {
            for (int c = j; c < m; ++c) {
                dd[i][j] += st.get(t[i][c], u);                
            }
            for (int c = 0; c < j; ++c) {
                st.add(t[i][c], 1);
                adds.push_back(t[i][c]);
            }
        }
        for (int i : adds) {
            st.add(i, -1);
        }
    }
    
    dp[0][0] = 0;
    vector<vector<bool>> dir(n, vector<bool>(m, 0));

    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            if (i > 0) {
                ll vr = dp[i - 1][j] + dd[i - 1][j];
                debug(i << " " << j << " " << vr);
                if (dp[i][j] > vr) {
                    dp[i][j] = vr;
                    dir[i][j] = 1;
                }
            }
            if (j > 0) {
                ll vr = dp[i][j - 1] + dr[i][j - 1];
                if (dp[i][j] > vr) {
                    dp[i][j] = vr;
                    dir[i][j] = 0;
                }
            }
        }
    }

    int i = n - 1;
    int j = m - 1;  
    vector<int> p(1, t[n - 1][m - 1]);
    while (i >= 0 && j >= 0) {
        debug(i << " " << j);
        if (dir[i][j]) {
            i--;
            if (i >= 0) {
                for (int c = m - 1; c >= j; c--) {
                    p.push_back(t[i][c]);
                }
            }
        } else {
            j--;
            if (j >= 0) {
                for (int c = n - 1; c >= i; c--) {
                    p.push_back(t[c][j]);
                }
            }
        }
    }

    $(
        for (int i : p) {
            cout << i << ' ';
        }
        cout << endl;
    )

    reverse(all(p));
    debug(p.size());
    int cnt = 0;
    for (int i = 0; i < u; ++i) {
        cnt += st.get(p[i], u);
        st.add(p[i], 1);
    }
    cout << cnt << '\n';
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int t = 1;
    $(cin >> t;)

    for (int i = 0; i < t; ++i) {
        solve();
        $(cout << endl;)
    } 
}

