#pragma GCC optimize("O3,unroll-loops")
#include <bits/stdc++.h>
#pragma GCC target("avx,avx2")

using namespace std;

#define all(x) (x).begin(),(x).end()

#ifdef DBG
#define debug(x) cout << #x << " = " << x << endl
#define $(x) {x}
#else
#define debug(x)
#define $(x)
#endif

using ll = long long;



struct SegTree {
    vector<ll> t;

    void add(ll i, ll l, ll r, ll q, ll v) {
        if (q < l || r <= q) return;
        if (l + 1 == r) {
            t[i] += v;
            return;
        }

        ll mid = (l + r) / 2;
        add(i * 2 + 1, l, mid, q, v);
        add(i * 2 + 2, mid, r, q, v);
        t[i] = t[i * 2 + 1] + t[i * 2 + 2];
    }

    ll get(ll i, ll l, ll r, ll ql, ll qr) {
        if (r <= ql || qr <= l) return 0;
        if (ql <= l && r <= qr) return t[i];
        ll mid = (l + r) / 2;
        return get(i * 2 + 1, l, mid, ql, qr) + get(i * 2 + 2, mid, r, ql, qr);
    }

    ll n;

    SegTree(ll n_): n(n_) {
        t.assign(n * 4 + 10, 0);
    }

    void add(ll q, ll v) {
        add(0, 0, n, q, v);
    }

    ll get(ll l, ll r) {
        return get(0, 0, n, l, r);
    }
};

const ll INF = 1e18;

void solve() {
    ll n, m;
    cin >> n >> m;
    ll u = n * m;
    vector<vector<ll>> t(n, vector<ll> (m));

    for (ll i = 0; i < n; ++i) {
        for (ll j = 0; j < m; ++j) {
            cin >> t[i][j];
            t[i][j]--;
        }
    }

    vector<vector<ll>> dp(n, vector<ll>(m, INF));
    vector<vector<ll>> dr(n, vector<ll>(m, 0));
    vector<vector<ll>> dd(n, vector<ll>(m, 0));

    vector<vector<ll>> ur(n, vector<ll>(m, 0)); 
    vector<vector<ll>> ud(n, vector<ll>(m, 0)); 

    SegTree st(u);

    for (ll i = 0; i < n; ++i) {
        vector<ll> adds;
        for (ll j = m - 1; j >= 0; --j) {
            for (ll c = i; c < n; ++c) {
                dr[i][j] += st.get(t[c][j], u);                
            }
            ur[i][j] = st.get(t[i][j], u);
            for (ll c = 0; c < i; ++c) {
                st.add(t[c][j], 1);
                adds.push_back(t[c][j]);
            }
        }
        for (ll c : adds) {
            st.add(c, -1);
        }
    }
    for (ll j = 0; j < m; ++j) {
        vector<ll> adds;
        for (ll i = n - 1; i >= 0; --i) {
            for (ll c = j; c < m; ++c) {
                dd[i][j] += st.get(t[i][c], u);                
            }
            ud[i][j] = st.get(t[i][j], u);

            for (ll c = 0; c < j; ++c) {
                st.add(t[i][c], 1);
                adds.push_back(t[i][c]);
            }
        }
        for (ll i : adds) {
            st.add(i, -1);
        }
    }
    for (int i = 0; i < n; ++i) {
        for (int j = m - 2; j >= 0; --j) {
            ur[i][j] += ur[i][j + 1];
        }
    }

    for (int j = 0; j < m; ++j) {
        for (int i = n - 2; i >= 0; --i) {
            ud[i][j] += ud[i + 1][j];
        }
    }
    
    dp[0][0] = 0;
    vector<vector<bool>> dir(n, vector<bool>(m, 0));

    for (ll i = 0; i < n; ++i) {
        for (ll j = 0; j < m; ++j) {
            if (i > 0) {
                ll vr = dp[i - 1][j] + dd[i - 1][j] + ur[i - 1][j];
                debug(i << " " << j << " " << vr);
                if (dp[i][j] > vr) {
                    dp[i][j] = vr;
                    dir[i][j] = 1;
                }
            }
            if (j > 0) {
                ll vr = dp[i][j - 1] + dr[i][j - 1] + ud[i][j - 1];
                if (dp[i][j] > vr) {
                    dp[i][j] = vr;
                    dir[i][j] = 0;
                }
            }
        }
    }

    ll i = n - 1;
    ll j = m - 1;  
    vector<ll> p(1, t[n - 1][m - 1]);
    while (i >= 0 && j >= 0) {
        debug(i << " " << j);
        if (dir[i][j]) {
            i--;
            if (i >= 0) {
                for (ll c = m - 1; c >= j; c--) {
                    p.push_back(t[i][c]);
                }
            }
        } else {
            j--;
            if (j >= 0) {
                for (ll c = n - 1; c >= i; c--) {
                    p.push_back(t[c][j]);
                }
            }
        }
    }

    
    reverse(all(p));
    debug(p.size());
    $(
        for (ll i : p) {
            cout << i << ' ';
        }
        cout << endl;
    )
    ll cnt = 0;
    for (ll i = 0; i < u; ++i) {
        cnt += st.get(p[i], u);
        st.add(p[i], 1);
    }
    cout << cnt << '\n';
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    ll t = 1;
    $(cin >> t;)

    for (ll i = 0; i < t; ++i) {
        solve();
        $(cout << endl;)
    } 
}

