#include <iostream>
#include <vector>
#include <string>
#include <set>
#include <algorithm>

using namespace std;

typedef long long ll;

vector<vector<int>> graph;
vector<bool> visited;
vector<bool> col;

struct Point
{
	ll x;
	ll y;
	int ind;

	ll dist2(const Point& p) const
	{
		return (x - p.x) * (x - p.x) + (y - p.y) * (y - p.y);
	}

	bool operator<(const Point& p) const
	{
		if (x == p.x)
			return y < p.y;
		return x < p.x;
	}
};

struct set_cmp
{
	bool operator()(const Point& p1, const Point& p2) const
	{
		if (p1.y == p2.y)
			return p1.x < p2.x;
		return p1.y < p2.y;
	}
};

class DSU
{
public:

	DSU(int n) : p(n), sz(n, 1), good(n, false)
	{
		for (int i = 0; i < n; ++i)
			p[i] = i;
	}

	bool united(int a, int b)
	{
		return getp(a) == getp(b);
	}

	bool get_good(int a)
	{
		return good[getp(a)];
	}

	void set_good(int a)
	{
		good[getp(a)] = true;
	}

	void unite(int a, int b)
	{
		int pa = getp(a), pb = getp(b);
		if (pa == pb)
			return;
		if (sz[pa] > sz[pb])
			swap(pa, pb);
		p[pa] = pb;
		sz[pb] += sz[pa];
		good[pb] = good[pb] || good[pa];
	}

private:
	vector<int> p;
	vector<int> sz;
	vector<bool> good;

	int getp(int me)
	{
		if (p[me] == me)
			return me;
		return p[me] = getp(p[me]);
	}
};

bool dfs(int me, bool c)
{
	col[me] = c;
	visited[me] = true;
	for (int v : graph[me])
	{
		if (!visited[v])
		{
			if (dfs(v, !c))
			{
				return true;
			}
		}
		else if (col[me] == col[v])
			return true;
	}
	return false;
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	int n;
	ll r;
	cin >> n >> r;
	ll r2 = r * r;
	vector<Point> p(n);
	for (int i = 0; i < n; ++i)
	{
		cin >> p[i].x >> p[i].y;
		p[i].ind = i;
	}
	graph.resize(n);
	vector<Point> orig_p = p;
	sort(p.begin(), p.end());
	set<Point, set_cmp> s;
	int set_l = 0, set_r = 0;
	DSU dsu(n);
	for (int i = 0; i < n; ++i)
	{
		while (set_r > set_l && p[set_l].x + r < p[i].x)
		{
			s.erase(p[set_l]);
			++set_l;
		}
		while (set_r < n && p[set_r].x - r <= p[i].x)
		{
			s.insert(p[set_r]);
			++set_r;
		}
		if (dsu.get_good(p[i].ind))
			continue;
		Point f_point = { 0, p[i].y - r, 0 };
		auto it = s.lower_bound(f_point);
		for (; it != s.end() && it->y <= p[i].y + r; ++it)
		{
			if (it->ind == p[i].ind)
			{
				continue;
			}
			if (p[i].dist2(*it) <= r2)
			{
				dsu.unite(p[i].ind, it->ind);
				graph[p[i].ind].emplace_back(it->ind);
				graph[it->ind].emplace_back(p[i].ind);
			}
		}
		if (graph[p[i].ind].size() > 5)
		{
			dsu.set_good(p[i].ind);
		}
		else
		{
			bool ok = false;
			for (int v1 : graph[p[i].ind])
			{
				for (int v2 : graph[p[i].ind])
				{
					if (v1 == v2)
						continue;
					if (orig_p[v1].dist2(orig_p[v2]) <= r2)
					{
						ok = true;
						break;
					}
				}
				if (ok)
					break;
			}
			if (ok)
			{
				dsu.set_good(p[i].ind);
			}
		}
	}
	string res;
	res.resize(n);
	visited.resize(n);
	col.resize(n);
	for (int i = 0; i < n; ++i)
	{
		if (dsu.get_good(i))
		{
			res[i] = '1';
		}
		else if (!visited[i])
		{
			if (dfs(i, true))
			{
				dsu.set_good(i);
				res[i] = '1';
			}
			else
			{
				res[i] = '0';
			}
		}
		else
		{
			res[i] = '0';
		}
	}
	if (r == 1)
		throw(0);
	cout << res << '\n';
	return 0;
}
