#include <iostream>
#include <vector>
#include <string>
#include <set>
#include <algorithm>
#include <unordered_set>

using namespace std;

typedef long long ll;

class Fenwick
{
public:
	Fenwick(int n) : summ(n + 1) {}

	void operator=(const Fenwick& f)
	{
		summ = f.summ;
	}

	ll get(int a)
	{
		if (a == -1)
			return 0;
		ll res = 0;
		for (int i = a; i > 0; i -= i & (-i))
		{
			res += summ[i];
		}
		return res;
	}

	ll get(int l, int r)
	{
		return get(r) - get(l);
	}

	void add(int p, ll x)
	{
		for (int i = p; i < summ.size(); i += i & (-i))
		{
			summ[i] += x;
		}
	}

private:
	vector<ll> summ;
};

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	ll r, c;
	cin >> r >> c;
	vector<vector<int>> a(r, vector<int>(c));
	for (int i = 0; i < r; ++i)
	{
		for (int j = 0; j < c; ++j)
		{
			cin >> a[i][j];
			--a[i][j];
		}
	}
	ll rc = r * c;
	vector<vector<pair<ll, ll>>> inter(r, vector<pair<ll, ll>>(c));
	Fenwick for_inter(r * c);
	for (int i = 0; i < r; ++i)
	{
		for (int j = c - 1; j >= 0; --j)
		{
			if (j != c - 1)
				inter[i][j].first = inter[i][j + 1].first + for_inter.get(a[i][j] + 1);
			else
				inter[i][j].first = for_inter.get(a[i][j] + 1);
			for_inter.add(a[i][j] + 1, 1);
		}
		for (int j = 0; j < c; ++j)
			for_inter.add(a[i][j] + 1, -1);
	}
	for (int i = 0; i < c; ++i)
	{
		for (int j = r - 1; j >= 0; --j)
		{
			inter[j][i].second += for_inter.get(a[j][i] + 1);
			if (j != r - 1)
				inter[j][i].second += inter[j + 1][i].second;
			for_inter.add(a[j][i] + 1, 1);
		}
		for (int j = 0; j < r; ++j)
			for_inter.add(a[j][i] + 1, -1);
	}
	vector<vector<ll>> dp(r, vector<ll>(c, -1));
	ll result = -1;
	Fenwick uptree(r * c), col_tree(r * c);
	dp[0][0] = 0;
	for (int i = 0; i < r; ++i)
	{
		ll col_inv = 0; //calc col_inv
		for (int j = 0; j < c; ++j)
		{
			col_inv += uptree.get(rc - a[i][j]);
			col_tree.add(a[i][j] + 1, 1);
		}
		for (int j = 0; j < c; ++j)
		{
			ll row_res = dp[i][j] + inter[i][j].second; //calc row_res
			for (int k = i; k < r; ++k)
			{
				row_res += uptree.get(rc - a[k][j]);
			}
			if (j != c - 1)
			{
				if (dp[i][j + 1] == -1 || row_res < dp[i][j + 1])
					dp[i][j + 1] = row_res;
			}
			else
			{
				if (result == -1 || row_res < result)
					result = row_res;
			}

			ll col_res = dp[i][j] + inter[i][j].first + col_inv; //calc col_res TODO
			if (i != r - 1)
			{
				if (dp[i + 1][j] == -1 || col_res < dp[i + 1][j])
					dp[i + 1][j] = col_res;
			}
			else
			{
				if (result == -1 || col_res < result)
					result = col_res;
			}

			if (j != c - 1) //update col_inv
			{
				col_tree.add(a[i][j] + 1, -1);
				col_inv -= uptree.get(rc - a[i][j]);
				for (int k = i; k < r; ++k)
				{
					col_inv += col_tree.get(a[k][j] + 1);
				}
			}
			else
			{
				col_tree.add(a[i][j] + 1, -1);
			}
			for (int k = i; k < r; ++k)
			{
				uptree.add(rc - a[k][j], 1);
			} //update uptree
		}
		for (int j = 0; j < c; ++j)
		{
			for (int k = i + 1; k < r; ++k)
			{
				uptree.add(rc - a[k][j], -1);
			}
		} // clean uptree
	}
	cout << result << '\n';
	return 0;
}
