#include <bits/stdc++.h>
#pragma GCC optimize("Ofast")

using namespace std;
using ll = long long;
using ld = long double;

struct DSU {
	vector<int> r, p;
	void init(int n) {
		r.assign(n, 0);
		p.resize(n);
		iota(p.begin(), p.end(), 0);
	}
	int find(int u) {
		if (p[u] ^ u) p[u] = find(p[u]);
		return p[u];
	}
	void merge(int u, int v) {
		u = find(u);
		v = find(v);
		if (u == v) return;
		if (r[u] > r[v]) swap(u, v);
		if (r[u] == r[v]) r[v]++;
		p[u] = v;
	}
	vector<vector<int>> get() {
		vector<vector<int>> res((int)r.size());
		for (int i = 0; i < (int)res.size(); ++i) {
			res[find(i)].push_back(i);
		}
		return res;
	}
};

string solve(vector<pair<int, int>> edges, int n) {
	vector<vector<int>> g(n);
	vector<int> used(n, -1);
	vector<int> bad(n);

	DSU st;
	st.init(n);

	for (auto &[u, v] : edges) {
		if (u == v) continue;
		g[u].push_back(v);
		g[v].push_back(u);
		st.merge(u, v);
	}

	auto dfs = [&](auto &&dfs, int v) -> void {
		for (int to : g[v]) {
			if (used[to] == -1) {
				used[to] = 1 - used[v];
				dfs(dfs, to);
			} else if (used[to] != 1 - used[v]) {
				bad[v] = 1;
			}
		}
	};

	for (int i = 0; i < n; ++i) {
		if (used[i] == -1) {
			used[i] = 0;
			dfs(dfs, i);
		}
	}

	vector<int> ans(n);

	vector<vector<int>> comps = st.get();
	for (auto it : comps) {
		bool is_bad = false;
		for (int v : it) {
			if (bad[v]) {
				is_bad = true;
				break;
			}
		}
		if (is_bad) {
			for (int v : it) {
				ans[v] = 1;
			}
		}
	}

	string res;
	for (int i = 0; i < n; ++i) {
		res += ans[i] + '0';
	}
	return res;
}

signed main() {
	ios_base::sync_with_stdio(0); cin.tie(0);

	int n, r;
	cin >> n >> r;
	vector<pair<int, int>> points(n);
	for (int i = 0; i < n; ++i) {
		cin >> points[i].first >> points[i].second;
	}
	vector<pair<int, int>> edges;

	auto get_sq_dist = [&](pair<int, int> a, pair<int, int> b) -> ll {
		ll x = a.first - b.first;
		ll y = a.second - b.second;
		return x * x + y * y;
	};

	set<pair<int, int>> st;
	vector<int> ord(n);

	auto get_extremum1 = [&](int l1, int r1, int l2, int r2) -> vector<int> {
		vector<int> res;

		auto it = st.lower_bound({r1, -1});

		for (int i = 0; i < 500; ++i) {
			if (it != st.end() && points[ord[it->second]].second <= r2) {
				res.push_back(ord[it->second]);
				it++;
			} else {
				break;
			}
		}

		sort(res.begin(), res.end());
		res.erase(unique(res.begin(), res.end()), res.end());
		
		if (!res.empty() && res.front() == -1) {
			reverse(res.begin(), res.end());
			res.pop_back();
			reverse(res.begin(), res.end());
		}

		return res;
	};

	auto get_extremum2 = [&](int l1, int r1, int l2, int r2) -> vector<int> {
		vector<int> res;

		auto it = st.lower_bound({l1, -1});

		for (int i = 0; i < 500; ++i) {
			if (it != st.end() && points[ord[it->second]].first <= l2) {
				res.push_back(ord[it->second]);
				it++;
			} else {
				break;
			}
		}

		sort(res.begin(), res.end());
		res.erase(unique(res.begin(), res.end()), res.end());
		
		if (!res.empty() && res.front() == -1) {
			reverse(res.begin(), res.end());
			res.pop_back();
			reverse(res.begin(), res.end());
		}

		return res;
	};

	iota(ord.begin(), ord.end(), 0);
	sort(ord.begin(), ord.end(), [&](int i, int j) -> bool {
		return points[i].first < points[j].first;
	});

	int ptr = 0;
	int c = 0;

	for (int i : ord) {
		while (ptr < c && points[ord[c]].first - points[ord[ptr]].first > r) {
			st.erase({points[ord[ptr]].second, ptr});
			ptr++;
		}
		auto point = points[i];
		int x = point.first, y = point.second;
		for (auto it : get_extremum1(x - r, y - r, x, y)) {
			if (get_sq_dist(points[it], points[i]) <= r * 1ll * r) {
				edges.push_back({i, it});
			}
		}
		for (auto it : get_extremum1(x - r, y, x, y + r)) {
			if (get_sq_dist(points[it], points[i]) <= r * 1ll * r) {
				edges.push_back({i, it});
			}
		}
		st.insert({points[ord[c]].second, c});
		c++;
	}

	sort(ord.begin(), ord.end(), [&](int i, int j) -> bool {
		return points[i].second < points[j].second;
	});

	ptr = c = 0;
	st.clear();

	for (int i : ord) {
		while (ptr < c && points[ord[c]].second - points[ord[ptr]].second > r) {
			st.erase({points[ord[ptr]].first, ptr});
			ptr++;
		}
		auto point = points[i];
		int x = point.first, y = point.second;
		for (auto it : get_extremum2(x - r, y - r, x, y)) {
			if (get_sq_dist(points[it], points[i]) <= r * 1ll * r) {
				edges.push_back({i, it});
			}
		}
		for (auto it : get_extremum2(x - r, y, x, y + r)) {
			if (get_sq_dist(points[it], points[i]) <= r * 1ll * r) {
				edges.push_back({i, it});
			}
		}
		st.insert({points[ord[c]].first, c});
		c++;
	}

	cout << solve(edges, n);
}
