#include <iostream>
#include <cstdint>
#include <algorithm>

using namespace std;

struct Point {
    uint32_t x;
    uint32_t y;
    uint32_t index;
};

inline bool compare(const Point & point1, const Point & point2) {
    if (point1.y == point2.y) return point1.x < point2.x;
    return point1.y < point2.y;
}

inline uint32_t get_comp(uint32_t * comps, uint32_t index) {
    if (index == comps[index]) return index;
    return comps[index] = get_comp(comps, comps[index]);
}

inline void unite(uint32_t * comps, uint32_t * lengths, uint32_t * can_comp, uint32_t index1, uint32_t index2) {
    uint32_t comp1 = get_comp(comps, index1);
    uint32_t comp2 = get_comp(comps, index2);
    if (comp1 != comp2) {
        if (lengths[comp1] > lengths[comp2]) {
            lengths[comp1] += lengths[comp2];
            if (can_comp[comp2] == '1') can_comp[comp1] = '1';
            comps[comp2] = comp1;
        } else {
            lengths[comp2] += lengths[comp1];
            if (can_comp[comp1] == '1') can_comp[comp2] = '1';
            comps[comp1] = comp2;
        }
    }
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    uint32_t n, r;
    cin >> n >> r;
    Point * points = new Point[n];
    for (uint32_t i = 0; i < n; i++) {
        cin >> points[i].x >> points[i].y;
        points[i].index = i;
    }
    sort(points, points + n, compare);
    uint32_t * comps = new uint32_t[n];
    uint32_t * lengths = new uint32_t[n];
    char * can_comp = new char[n];
    uint32_t comp_count = 0;
    uint32_t index = 0;
    while (index < n) {
        uint32_t y = points[index].y;
        uint32_t since = index;
        while (index < n && points[index].y == y) index++;
        while (since < index) {
            uint32_t new_since = since;
            while (since < n - 1 && points[since + 1].x - points[since].x <= r) since++;
            since++;
            for (uint32_t i = new_since; i < since; i++) {
                comps[i] = new_since;
            }
            lengths[new_since] = since - new_since;
            can_comp[new_since] = '0';
            for (uint32_t i = new_since; i + 2 < since; i++) {
                if (points[i + 2].x - points[i].x <= r) {
                    can_comp[new_since] = '1';
                    break;
                }
            }
        }
    }
    char * answer = new char[n + 1];
    for (uint32_t i = 0; i < n; i++) {
        answer[points[i].index] = can_comp[get_comp(comps, i)];
    }
    delete[] points;
    delete[] comps;
    delete[] lengths;
    delete[] can_comp;
    answer[n] = '\0';
    cout << answer;
    delete[] answer;
}
