#include <iostream>
#include <cstdint>
#include <algorithm>
#include <vector>

using namespace std;

struct Point {
    int32_t x;
    int32_t y;
    uint32_t index;
};

inline bool compare(const Point & point1, const Point & point2) {
    if (point1.y == point2.y) return point1.x < point2.x;
    return point1.y < point2.y;
}

inline uint32_t get_comp(uint32_t * comps, uint32_t index) {
    if (index == comps[index]) return index;
    return comps[index] = get_comp(comps, comps[index]);
}

inline void unite(uint32_t * comps, uint32_t * lengths, char * can_comp, uint32_t index1, uint32_t index2) {
    uint32_t comp1 = get_comp(comps, index1);
    uint32_t comp2 = get_comp(comps, index2);
    if (comp1 != comp2) {
        if (lengths[comp1] > lengths[comp2]) {
            lengths[comp1] += lengths[comp2];
            if (can_comp[comp2] == '1') can_comp[comp1] = '1';
            comps[comp2] = comp1;
        } else {
            lengths[comp2] += lengths[comp1];
            if (can_comp[comp1] == '1') can_comp[comp2] = '1';
            comps[comp1] = comp2;
        }
    }
}

void unite_with(uint32_t index, Point * points, uint32_t * comps, uint32_t * lengths, char * can_comp, uint32_t from, uint32_t to, int32_t x, uint32_t dy, uint32_t r) {
    if (points[to - 1].x < x && (x - points[to - 1].x) * (x - points[to - 1].x) > r * r - dy * dy) return;
    if (points[from].x > x && (points[from].x - x) * (points[from].x - x) > r * r - dy * dy) return;
    if (to - from == 1) {
        unite(comps, lengths, can_comp, index, from);
        return;
    }
    uint32_t middle = (from + to) / 2;
    unite_with(index, points, comps, lengths, can_comp, from, middle, x, dy, r);
    unite_with(index, points, comps, lengths, can_comp, middle, to, x, dy, r);
}

void connect_with(uint32_t index, Point * points, vector<uint32_t> * adj, uint32_t from, uint32_t to, int32_t x, uint32_t dy, uint32_t r) {
    if (points[to - 1].x < x && (x - points[to - 1].x) * (x - points[to - 1].x) > r * r - dy * dy) return;
    if (points[from].x > x && (points[from].x - x) * (points[from].x - x) > r * r - dy * dy) return;
    if (to - from == 1) {
        if (from == index) return;
        adj[index].push_back(from);
        adj[from].push_back(index);
        return;
    }
    uint32_t middle = (from + to) / 2;
    connect_with(index, points, adj, from, middle, x, dy, r);
    connect_with(index, points, adj, middle, to, x, dy, r);
}

char dfs(vector<uint32_t> * adj, uint8_t * colors, uint32_t index) {
    char result = '0';
    for (auto child : adj[index]) {
        if (colors[child] == colors[index]) result = '1';
        else if (colors[child] == 0) {
            colors[child] = 3 - colors[index];
            if (dfs(adj, colors, child) == '1') result = '1';
        }
    }
    return result;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    uint32_t n, r;
    cin >> n >> r;
    Point * points = new Point[n];
    for (uint32_t i = 0; i < n; i++) {
        cin >> points[i].x >> points[i].y;
        points[i].index = i;
    }
    sort(points, points + n, compare);
    uint32_t * comps = new uint32_t[n];
    uint32_t * lengths = new uint32_t[n];
    char * can_comp = new char[n];
    uint32_t comp_count = 0;
    uint32_t index = 0;
    vector<uint32_t> level_since;
    while (index < n) {
        uint32_t y = points[index].y;
        uint32_t since = index;
        level_since.push_back(since);
        while (index < n && points[index].y == y) index++;
        while (since < index) {
            uint32_t new_since = since;
            while (since < n - 1 && points[since + 1].x - points[since].x <= r) since++;
            since++;
            for (uint32_t i = new_since; i < since; i++) {
                comps[i] = new_since;
            }
            lengths[new_since] = since - new_since;
            can_comp[new_since] = '0';
            for (uint32_t i = new_since; i + 2 < since; i++) {
                if (points[i + 2].x - points[i].x <= r) {
                    can_comp[new_since] = '1';
                    break;
                }
            }
            for (uint32_t i = new_since; i < since; i++) {
                for (uint32_t j = level_since.size() - 1; j--;) {
                    uint32_t dy = points[i].y - points[level_since[j]].y;
                    if (dy > r) break;
                    unite_with(i, points, comps, lengths, can_comp, level_since[j], level_since[j + 1], points[i].x, dy, r);
                }
            }
        }
    }
    level_since.push_back(n);
    vector<uint32_t> * adj = new vector<uint32_t>[n];
    for (uint32_t i = 0; i < level_since.size() - 1; i++) {
        for (uint32_t j = level_since[i]; j < level_since[i + 1]; j++) {
            if (can_comp[get_comp(comps, j)] == '1') continue;
            for (uint32_t k = i + 1; k--;) {
                uint32_t dy = points[j].y - points[level_since[k]].y;
                if (dy > r) break;
                connect_with(j, points, adj, level_since[k], level_since[k + 1], points[j].x, dy, r);
            }
        }
    }
    uint8_t * colors = new uint8_t[n];
    fill(colors, colors + n, 0);
    char * answer = new char[n + 1];
    for (uint32_t i = 0; i < n; i++) {
        uint32_t comp = get_comp(comps, i);
        if (can_comp[comp] == '0' && colors[i] == 0) {
            colors[i] = 1;
            can_comp[comp] = dfs(adj, colors, i);
        }
        answer[points[i].index] = can_comp[comp];
    }
    delete[] adj;
    delete[] colors;
    delete[] points;
    delete[] comps;
    delete[] lengths;
    delete[] can_comp;
    answer[n] = '\0';
    cout << answer;
    delete[] answer;
}
