#include <iostream>
#include <iomanip>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <cmath>

#define all(v) v.begin(), v.end()
#define len(v) (int)v.size()

using namespace std;
using ll = long long;

int n, m;
vector<vector<int>> mtx;
const ll INF = 1e18;

struct Seg_tree
{
    vector<int> tree;
    int n;
    Seg_tree(int _n)
    {
        n = _n;
        tree.resize(4 * n, 0);
    }
    void update(int v, int l, int r, int pos, int x)
    {
        if (l > pos || r <= pos) return;
        if (r - l == 1)
        {
            tree[v] += x;
            return;
        }
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, pos, x);
        update(2 * v + 2, m, r, pos, x);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }
    int get_sum(int v, int l, int r, int ql, int qr)
    {
        if (l >= qr || r <= ql) return 0;
        if (l >= ql && r <= qr) return tree[v];
        int m = (l + r) / 2;
        return get_sum(2 * v + 1, l, m, ql, qr) + get_sum(2 * v + 2, m, r, ql, qr);
    }
};

ll get_inv(vector<int> &b)
{
    int k = n * m;
    Seg_tree tree(k + 1);
    ll cur = 0;
    for (int i = 0; i < len(b); ++i)
    {
        cur += tree.get_sum(0, 0, k + 1, b[i] + 1, k + 1);
        tree.update(0, 0, k + 1, b[i], 1);
    }
    return cur;
}

int main()
{
    cin.tie(0)->sync_with_stdio(0);
    cin >> n >> m;
    mtx.resize(n, vector<int>(m));
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < m; ++j)
        {
            cin >> mtx[i][j];
        }
    }
    //if (n == 1)
    {
        vector<int> b;
        for (int i = 0; i < n; ++i)
        {
            for (int j = 0; j < m; ++j)
            {
                b.push_back(mtx[i][j]);
            }
        }
        cout << get_inv(b);
        return 0;
    }
    if (n == 2)
    {
        int k = n * m;
        Seg_tree tree(k + 1);
        for (int j = 0; j < m; ++j)
        {
            tree.update(0, 0, k + 1, mtx[0][j], 1);
        }
        vector<int> b;
        for (int i = 0; i < n; ++i)
        {
            for (int j = 0; j < m; ++j)
            {
                b.push_back(mtx[i][j]);
            }
        }
        ll cur = get_inv(b);
        ll ans = cur;
        for (int i = 0; i < m; ++i)
        {
            tree.update(0, 0, k + 1, mtx[0][i], -1);
            // action
            int cntbig = tree.get_sum(0, 0, k + 1, mtx[1][i] + 1, k + 1);
            int cntsml = tree.get_sum(0, 0, k + 1, 0, mtx[1][i]);
            cur -= cntbig;
            cur += cntsml;
            ans = min(ans, cur);
        }
        cout << ans;
    }

    return 0;
}

