#include <iostream>
#include <iomanip>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <cmath>

#define all(v) v.begin(), v.end()
#define len(v) (int)v.size()

using namespace std;
using ll = long long;

int n, m;
vector<vector<int>> mtx;
const ll INF = 1e18;
ll ans = INF;

struct Seg_tree
{
    vector<int> tree;
    int n;
    Seg_tree(int _n)
    {
        n = _n;
        tree.resize(4 * n, 0);
    }
    void update(int v, int l, int r, int pos)
    {
        if (l > pos || r <= pos) return;
        if (r - l == 1)
        {
            tree[v] += 1;
            return;
        }
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, pos);
        update(2 * v + 2, m, r, pos);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }
    int get_sum(int v, int l, int r, int ql, int qr)
    {
        if (l >= qr || r <= ql) return 0;
        if (l >= ql && r <= qr) return tree[v];
        int m = (l + r) / 2;
        return get_sum(2 * v + 1, l, m, ql, qr) + get_sum(2 * v + 2, m, r, ql, qr);
    }
};

ll get_inv(vector<int> &b)
{
    int k = n * m;
    Seg_tree tree(k + 1);
    ll cur = 0;
    for (int i = 0; i < len(b); ++i)
    {
        cur += tree.get_sum(0, 0, k + 1, b[i] + 1, k + 1);
        tree.update(0, 0, k + 1, b[i]);
    }
    return cur;
}

int main()
{
    //cin.tie(0)->sync_with_stdio(0);
    cin >> n >> m;
    mtx.resize(n, vector<int>(m));
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < m; ++j)
        {
            cin >> mtx[i][j];
        }
    }
    vector<vector<ll>> dp(n + 1, vector<ll>(m + 1, INF));
    dp[1][1] = 0;
    for (int i = 2; i <= n; ++i)
    {
        dp[i][1] = dp[i - 1][1];
        for (int j = n - (i - 1); j < n; ++j)
        {
            if (mtx[n - i][m - 1] > mtx[j][m - 1])
            {
                dp[i][1] += 1;
            }
        }
    }
    for (int j = 2; j <= m; ++j)
    {
        dp[1][j] = dp[1][j - 1];
        for (int i = m - (j - 1); i < m; ++i)
        {
            if (mtx[n - 1][m - j] > mtx[n - 1][i])
            {
                dp[1][j] += 1;
            }
        }
    }
    for (int i = 2; i <= n; ++i)
    {
        for (int j = 2; j <= m; ++j)
        {
            int k = n * m;
            ll cur1 = dp[i - 1][j];
            Seg_tree tree(k + 1);
            vector<int> b1;
            for (int u = m - j; u < m; ++u)
            {
                b1.push_back(mtx[n - i][u]);
                tree.update(0, 0, k + 1, mtx[n - i][u]);
            }
            for (int u = m - j; u < m; ++u)
            {
                for (int w = n - (i - 1); w < n; ++w)
                {
                    cur1 += tree.get_sum(0, 0, k + 1, mtx[w][u] + 1, k + 1);
                }
            }
            cur1 += get_inv(b1);
            ll cur2 = dp[i][j - 1];
            Seg_tree tree1(k + 1);
            vector<int> b2;
            for (int u = n - i; u < n; ++u)
            {
                b2.push_back(mtx[u][m - j]);
                tree1.update(0, 0, k + 1, mtx[u][m - j]);
            }
            for (int u = m - (j - 1); u < m; ++u)
            {
                for (int w = n - i; w < n; ++w)
                {
                    cur2 += tree.get_sum(0, 0, k + 1, mtx[w][u] + 1, k + 1);
                }
            }
            cur2 += get_inv(b2);
            if (i == 2 && j== 2)
            {
               //cout << cur1 << ' ' << cur2 << '\n';
            }
            dp[i][j] = min(cur1, cur2);
        }
    }
    /*for (int i = 1; i <= n; ++i)
    {
        for (int j = 1; j <= m; ++j)
        {
            cout << dp[i][j] << ' ';
        }
        cout << '\n';
    }*/
    cout << dp[n][m];

    return 0;
}
