#include <iostream>
#include <iomanip>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <cmath>

#define all(v) v.begin(), v.end()
#define len(v) (int)v.size()

using namespace std;
using ll = long long;

int n, m;
vector<vector<int>> mtx;
const ll INF = 1e18;
ll ans = INF;

struct Seg_tree
{
    vector<int> tree;
    int n;
    Seg_tree(int _n)
    {
        n = _n;
        tree.resize(4 * n, 0);
    }
    void update(int v, int l, int r, int pos)
    {
        if (l > pos || r <= pos) return;
        if (r - l == 1)
        {
            tree[v] += 1;
            return;
        }
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, pos);
        update(2 * v + 2, m, r, pos);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }
    int get_sum(int v, int l, int r, int ql, int qr)
    {
        if (l >= qr || r <= ql) return 0;
        if (l >= ql && r <= qr) return tree[v];
        int m = (l + r) / 2;
        return get_sum(2 * v + 1, l, m, ql, qr) + get_sum(2 * v + 2, m, r, ql, qr);
    }
};

ll get_inv(vector<int> &b)
{
    int k = n * m;
    Seg_tree tree(k + 1);
    ll cur = 0;
    for (int i = 0; i < len(b); ++i)
    {
        cur += tree.get_sum(0, 0, k + 1, b[i] + 1, k + 1);
        tree.update(0, 0, k + 1, b[i]);
    }
    return cur;
}

int main()
{
    cin.tie(0)->sync_with_stdio(0);
    cin >> n >> m;
    mtx.resize(n, vector<int>(m));
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < m; ++j)
        {
            cin >> mtx[i][j];
        }
    }
    vector<vector<ll>> dp(n + 1, vector<ll>(m + 1, INF));
    vector<vector<ll>> inv(n + 1, vector<ll>(m + 1, INF));
    vector<vector<ll>> inv1(n + 1, vector<ll>(m + 1, INF));
    dp[1][1] = 0;
    inv[1][1] = 0;
    for (int i = 1; i <= n; ++i)
    {
        dp[i][0] = 0;
        inv[i][0] = 0;
        inv1[i][0] = 0;
    }
    for (int j = 1; j <= m; ++j)
    {
        dp[0][j] = 0;
        inv1[0][j] = 0;
    }
    for (int j = 1; j <= m; ++j)
    {
        int k = n * m;
        Seg_tree tree(k + 1);
        for (int i = 1; i <= n; ++i)
        {
            int k = n * m;
            inv[i][j] = inv[i - 1][j];
            for (int u = m - 1; u >= m - j; --u)
            {
                inv[i][j] += tree.get_sum(0, 0, k + 1, 0, mtx[n - i][u]);
                tree.update(0, 0, k + 1, mtx[n - i][u]);
            }
        }
    }
    for (int i = 1; i <= n; ++i)
    {
        int k = n * m;
        Seg_tree tree(k + 1);
        for (int j = 1; j <= m; ++j)
        {
            int k = n * m;
            inv1[i][j] = inv1[i][j - 1];
            for (int u = n - 1; u >= n - i; --u)
            {
                inv1[i][j] += tree.get_sum(0, 0, k + 1, 0, mtx[u][m - j]);
                tree.update(0, 0, k + 1, mtx[u][m - j]);
            }
        }
    }
    /*for (int i = 1; i <= n; ++i)
    {
        for (int j = 1; j <= m; ++j)
        {
            cout << inv[i][j] << ' ';
        }
        cout << '\n';
    }*/
    for (int i = 1; i <= n; ++i)
    {
        for (int j = 1; j <= m; ++j)
        {
            int k = n * m;
            ll cur1 = inv[i][j] - inv[i - 1][j] + dp[i - 1][j];
            ll cur2 = inv1[i][j] - inv1[i][j - 1] + dp[i][j - 1];
            dp[i][j] = min(cur1, cur2);
        }
    }
    /*for (int i = 1; i <= n; ++i)
    {
        for (int j = 1; j <= m; ++j)
        {
            cout << dp
            [i][j] << ' ';
        }
        cout << '\n';
    }*/
    cout << dp[n][m];

    return 0;
}
