#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <set>
#include <queue>
#include <random>

using namespace std;

#define len(v) (int)((v).size())

typedef long long ll;


const int SZ = 1 << 20;

int af[SZ];
int bf[SZ];

ll merge(int l, int m, int r) {
	int i = l, j = m;
	ll res = 0;
	while (i < m && j < r) {
		if (af[i] < af[j]) {
			bf[i + j - m] = af[i];
			++i;
		}
		else {
			res += (ll)(m - i);
			bf[i + j - m] = af[j];
			++j;
		}
	}
	while (i < m) {
		bf[i + j - m] = af[i];
		++i;
	}
	while (j < r) {
		bf[i + j - m] = af[j];
		++j;
	}
	for (int k = l; k < r; ++k) {
		af[k] = bf[k];
	}
	return res;
}

ll merge_sort(int l, int r) {
	if (r - l == 1) {
		return 0;
	}

	int m = (l + r) / 2;
	ll res = 0;
	res += merge_sort(l, m);
	res += merge_sort(m, r);
	res += merge(l, m, r);
	return res;
}

mt19937 gen;

int rnd() {
	return uniform_int_distribution<int>()(gen);
}

struct Root;

struct Tree {
	Root* v = nullptr;

	Tree() : v(nullptr) {};
	Tree(Root* v_) : v(v_) {};

	bool empty() {
		return v == nullptr;
	}

	int size();

	void copy();

};

struct Root {
	Tree l, r;
	int x, y;
	int sz;

	void upd();

	Root(int x_) {
		l = Tree();
		r = Tree();
		x = x_;
		y = rnd();
		sz = 1;
	}
};

int Tree::size() {
	if (empty()) return 0;
	return v->sz;
}

void Tree::copy() {
	if (!empty())
		v = new Root(*v);
}

Tree merge(Tree a, Tree b) {
	if (a.empty()) return b;
	if (b.empty()) return a;

	if (a.v->y > b.v->y) {
		a.copy();
		a.v->l = merge(a.v->l, a.v->r);
		a.v->r = b;
		a.v->upd();
		return a;
	}
	else {
		b.copy();
		b.v->r = merge(b.v->l, b.v->r);
		b.v->l = a;
		b.v->upd();
		return b;
	}
}

pair<Tree, Tree> split(Tree a, int qx) {
	if (a.empty()) return { Tree(), Tree() };

	a.copy();
	if (a.v->x < qx) {
		pair<Tree, Tree> spl = split(a.v->r, qx);
		a.v->r = spl.first;
		a.v->upd();
		return { a, spl.second };
	}
	else {
		pair<Tree, Tree> spl = split(a.v->l, qx);
		a.v->l = spl.second;
		a.v->upd();
		return { spl.first, a };
	}
}

Tree insert(Tree a, int x) {
	a.copy();
	pair<Tree, Tree> spl1 = split(a, x);
	pair<Tree, Tree> spl2 = split(spl1.second, x + 1);
	return merge(spl1.first, merge(Tree(new Root(x)), spl2.second));
}

pair<Tree, int> get_i(Tree a, int x) {
	pair<Tree, Tree> spl = split(a, x);
	pair<Tree, int> res;
	res.second = spl.first.size();
	res.first = merge(spl.first, spl.second);
	return res;
}

void Root::upd() {
	sz = 1 + l.size() + r.size();
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	int n, m;
	cin >> n >> m;

	vector<vector<int>> a(n, vector<int>(m));
	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			cin >> a[i][j];
		}
	}

	vector<vector<ll>> dp(n, vector<ll>(m, n * 1ll * m * n * m));
	dp[n - 1][m - 1] = 0;

	vector<vector<Tree>> dd(n, vector<Tree>(m));

	for (int i = n - 1; i >= 0; --i) {
		for (int j = m - 1; j >= 0; --j) {
			if (i < n - 1) dd[i][j] = Tree(new Root(*dd[i + 1][j].v));
			for (int j2 = j; j2 < m; ++j2) {
				dd[i][j] = insert(dd[i][j], a[i][j2]);
			}
		}
	}

	for (int i = n - 1; i >= 0; --i) {
		for (int j = m - 1; j >= 0; --j) {
			if (i > 0) {
				int cr = 0;
				ll cf = 0;
				for (int j2 = j; j2 < m; ++j2) {
					af[cr++] = a[i - 1][j2];
					cf += get_i(dd[i][j], a[i - 1][j2]).second;
				}
				cf += merge_sort(0, cr);

				dp[i - 1][j] = min(dp[i - 1][j], cf + dp[i][j]);
			}
			if (j > 0) {
				int cr = 0;
				ll cf = 0;
				for (int i2 = i; i2 < n; ++i2) {
					af[cr++] = a[i2][j - 1];
					cf += get_i(dd[i][j], a[i2][j - 1]).second;
				}
				cf += merge_sort(0, cr);

				dp[i][j - 1] = min(dp[i][j - 1], cf + dp[i][j]);
			}
		}
	}

	cout << dp[0][0] << '\n';
}
